*This do file checks for duplicate interviews

*Identify potential duplicates
use "${gsdTemp}/hh_raw.dta", clear
keep dataset state camp ea ea_block enum_clean ParentId1 hhh_id hhr_id loc__* today datetime duration hhsize
*Tag potential duplicate #1: records with identical GPS coordinates
duplicates tag loc__Latitude loc__Longitude loc__Altitude if loc__Latitude != . & loc__Longitude != . & loc__Altitude != . , generate(tag1)
tab tag1
replace tag1 = 0 if tag1 == .
*Tag potential duplicate #2: records with identical respondent names and same sized households
gen Id=hhr_id
merge 1:1 ParentId1 Id using "${gsdTemp}/hhm_raw.dta", nogen assert(match using) keep(match) keepusing(hhm_name)
rename hhm_name hhr_name
drop Id
duplicates tag hhr_name hhsize, generate(tag2)
tab tag2
*Tag potential duplicate #3: records with identical household head names and same sized households
gen Id=hhh_id
merge 1:1 ParentId1 Id using "${gsdTemp}/hhm_raw.dta", nogen assert(match using) keep(match) keepusing(hhm_name)
rename hhm_name hhh_name
drop Id
duplicates tag hhh_name hhsize, generate(tag3)
tab tag3
*Generate group indicators within each duplicate type
*Tag groups within duplicate type #1
egen duplicategroup_hhq_1 = group(loc__Latitude loc__Longitude loc__Altitude) if tag1 == 1
*Tag groups within duplicate type #2
egen duplicategroup_hhq_2 = group(hhr_name) if tag2 == 1 
*Tag groups within duplicate type #3
egen duplicategroup_hhq_3 = group(hhh_name) if tag3 == 1
*Compute distance between groups within duplicate types #2 and #3
*Compute distance between groups of potential duplicates in categories #2 and #3
do "${gsdDo}/fDistance.do"
foreach num of numlist 2 3 {
	sort duplicategroup_hhq_`num', stable
	bysort duplicategroup_hhq_`num': gen loc__Latitude_a = loc__Latitude[_n+1] if duplicategroup_hhq_`num' != .
	bysort duplicategroup_hhq_`num': gen loc__Longitude_a = loc__Longitude[_n+1] if duplicategroup_hhq_`num' != .
	quietly fDistance loc__Latitude loc__Longitude loc__Latitude_a loc__Longitude_a dist_`num' if duplicategroup_hhq_`num' != .
	drop loc__Latitude_a loc__Longitude_a
}
*Generate master distance variable for potential duplicates #2 and #3
gen dist = dist_2 if duplicategroup_hhq_2 != .
replace dist = dist_3 if duplicategroup_hhq_3 != .
drop dist_2 dist_3
*merge household member names
merge 1:1 ParentId1 using "${gsdData}/0-RawTemp/hhm_names_wide.dta", nogen assert(match using) keep(match)
*Generate a variable identifying how many household member names are exactly repeated across the duplicate observations.
sort duplicategroup_hhq*
gen hhm_n = 0
forvalues i = 1/17 {
	forvalues j = 1/17 {
	replace hhm_n = hhm_n+1 if hhm_name`i' == hhm_name`j'[_n+1] & hhm_name`i'!=""
	}
}
order ParentId1 dataset state camp ea ea_block enum_clean today hhr_name tag2 hhh_name tag3 loc__* tag1 
*Manually inspect potential duplicate records
*Manually inspect potential duplicates #1 
sort tag1 duplicategroup_hhq_1
*br if tag1 == 1
* don't mark as duplicates since these are adjacent EAs and GPS are relatively inaccurate; plus member names etc don't match
*Manually inspect potential duplicates #2 // respondents only gave first names so have to look at all names
sort tag2 duplicategroup_hhq_2 hhsize
br tag2 duplicategroup_hhq_2 hhsize hhr_name hhm_name* if tag2 == 1
*Manually inspect potential duplicate #3
sort tag3 duplicategroup_hhq_3 
br if tag3 == 1
*gen sum of tags
gen tags=tag1>0 
replace tags=tags+1 if tag2>0
replace tags=tags+1 if tag3>0
tab tags
tab hhm_n
