*This do files matches wave 4 households with Wave 1 and 2 households
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*prepare file with households interviewed in waves 1 and 2 to match
use "${gsdDataRaw}/Sample_W4_Final.dta", clear
keep s_ea_full hhh_name_s ea parent_key hh_list_s__1 hh_list_s__2 
rename (hh_list_s__1 hh_list_s__2) (hh_list_s__0  hh_list_s__1)
duplicates report, 
destring ea, replace
save "${gsdTemp}/match_w1w2.dta", replace
*merge sample data to collected data to extract the itnerview uuid from waves 1 and 2
use "${gsdTemp}/hh_raw.dta", clear
*keep identifying data to merge
keep if dataset==2
keep ParentId1 hhh_name_s hh_list_s__0 hh_list_s__1 hh_list_s__2  s_ea_full ea
*cleanup a bit
replace hhh_name_s=subinstr(hhh_name_s,`"""',"",.)
*merge households
merge 1:1 hhh_name_s s_ea_full ea using "${gsdTemp}/match_w1w2.dta", gen(merge1)
gen matched=(merge1==3)
keep if merge1==1 | merge1==3
*three households weren't matched
tab matched
*all the unmatched households could be manually identified 
replace parent_key="uuid:537d5d5a-79da-4b11-acd7-a44ccffb336f" if ParentId1=="7b76500fa26f4b10a49c46403a3f32ca"
replace parent_key="uuid:e806097f-9549-454e-a3fd-7ea9b8cd0edc" if ParentId1=="3e2a4f35d90b45b5af732ddd996e57ec"
replace parent_key="uuid:045a78dd-95a1-4de3-86f0-534815d29c66" if ParentId1=="12ee09ab689c429f8aa2439a19cecb68"
replace matched=1 if parent_key!=""
assert matched==1
keep ParentId1 parent_key
*there are a few duplicate parent_keys, most likely due to these households being taken from the listing, since they do not feature in the files of households interviewed in W1 or 2
*create a unique identified for these households
duplicates tag parent_key, gen(t)
gsort -t
gen n=_n
tostring n, replace
replace parent_key=subinstr(parent_key,"-",n,.) if inlist(t,1,2,3)
drop t n
duplicates report parent_key
*generate sample tag
*identify households from waves 1 2 and 4
merge 1:1 parent_key using "${gsdDataRaw}/W1W2MatchedIDs.dta" , nogen assert(match master using) keep(match master)
gen sample_W1W2W4=1 if (hhuid!="")
label var sample_W1W2W4 "Household interviewed in HFS Waves 1, 2, and 4"
drop hhuid
*identify households from wave 2
merge 1:1 parent_key using "${gsdDataRaw}/hhq_W2.dta" , nogen assert(match master using) keep(match master) keepusing(treat)
gen sample_W2W4=1 if !missing(treat)
label var sample_W2W4 "Household interviewed in HFS Waves 2 and 4"
drop treat
*identify households from wave 1
rename parent_key hhuid 
merge 1:1 hhuid using "${gsdDataRaw}/hhq_W1.dta" , nogen assert(match master using) keep(match master) keepusing(treat)
gen sample_W1W4=1 if !missing(treat)
label var sample_W1W4 "Household interviewed in HFS Waves 2 and 4"
rename hhuid parent_key
drop treat
*identify households from wave 4 only
egen insample=rowtotal(sample*)
gen sample_W4=1 if insample==0
label var sample_W4 "Household interviewed in HFS Wave 4 only"
drop insample
*consolidate these variables
gen panel=1 if sample_W1W2W4==1
replace panel=2 if sample_W2W4==1 & sample_W1W2W4!=1
replace panel=3 if sample_W1W4==1 & sample_W1W2W4!=1
replace panel=4 if sample_W4==1
assert !missing(panel)
label define lpanel 1 "Waves 1, 2, and 4" 2 "Waves 2 and 4" 3 "Waves 1 and 4" 4 "Wave 4, only" 
label val panel lpanel 
label var panel "Waves in which household was interviewed"
save "${gsdTemp}/hh_matchkeys.dta", replace

*Check how many hh members match from panel
use "${gsdDownloads}/HFSSSW4/hh_list_s_presence.dta", clear
rename Id member_id
replace hh_list_s_yn=.z if hh_list_s_yn<0
collapse (sum) hh_list_s_yn (max) num_members=member_id , by(ParentId1)
merge 1:1 ParentId1 using "${gsdTemp}/hh_raw.dta", keepusing(hhh_name_yn hh* ParentId1 enum_clean state) assert(match using master) keep(match) nogen 
replace num_members=0 if missing(num_members)
gen others_identified=hh_list_s_yn/num_members
label var others_identified "Percent hh members identified, not hh head"
label var hhh_name_yn "Previous hh head lives in hh"
label var hh_list_s_yn "No. of previous (adult) hh members still living in hh"
label var num_members "Number of previous (adult) hh members"
gen issue=(hhh_name_yn!=1 & (others_identified==0 | missing(others_identified)))
keep if issue==1
rename hh_list_s__* hh_previous_wave*
foreach v of varlist hh_previous_* {
	label var `v' "HH members from previous wave"
	replace `v'="" if `v'=="##N/A##" | `v'=="N/A"
}
rename hh_list__* hh_members*
foreach v of varlist hh_members* {
	label var `v' "HH members listed"
	replace `v'="" if `v'=="##N/A##" | `v'=="N/A"
}
rename hh_list_separated_* hh_separated*
foreach v of varlist hh_separated* {
	label var `v' "HH members separated listed"
	replace `v'="" if `v'=="##N/A##" | `v'=="N/A"
}
*merge with full list of names from waves 1 and 2
merge 1:1 ParentId1 using "${gsdTemp}/hh_matchkeys.dta", nogen assert(match master using) keep(match master) keepusing(parent_key)
merge 1:1 parent_key using "${gsdDataRaw}/Wave2_hhm_names.dta", nogen assert(match master using) keep(match master)
merge 1:1 parent_key using "${gsdDataRaw}/Wave1_hhm_names.dta", nogen  keep(match master) update
foreach v of varlist rhhm_name* {
	label var `v' "All hh members in waves 1 or 2"
	replace `v'="" if `v'=="##N/A##" | `v'=="N/A"
}
ds3, all(missing(X))
drop `r(varlist)' parent_key issue hhsize hhh_presence hhh_absence_reason hhh_absence_reason_spec hhh_id1 hhm_separated hhm_unite hhr_same hhr_id_perc hhh_id0 hhr_id hhh_name_yn others_identified num_members hh_list_s_yn
order ParentId1 , first
reshape long hh_members hh_separated_ hh_previous_wave rhhm_name, i(ParentId1 hhh_id enum_clean state) j(id)
order state ParentId1 hhh_id enum_clean id hhh_name_s hh_members hh_separated_ hh_previous_wave rhhm_name
*create excel sheet to more easily identify
export excel "${gsdOutput}/Cleaning/matching_check.xlsx", replace first(varl)
*For the households identified as not a match, change the ID in the anonimization do file
*The following households seem like problematic matches:
/*
074aed994ae54573a313ac77180a0df4
0b7a7976148b4d259f8dcf57ef44a62b
0f5e35bc68c546148852efb087cbf73d
184f89c857e5412bb28eceddeb3fa749
329562afb8ec4b099588e8238b43ca54
4da6df6913ef42f6a683a1b695530189
8b0799d6574e43f390ff041fe2eb5655
98197255bf6a45eaa2b8d263a7e87d92
a014e9f64487409f828b14f4f1f039a6
ae8931593b00413780e35d13962b6a66
b8ffd0f943ba4da79a720530a9bee402
ee889039a1114839b84f0e7b05688f98
f0004620feb6493e88b640bf24856b66
12ee09ab689c429f8aa2439a19cecb68
1abeec0bcc5e449c97f09a1bdceb686d
401043c7a5e54a7199e5af4f4e6032f8
*/
