*This do file calculates weights for the CRS

*prepare HHinstratum data
import excel "${gsdDataRaw}/sample_IDP.xlsx", clear sheet("Overview") cellrange(A2:C7) firstrow
drop if A=="Total "
gen camp=1 if A=="Juba"
replace camp=2 if A=="Wau"
replace camp=5 if A=="Malakal"
replace camp=6 if A=="Bentiu"
drop A
rename ea_all EAinStratum
rename st_all HHinStratum
save "${gsdTemp}/HHinStratum.dta" , replace
*prepare file with replacement ea for weights
import excel using "${gsdDataRaw}/EA_Replacements_CRS_v2.xlsx", clear first cellrange(F1:I12)
keep o_ea r_ea	
drop if substr(o_ea,1,1)!=substr(r_ea,1,1)
keep if r_ea!=""
drop if length(r_ea)!=4
destring o_ea r_ea, replace
label var o_ea "Original EA sampled"
rename r_ea ea
label var ea "Replacement EA interviewed during fieldwork"
format ea o_ea %12.0f
save "${gsdTemp}/Replacements_CRS.dta", replace
*prepare the necessary data from the sample frame
import excel "${gsdDataRaw}/sample_IDP.xlsx", clear sheet("Master") firstrow
keep if selected==1
gen camp=floor(ea/1000)
drop if camp==4
replace camp=1 if camp==3
rename (st_n prob) (HHinEA prob_EA)
keep camp ea HHinEA prob_EA
order camp ea HHinEA prob_EA
save "${gsdTemp}/EA_weights_data_CRS.dta", replace
*get the number of structures per block
use "${gsdDownloads}/CRS/structure_r.dta", clear
collapse (count) StrperBlock=Id, by(ParentId1)
save "${gsdTemp}/microlisting_CRS.dta", replace

*calculate first two components of weights, p1 and p2 at the EA level
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset==1
*drop interviews from Bor camp
keep if camp!=4
*collapse to get interview count and EA count per state
assert !missing(maycontinue)
assert maycontinue==1
collapse (count) interviewsperEA=maycontinue , by(camp ea)
*merge replacement EA info
merge 1:1 ea using "${gsdTemp}/Replacements_CRS.dta", nogen assert(match master using) keep(match master) 
assert o_ea!=ea if !missing(o_ea)
replace o_ea=ea if missing(o_ea)
assert !missing(ea) & !missing(o_ea)
rename ea actual_ea
rename o_ea ea
*merge EA data 
*drop Malakal for now
drop if camp==5
merge 1:1 ea using "${gsdTemp}/EA_weights_data_CRS.dta", nogen assert(match using) keep(match) 
drop ea
rename actual_ea ea
*calculate number of EAs per strata
bys camp: egen EAperStrata=count(ea)
*merge with number of HH in strata
merge m:1 camp using "${gsdTemp}/HHinStratum.dta", nogen keep(match)
*calculate P1
*	P1 = no. of EAs per strata * (no. structures per EA / no. structures per strata)
gen P1=EAperStrata*(HHinEA/HHinStratum)
*calculate P2
*	P2 = (no. blocks per EA selected / Total no. of blocks per EA)
*	EAs were built with 12 blocks so P2=1
gen P2=1
keep camp ea P1 P2 HHinStratum
assert !missing(P1, P2, HHinStratum)
save "${gsdTemp}/weights_p1p2_CRS.dta", replace

*calculate second two components of weights, p3 and p4 at the household level
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset==1
*drop interviews from Bor camp
keep if camp!=4
keep camp ea ea_block ParentId1 n_hh 
*merge microlisting
merge 1:1 ParentId1 using "${gsdTemp}/microlisting_CRS.dta", nogen assert(match master using) keep(match master)
rename n_hh HHperStructure
tabstat HHperStructure , by(camp) stat(N mean sd min q p95 p99 max) col(stat)
*clean a few interviews with much too high numbers of households per structure, replace with median per camp
replace HHperStructure=. if HHperStructure>25
*twelve households are missing the number of households within the structure, replace with median per camp; they are not return visits
bys camp: egen mednhh=median(HHperStructure)
replace HHperStructure=mednhh if missing(HHperStructure)
drop mednhh
*two interviews did not submit the original listing for a revisited household, replace with the median number for the camp
bys camp: egen mednstr=median(StrperBlock)
replace StrperBlock=mednstr if missing(StrperBlock)
assert !missing(StrperBlock,HHperStructure)
*calculate P3
*	P3 = (no. interviews per block / Total no. of structures per Block)
gen P3=1/StrperBlock
*calculate P4
*	P3 = (no. interviews per Structure / Total no. of household per Structure)
gen P4=1/HHperStructure
assert !missing(P3, P4)
keep ParentId1 camp ea ea_block P3 P4
save "${gsdTemp}/weights_p3p4_CRS.dta", replace

*merge all weights components
use "${gsdTemp}/weights_p3p4_CRS.dta", clear
merge m:1 camp ea using "${gsdTemp}/weights_p1p2_CRS.dta", nogen assert(match master) keep(match master)
*replace p1 and p2 as 1 for Malakal camp
replace P1=1 if camp==5
replace P2=1 if camp==5
order ParentId1 camp ea ea_block P1 P2 P3 P4 HHinStratum
gen weight = 1/(P1*P2*P3*P4)
keep ParentId1 camp ea ea_block weight
*check
bys camp: egen hh_pop=total(weight)
merge 1:1 ParentId1 using "${gsdData}/0-RawTemp/hhsize.dta", nogen assert(match master using) keep(match master) keepusing(hhsize) 
gen hhweight=weight*hhsize
bys camp: egen pop=total(hhweight)
tabstat pop hh_pop, by(camp) stat(mean)
save "${gsdData}/0-RawTemp/weights_CRS.dta", replace 

*merge to main dataset
use "${gsdTemp}/hh_raw.dta", clear
keep if dataset==1
merge m:1 ParentId1 using "${gsdData}/0-RawTemp/weights_CRS.dta", nogen assert(match master) keepusing(weight) 
*make Bor weights equal to one
replace weight=1 if camp==4
assert !missing(weight)
save "${gsdTemp}/hh_crs_raw_withweights.dta", replace
