clear all
set more off
set maxvar 10000
version 14.2
set rng mt64
*Check if filepaths have been established using setup.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*Download the data 
*	This cannot be run in the public do files, because the server name, username, 
*	and password required are ommitted for confidentiality reasons.
local download = 0
if `download' == 1 { 
	...
}
*Declare name of questionnaires
global HFSSSW4 = "High Frequency Survey South Sudan Wave - 4 (Fieldwork)"
global CRS = "Crisis Recovery Survey - Fieldwork"
global available = "HFSSSW4 CRS"

*Prepare Raw data (The do files perform the same actions for CRS and HFSSSW4 in parallel)
local public=1
if `public'==0 {
	*prepare and append raw data
	do "${gsdDo}/0-1-hhm.do" 
	do "${gsdDo}/0-2-0-hh.do"
	do "${gsdDo}/0-3-food.do"
	do "${gsdDo}/0-4-nonfood.do"
	do "${gsdDo}/0-5-livestock.do"
	do "${gsdDo}/0-6-assets.do"
	do "${gsdDo}/0-7-prepare_panel.do"
	do "${gsdDo}/0-8-0-weights_HFS.do"
	do "${gsdDo}/0-8-1-weights_CRS.do"
	*create anonynomous IDs, (Note: Data is not anonymous yet, still contains some confidential info dropped in the prepare do file)
	do "${gsdDo}/0-9-anonymize.do"
	do "${gsdDo}/0-10-prepare.do"
	
	*Create dashboard tracking data collection
	do "${gsdDo}/0-0-Dashboard_HFSSSW4.do"
	do "${gsdDo}/0-0-Dashboard_CRS.do"
}

*Clean data
do "${gsdDo}/1-1-clean_hhm.do"
do "${gsdDo}/1-2-clean_livestock.do"
do "${gsdDo}/1-3-clean_food.do"
do "${gsdDo}/1-4-clean_nonfood.do"
do "${gsdDo}/1-5-consumption_deflator.do"
do "${gsdDo}/1-6-clean_assets.do"
do "${gsdDo}/1-7-clean_hhq.do"
do "${gsdDo}/1-8-0-multiple_imputation.do"

if `public'==0 {
	*prepare for analysis
	do "${gsdDo}/1-9-prepare_analysis.do"
	*Compare consumption patterns across waves to check impact of cleaning
	do "${gsdDo}/1-10-consumption_patterns.do"
	do "${gsdDo}/1-11-international comparisons.do"
}

*Conduct analysis
*	Only some of the analysis is reproducible with only the publicly available files.
local public=1
if `public'==1 {
	global public=1
}
do "${gsdDo}/2-1-1-poverty.do"
do "${gsdDo}/2-1-6-education.do"
do "${gsdDo}/2-1-7-labor.do"
do "${gsdDo}/2-1-8-living_standards.do"
do "${gsdDo}/2-1-9-perceptions.do"
*	The do files below require non-shareable confidential data to run
if `public'==0 {
	*Analysis - HFS
	do "${gsdDo}/2-1-2-distributions.do"
	do "${gsdDo}/2-1-3-maps.do"
	do "${gsdDo}/2-1-4-ACLED.do"
	do "${gsdDo}/2-1-5-multidimensional_deprivation.do"
	do "${gsdDo}/2-1-10-conflict.do"
	do "${gsdDo}/2-1-11-vulnerability.do"
	do "${gsdDo}/2-1-12-PMT.do"
	do "${gsdDo}/2-1-13-social_protection.do"
	do "${gsdDo}/2-1-14-poverty_profile.do"
}
