*This do file compares consumption across waves and across camps to check impact of cleaning

*prepare appended food and nonfood dataset
use "${gsdW2}/Data/1-CleanOutput/food.dta", clear
local keepvars = "state ea hh cons price_ssp_per_kg_cleaned cons_q_kg purc_q_kg cons_value_org cons_value_fin itemid mod_item"
keep `keepvars' itemlabel
merge m:1 state ea hh using "${gsdW2}/Data/1-CleanOutput/hhq.dta", nogen assert(match master using) keepusing(month mod_hh weight_x hhsize poorPPP tc_imp quintiles_tc) keep(match master)
gen wave=2
label define lwave 1 "Wave1" 2 "Wave2" 3 "Wave3" 4 "Wave4"
label val wave lwave
rename weight_x weight
append using "${gsdData}/1-CleanOutput/food.dta" , keep(`keepvars' dataset)
merge m:1 dataset state ea hh using "${gsdData}/1-CleanOutput/hhq.dta", nolabel keepusing(month mod_hh weight hhsize poorPPP tc_imp quintiles_tc dataset) nogen update 
replace wave=4 if missing(wave)
bys itemid: egen item_name=max(itemlabel)
replace poorPPP=poorPPP_prob if wave==4
drop itemlabel poorPPP_prob 
drop if missing(itemid)
label val item_name item_name
label val state s_v
label define lState 81 "Warrap", modify
order wave state ea hh weight poorPPP hhsize tc_imp mod_hh mod_item itemid item_name, first
format item_name %24.0f
save "${gsdData}/1-CleanTemp/food_analysis.dta", replace

***Compare waves 2 and 4
*Check poverty trends using a core consumption measure of poverty (to check impact of imputation)
use "${gsdData}/1-CleanTemp/hhq_analysis.dta", clear
keep if inlist(wave,2,4)
drop if dataset==1
*generate a core consumption measure of poverty (value is 70% for both waves)
gen rcore=tc_core/tc_imp
quietly su rcore
gen poor_core=(tc_core<(plinePPP*r(mean)))
mean poor_core [pw=weight*hhsize], over(wave)
drop poor_core
keep if panel_w24==1
gen xw=weight if wave==4
bys state ea hh: egen w=max(xw)
quietly su rcore
gen poor_core=(tc_core<(plinePPP*r(mean)))
mean poor_core [pw=w*hhsize], over(wave)
*consumption of the various modules
use "${gsdData}/1-CleanTemp/hhq-poverty.dta" , clear
gen wave="Wave4"
drop if dataset==1
append using "${gsdW2}/Data/1-CleanTemp/hhq-poverty.dta" 
replace wave="Wave2" if wave==""
tabstat mi_cons_f? , by(wave) stat(N mean min p5 q p95 p99 max) col(stat)
*check most/least consumed items
use "${gsdData}/1-CleanOutput/food.dta" , clear
keep if dataset==2
merge m:1 dataset state ea hh using "${gsdData}/1-CleanOutput/hhq.dta", keepusing(mod_hh) keep(match master) assert(match master) nogen
tab cons if (mod_item==0 | mod_item==mod_hh) , m 
tabstat cons 
drop if missing(cons)
collapse (sum) cons , by(itemid)
gsort -cons 
list itemid cons in 1/15 ,  table
local N1=_N-14
local N2=_N
list itemid cons in `N1'/`N2', table
*check number of items consumed
use "${gsdData}/1-CleanTemp/food_analysis.dta" , clear
drop if dataset==1
collapse cons , by(wave state ea hh)
su cons if wave==2, detail
graph twoway  (hist cons, by(wave)) (scatteri 0 `r(p50)' 8 `r(p50)', c(l) m(i))
graph export "${gsdOutput}/Cleaning/food_itemshare_distribution_w2w4.pdf" , replace 
tabstat cons , c(stat) by(wave) s(N mean min p5 q p95 max)
*do it for core items
use "${gsdData}/1-CleanTemp/food_analysis.dta" , clear
drop if dataset==1
collapse cons , by(wave state ea hh mod_item)
keep if mod_item==0
quietly su cons if wave==2, detail
graph twoway  (hist cons, by(wave)) (scatteri 0 `r(p50)' 8 `r(p50)', c(l) m(i))
graph export "${gsdOutput}/Cleaning/food_core_itemshare_distribution_w2w4.pdf" , replace
tabstat cons , c(stat) by(wave) s(N mean min p5 q p95 max)
*and noncore 
use "${gsdData}/1-CleanTemp/food_analysis.dta" , clear
drop if dataset==1
collapse cons , by(wave state ea hh mod_item)
keep if inlist(mod_item,1,2,3,4)
quietly su cons if wave==2, detail
graph twoway  (hist cons, by(wave)) (scatteri 0 `r(p50)' 40 `r(p50)', c(l) m(i))
graph export "${gsdOutput}/Cleaning/food_opt_itemshare_distribution_w2w4.pdf" , replace
tabstat cons , c(stat) by(wave) s(N mean min p5 q p95 max)
*quantities per item between waves 2 and 4
use "${gsdW2}/Data\1-CleanOutput/food.dta" , clear
collapse (mean) meancons_w2=cons_q_kg meanpurc_w2=purc_q_kg (median) medcons_w2=cons_q_kg medpurc_w2=purc_q_kg (count) numhh_w2=cons , by(itemid)
tempfile wave2_quantities
label var medcons_w2 "Median quantity consumed in kg - Wave 2"
label var numhh_w2 "Number of households that consumed the product - Wave 2"
gen pchh_w2=100*(numhh_w2/1179)
label var pchh_w2 "Percent of households that consume the product - Wave 2"
save `wave2_quantities' , replace
use "${gsdData}/1-CleanOutput/food.dta" , clear
keep if dataset==2
gen cons_yes=1 if cons==1
collapse (mean) meancons=cons_q_kg meanpurc=purc_q_kg (median) medcons=cons_q_kg medpurc=purc_q_kg (count) numhh=cons_yes , by(itemid mod_item)
label var medcons "Median quantity consumed in kg"
label var numhh "Number of households that consumed the product"
gen pchh=100*(numhh/943)
label var pchh "Percent of households that consume the product"
merge 1:1 itemid using `wave2_quantities' , nogen
gen diff=medcons-medcons_w2 
label var diff "Difference in kg"
gen diff_pc = ((medcons-medcons_w2 )/medcons_w2)*100
label var diff_pc "Difference in (%)"
save "${gsdTemp}/food_consumption_quantities_check.dta", replace
gen item=itemid
keep itemid item numhh medcons_w2 medcons diff diff_pc 
order  itemid item numhh  medcons_w2 medcons diff diff_pc 
export excel "${gsdOutput}/Cleaning/consumption quantities comparison waves 2 and 4.xlsx" , first(varl) replace
*nonfood to food ratios
use "${gsdW2}/Data/1-CleanOutput/hhq.dta", clear
gen wave="Wave2"
append using "${gsdData}/1-CleanOutput/hhq.dta"
drop if dataset==1
replace wave="Wave4" if wave==""
gen nf_f=mi_cons_nf/mi_cons_f
bys wave: su nf_f , detail
quietly su nf_f if wave=="Wave2", detail
graph twoway  (hist nf_f, by(wave)) (scatteri 0 `r(p50)' 6 `r(p50)' , c(l) m(i))  if nf_f<3 
graph export "${gsdOutput}/Cleaning/nonfood_food_ratio_w2w4.pdf" , replace
*core to non core
use "${gsdData}/1-CleanTemp/hhq-poverty.dta" , clear
gen wave="Wave4"
drop if dataset==1
append using "${gsdW2}/Data/1-CleanTemp/hhq-poverty.dta" 
replace wave="Wave2" if wave==""
gen noncorecore_f=(mi_cons_f1+mi_cons_f2+mi_cons_f3+mi_cons_f4)/mi_cons_f0
bys wave: su noncorecore_f , detail
quietly su noncorecore_f if wave=="Wave2", detail
graph twoway  (hist noncorecore_f, by(wave)) (scatteri 0 `r(p50)' 6 `r(p50)' , c(l) m(i))  if noncorecore_f<3
graph export "${gsdOutput}/Cleaning/noncore_core_ratio_food_w2w4.pdf" , replace
gen noncorecore_nf=(mi_cons_nf1+mi_cons_nf2+mi_cons_nf3+mi_cons_nf4)/mi_cons_nf0
quietly su noncorecore_nf if wave=="Wave2", detail
graph twoway  (hist noncorecore_nf, by(wave)) (scatteri 0 `r(p50)' 6 `r(p50)' , c(l) m(i))  if noncorecore_nf<3
graph export "${gsdOutput}/Cleaning/noncore_core_ratio_nonfood_w2w4.pdf" , replace
*compare weights/itemshares
use "${gsdW2}/Temp/food-weights.dta", clear
rename * *_w2
rename itemid_w2 itemid
*keep only matched items (i.e. drop module 4)
merge 1:1 itemid using "${gsdTemp}/food-weights.dta" , assert(match master using) keep(match) nogen
*create food item labels
preserve 
use "${gsdData}/1-CleanOutput/food.dta", clear
drop if dataset==1
collapse mod_item, by(itemid)
tempfile items
save `items', replace
restore
merge 1:1 itemid using `items', assert(match using) keep(match) nogen 
*relabel variables
label var cons_tshare_w2 "Wave 2: share of total consumption"
label var cons_mshare_w2 "Wave 2: share of module consumption"
label var cons_tshare "Wave 3: share of total consumption"
label var cons_mshare "Wave 3: share of module consumption"
*generate differences
gen diff_t = cons_tshare - cons_tshare_w2
label var diff "Difference in item's share of total consumption"
gen diff_m = cons_mshare - cons_mshare_w2
label var diff_m "Difference in item's share of module consumption"
*export table of all items
gen item=itemid
label val itemid itemid
order itemid item mod_item cons_tshare_w2 cons_tshare diff_t cons_mshare_w2 cons_mshare diff_m 
keep itemid item mod_item cons_tshare_w2 cons_tshare diff_t 
export excel "${gsdOutput}/Cleaning/consumption_food_shares_comparison_w2w4.xlsx" , first(varl) replace
*compare prices
local ls = "food nonfood" 
foreach cat of local ls {
	use "${gsdW2}/Data/1-CleanOutput/`cat'.dta", clear
	if "`cat'"=="food" {
		rename price_ssp_per_kg_cleaned uprice
	}
	else {
		rename price uprice
	}
	*national for missing
	bysort itemid: egen uprice_med_all = median(uprice)
	merge m:1 state ea hh using "${gsdW2}/Data/1-CleanOutput/hhq.dta", nogen assert(match using) keepusing(month)
	rename month tm
	*calculate median prices
	collapse (median) uprice_med = uprice  [pweight=weight], by(tm itemid itemlabel uprice_med_all)
	replace uprice_med = uprice_med_all if missing(uprice_med)
	drop uprice_med_all	
	rename uprice_med uprice_med_w2
	keep if tm==ym(2016,2)
	drop tm
	merge 1:m itemid using "${gsdTemp}/`cat'-prices.dta" , nogen assert(match master using)  keep(match)
	keep if strata==7
	keep if tm==ym(2017,5)
	drop ref tm 
	gen diff = uprice_med - uprice_med_w2
	gen diff_pc = 100 * ((uprice_med - uprice_med_w2) / uprice_med_w2)
	label var uprice_med_w2 "Price in February 2016"
	label var uprice_med "Price in May 2017"
	label var diff "Difference"
	label var diff_pc "Difference (%)"
	order  itemid itemlabel uprice_med_w2 uprice_med diff diff_pc
	keep  itemid itemlabel uprice_med uprice_med_w2 diff diff_pc
	sort  itemid
	export excel "${gsdOutput}/Cleaning/`cat' prices comparison waves 2 and 4.xlsx" , first(varl) replace
}
*assets 
*durables to total consumption ratio
use "${gsdW1}/Data/1-CleanOutput/hhq.dta", clear
gen wave="Wave2"
append using "${gsdData}/1-CleanOutput/hhq.dta"
drop if dataset==1
replace wave="Wave4" if wave==""
gen df=mi_cons_d/tc_imp
tabstat df mi_cons_d , s(N mean min p5 q p95 p99 max) by(wave) col(stat)
hist df , by(wave)
quietly su df if wave=="Wave2", detail
graph twoway  (hist df, by(wave)) (scatteri 0 `r(p50)' 60 `r(p50)' , c(l) m(i)) if mi_cons_d!=0
graph export "${gsdOutput}/Cleaning/durables_consumption_share_w1w3.pdf" , replace



***Compare consumption across camps
use "${gsdData}/1-CleanTemp/hhq_analysis.dta", clear
keep if dataset==1
*generate a core consumption measure of poverty
gen rcore=tc_core/tc_imp
quietly su rcore
gen poor_core=(tc_core<(plinePPP*r(mean)))
mean poor_core poorPPP poor [pw=weight*hhsize], over(state)
*consumption of the various modules
use "${gsdData}/1-CleanTemp/hhq-poverty.dta" , clear
gen strata=state 
replace strata=7 if state>6
label val strata s_v
label define s_v 7 "HFS", modify
tabstat mi_cons_f mi_cons_nf mi_cons_d , by(strata) stat(N mean min p5 q p95 p99 max) col(stat)
tabstat mi_cons_f? , by(strata) stat(N mean min p5 q p95 p99 max) col(stat)
tabstat mi_cons_nf? , by(strata) stat(N mean min p5 q p95 p99 max) col(stat)
tabstat mi_cons_d , by(strata) stat(N mean min p5 q p95 p99 max) col(stat)
*check number of items consumed
use "${gsdData}/1-CleanTemp/food_analysis.dta" , clear
keep if dataset==1
collapse cons , by(state ea hh)
quietly su cons , detail
graph twoway  (hist cons, by(state)) (scatteri 0 `r(p50)' 8 `r(p50)', c(l) m(i))
graph export "${gsdOutput}/Cleaning/food_itemshare_distribution_crs.pdf" , replace 
tabstat cons , c(stat) by(state) s(N mean min p5 q p95 max)
*do it for core items
use "${gsdData}/1-CleanTemp/food_analysis.dta" , clear
keep if dataset==1
collapse cons , by( state ea hh mod_item)
keep if mod_item==0
quietly su cons , detail
graph twoway  (hist cons, by(state)) (scatteri 0 `r(p50)' 8 `r(p50)', c(l) m(i))
graph export "${gsdOutput}/Cleaning/food_core_itemshare_distribution_crs.pdf" , replace
tabstat cons , c(stat) by(state) s(N mean min p5 q p95 max)
*and noncore 
use "${gsdData}/1-CleanTemp/food_analysis.dta" , clear
keep if dataset==1
collapse cons , by(state ea hh mod_item)
keep if inlist(mod_item,1,2,3,4)
quietly su cons, detail
graph twoway  (hist cons, by(state)) (scatteri 0 `r(p50)' 40 `r(p50)', c(l) m(i))
graph export "${gsdOutput}/Cleaning/food_opt_itemshare_distribution_crs.pdf" , replace
tabstat cons , c(stat) by(state) s(N mean min p5 q p95 max)
*quantities consumed per item between camps
use "${gsdData}/1-CleanTemp/food_analysis.dta" , clear
keep if dataset==1
gen cons_yes=1 if cons==1
gen cons_q_kg_pc=cons_q_kg/hhsize
collapse (mean) meancons=cons_q_kg meanconspc=cons_q_kg_pc (median) medcons=cons_q_kg medconspc=cons_q_kg_pc (count) numhh=cons_yes (count) numhh_camp=hh, by(state itemid mod_item item_name)
label var medcons "Median quantity consumed in kg"
label var numhh "Number of households that consumed the product"
label var numhh_camp "Number of households in the camp"
gen pchh=(numhh/numhh_camp)
label var pchh "Percent of households that consume the product"
sort itemid state
keep state item_name itemid numhh pchh meancons medcons meanconspc medconspc
order  state item_name itemid numhh pchh meancons medcons meanconspc medconspc
keep meancons state itemid item_name numhh
bys itemid: egen numberhh=total(numhh)
drop numhh
reshape wide meancons , i(item_name itemid numberhh) j(state)
export excel "${gsdOutput}/Cleaning/Consumption_check_CRS.xlsx" , first(varl) sheetreplace sheet("cons quant - wide") 
*compare prices
use "${gsdData}/1-CleanOutput/food.dta" , clear
gen strata=state 
replace strata=7 if state>6
label val strata s_v
label define s_v 7 "HFS", modify
hist price_ssp_per_kg_cleaned if price_ssp_per_kg_cleaned <2000, by(strata)
graph export "${gsdOutput}/Cleaning/prices_distribution_strata.pdf" , replace
collapse (mean) price_mean=price_ssp_per_kg_cleaned (p50) price_med=price_ssp_per_kg_cleaned (sum) numhh=cons , by(strata itemid)
bys itemid: egen numberhh=total(numhh)
drop numhh price_med
reshape wide price_mean , i( itemid numberhh) j(strata)
export excel "${gsdOutput}/Cleaning/Consumption_check_CRS.xlsx" , first(varl) sheetreplace sheet("prices - wide") 
*Consumption values per item per camp
use "${gsdData}/1-CleanTemp/food_analysis.dta" , clear
keep if dataset==1
gen cons_yes=1 if cons==1
collapse (mean) meancons=cons_value_org (median) medcons=cons_value_org (count) numhh=cons_yes, by(state itemid mod_item item_name)
sort itemid state
keep meancons state itemid item_name numhh
bys itemid: egen numberhh=total(numhh)
drop numhh
reshape wide meancons , i(item_name itemid numberhh) j(state)
export excel "${gsdOutput}/Cleaning/Consumption_check_CRS.xlsx" , first(varl) sheetreplace sheet("cons value - wide") 
*calculate poverty per enumerator
use "${gsdData}/1-CleanOutput/hhq.dta", clear
keep if dataset==1
quietly su poorPPP_prob 
graph bar poorPPP_prob ,  over(enum) over(state) nofill  yline(`r(mean)')
graph export "${gsdOutput}/Cleaning/poverty_headcount_by_enum.pdf" , replace
*calculate total consumption per enumerator
use "${gsdData}/1-CleanOutput/hhq.dta", clear
keep if dataset==1 
quietly su tc_summ 
graph bar tc_summ ,  over(enum) over(state) nofill  yline(`r(mean)')
graph export "${gsdOutput}/Cleaning/total_cons_by_enum.pdf" , replace
*calculate total consumption per enumerator
use "${gsdData}/1-CleanTemp/hhq-poverty.dta", clear
merge 1:1 state ea hh using "${gsdData}/1-CleanOutput/hhq.dta", keepusing(enum)
keep if dataset==1
egen mi_cons_f_opt=rowtotal(mi_cons_f1 mi_cons_f2 mi_cons_f3 mi_cons_f4)
gen mi_cons_f_core=mi_cons_f0
quietly su mi_cons_f_opt
graph bar mi_cons_f_opt ,  over(enum) over(state) nofill  yline(`r(mean)')
quietly su mi_cons_f_core
graph bar mi_cons_f_core ,  over(enum) over(state) nofill  yline(`r(mean)')
*take a closer look at consumptuin patterns by enumerator
use "${gsdData}/1-CleanOutput/food.dta", clear
keep if dataset==1
merge m:1 state ea hh using "${gsdData}/1-CleanOutput/hhq.dta", keepusing(enum tc_imp hhsize) nogen
tabstat cons_q_kg purc_q_kg price_ssp_per_kg cons_value_org , by(enum) stat(N mean min q p95 p99 max) col(stat)  
keep if cons==1
collapse (count) cons , by(enum itemid)
reshape wide cons , i(itemid) j(enum)
export excel "${gsdOutput}/Cleaning/Consumption_check_CRS.xlsx" , first(varl) sheetreplace sheet("enumerator") 
*check other stats by camp
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 state ea hh using "${gsdData}/1-CleanOutput/hhq.dta", keepusing(weight hhsize) nogen
keep if dataset==1
mean literacy [pw=weight] , over(state)
mean hhsize [pw=weight] , over(state)
prop edu_level_g  [pw=weight] , over(state) 
mean lfparticip [pw=weight] , over(state)
mean u_rate [pw=weight] , over(state) 
*check whether interviews without GPS are less poor
use "${gsdData}/1-CleanTemp/hhq-poverty.dta", clear
merge 1:1 state ea hh using "${gsdData}\0-RawOutput/hh.dta", keepusing(enum loc_* contact_phone duration*)
keep if dataset==1
gen missing_gps=missing(loc__Latitude )
gen missing_phone=(contact_phone=="N/A")
mean poorPPP_prob [pw=weight*hhsize] , over(state missing_gps)
mean poorPPP_prob [pw=weight*hhsize] , over(state missing_phone)
*Check duration of food module
use "${gsdTemp}/hh_raw.dta", clear	
gen datetime_Db=Clock(todayD_b,"YMD#hms#")
format datetime_Db %tC
gen datetime_De=Clock(todayD_e,"YMD#hms#")
format datetime_De %tC
gen duration_D=(datetime_De-datetime_Db)/(1000*60*60)
replace duration_D=. if duration_D<0
rename (state ea) (State EA)
merge 1:1 ParentId1 using "${gsdData}/0-RawOutput/hh.dta", keepusing(state ea hh enum) nogen
replace state=camp if dataset==1
gen strata=state 
replace strata=7 if state>6
label val strata s_v
label define s_v 7 "HFS", modify
hist duration_D if duration_D<1, by(strata)
merge 1:1 state ea hh using "${gsdData}/1-CleanOutput/hhq.dta", keepusing(tc_imp poorPPP_prob poor) nogen
*check time difference between gps and module D
use "${gsdData}\0-RawOutput/hh.dta", clear
format  today* loc__Timestamp %20s
*br today* loc__Timestamp if camp==5
gen datetime_Db=Clock(todayD_b,"YMD#hms#")
format datetime_Db %tC 
gen datetime_GPS=Clock(loc__Timestamp,"YMD#hms#")
format datetime_GPS %tC
gen diff_GPS_D=(datetime_Db-datetime_GPS)/(1000*60*60)
sort state enum

graph close

