set checksum off

*check whether data has already been downloaded, only download if file is non existent
*	for updates simply set runimport=1 in the if command on line 9
capture confirm file "${gsdData}/1-CleanTemp/WB_data_raw.dta"
display _rc
if _rc==0  {
	display "File already downloaded
	local runimport=0
}
else if _rc!=0  { 
	*download international comparisons data
	local runimport=1
}
*obtain the data for each variable
if (`runimport'==1) {
	*sourcing from WB Open data to Box/DataRaw in dta file 
	wbopendata, language(en - English) country() topics() indicator(NY.GNP.PCAP.CD ; SI.POV.DDAY; SI.POV.2DAY ; SI.POV.GAPS; SI.POV.GINI; NY.GDP.PCAP.PP.KD; NY.GDP.PCAP.CD; HH.DHS.NAR.1; HH.DHS.NAR.23; SE.ADT.LITR.ZS; HH.DHS.PCR; ccx_lf_pop_tot; ccx_lf_pop_rur; ccx_lf_pop_urb; SL.AGR.EMPL.ZS; SL.IND.EMPL.ZS; SL.SRV.EMPL.ZS; SL.UEM.TOTL.NE.ZS ; SL.UEM.TOTL.ZS; SH.H2O.SAFE.ZS; SH.STA.ACSN) clear long
	save "${gsdData}/1-CleanTemp/WB_data_raw.dta", replace
}
*for each variable obtain the latest figures and year available
use "${gsdData}/1-CleanTemp/WB_data_raw.dta", clear
*rename
rename (ny_gnp_pcap_cd si_pov_dday si_pov_gaps si_pov_gini ny_gdp_pcap_pp_kd ny_gdp_pcap_cd) (gnipc poverty gap gini gdppc gdppccd)
rename (hh_dhs_nar_1 hh_dhs_nar_23 se_adt_litr_zs hh_dhs_pcr) (attendanceprimary attendancesecondary literacy15 primary)
rename (ccx_lf_pop_tot  ccx_lf_pop_rur ccx_lf_pop_urb) (lfptot lfprur lfpurb)
rename (sh_h2o_safe_zs sh_sta_acsn) (water sanitation)
rename (sl_agr_empl_zs sl_ind_empl_zs sl_srv_empl_zs sl_uem_totl_ne_zs sl_uem_totl_zs) (emplagr emplind emplser uratene urate) 
local indicators = "gnipc poverty gap gini gdppc gdppccd attendanceprimary attendancesecondary literacy15 primary lfptot lfprur lfpurb emplagr emplind emplser uratene urate water sanitation"
keep countryname countrycode year `indicators'
foreach indicator of local indicators {
	bysort countryname: egen `indicator'_y=max(year) if !missing(`indicator')
	replace `indicator'=. if year!=`indicator'_y
	replace `indicator'=. if year==`indicator'_y & year<2008
}
drop year
ds countryname countrycode, not
collapse `r(varlist)' , by(countryname countrycode)
order * , alpha
order countryname countrycode, first
save "${gsdData}/1-CleanTemp/WB_data.dta", replace
use "${gsdData}/1-CleanTemp/WB_data.dta", clear 
export excel "${gsdOutput}/Figures.xlsx", sheetreplace sheet("WB Country Data") first(variables)
local keepSSA=1
if `keepSSA'==1 {
	*integrate the final dataset and export it to excel 
	gen keep=1 if countrycode=="BEN"
	replace keep=1 if countrycode=="BFA"
	replace keep=1 if countrycode=="BEN"
	replace keep=1 if countrycode=="BWA"
	replace keep=1 if countrycode=="AGO"
	replace keep=1 if countrycode=="BDI"
	replace keep=1 if countrycode=="CAF"
	replace keep=1 if countrycode=="TCD"
	replace keep=1 if countrycode=="COM"
	replace keep=1 if countrycode=="COD"
	replace keep=1 if countrycode=="CMR"
	replace keep=1 if countrycode=="CAF"
	replace keep=1 if countrycode=="COM"
	replace keep=1 if countrycode=="DJI"
	replace keep=1 if countrycode=="GNQ"
	replace keep=1 if countrycode=="GAB"
	replace keep=1 if countrycode=="GHA"
	replace keep=1 if countrycode=="GIN"
	replace keep=1 if countrycode=="CIV"
	replace keep=1 if countrycode=="KEN"
	replace keep=1 if countrycode=="LSO"
	replace keep=1 if countrycode=="LBR"
	replace keep=1 if countrycode=="MRT"
	replace keep=1 if countrycode=="MUS"
	replace keep=1 if countrycode=="NGA"
	replace keep=1 if countrycode=="COG"
	replace keep=1 if countrycode=="STP"
	replace keep=1 if countrycode=="SDN"
	replace keep=1 if countrycode=="TGO"
	replace keep=1 if countrycode=="ZBA"
	replace keep=1 if countrycode=="ERI"
	replace keep=1 if countrycode=="CPV"
	replace keep=1 if countrycode=="ETH"
	replace keep=1 if countrycode=="GMB"
	replace keep=1 if countrycode=="GIN"
	replace keep=1 if countrycode=="GNB"
	replace keep=1 if countrycode=="LBR"
	replace keep=1 if countrycode=="MDG"
	replace keep=1 if countrycode=="MWI"
	replace keep=1 if countrycode=="MLI"
	replace keep=1 if countrycode=="MOZ"
	replace keep=1 if countrycode=="NER"
	replace keep=1 if countrycode=="RWA"
	replace keep=1 if countrycode=="SEN"
	replace keep=1 if countrycode=="SLE"
	replace keep=1 if countrycode=="SSD"
	replace keep=1 if countrycode=="TZA"
	replace keep=1 if countrycode=="TGO"
	replace keep=1 if countrycode=="UGA"
	replace keep=1 if countrycode=="ZWE"
	replace keep=1 if countrycode=="SOM"
	keep if keep==1
	drop keep
}
export excel "${gsdOutput}/Figures.xlsx", sheetreplace sheet("WB Country Data-SSA") first(variables)

