*this do file calculates the deflator for food and nonfood consumption
local lis = "food nonfood"
foreach cat of local lis {
	use "${gsdData}/1-CleanTemp/`cat'.dta", clear
	*ensure that food and non-food have the same format
	if ("`cat'"=="food") {
		ren price_ssp_per_kg_cleaned uprice
	}
	else {
		ren price_ssp_cleaned uprice
	}
	*merge sampling weights and month
	merge m:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta", assert(match using) keepusing(weight month mod_hh) keep(match master) nogen
	keep dataset state ea hh weight mod_item mod_hh itemid cons_value uprice month
	*generate a variable for strata over which to deflate, i.e. HFS and each camp separately
	gen strata=state
	replace strata=7 if state>80
	label define lstrata 1 "JubaPOC" 2 "Wau" 4 "Bor" 5 "Malakal" 6 "Bentiu" 7 "HFS"
	label val strata lstrata
	ren month tm
	tab state tm 
	*consolidate months with little data, only august 
	replace tm=ym(2017,7) if tm==ym(2017,8)
	*calculate core and optional module consumption per hh
	bys strata state ea hh mod_item: egen tcons = total(cons_value)
	label var tcons "Total consumption of module"
	*check that consumption does not change within hh & module
	bys strata state ea hh mod_item: egen check=sd(tcons)
	assert check==0
	drop check
	*add zero consumption
	reshape wide cons_value uprice, i(strata state ea hh mod_item) j(itemid)
	foreach v of varlist cons_value* {
	replace `v' = 0 if missing(`v') & inlist(mod_item,0,mod_hh)
	}	
	reshape long cons_value uprice, i(strata state ea hh mod_item) j(itemid)
	drop if missing(cons_value)
	assert inlist(mod_item,0,mod_hh)
	*calculate item shares relative to core or optional module
	gen cons_share = cons_value / tcons
	label var cons_share "Item share of module consumption"
	*check shares sum to 1
	bys state ea hh mod_item: egen check=total(cons_share)
	assert inlist(round(check,0.0001),1,0) 
	drop check
	*check shares are missing if module items are not consumed, and is not missing if module items are consumed
	assert missing(cons_share) if tcons==0
	assert !missing(cons_share) if tcons!=0
	*check whether any products do not have prices
	bys itemid: egen count=count(uprice)
	tab itemid if count==0
	*drop products with no prices
	drop if count==0
	assert !missing(count)
	assert count!=0
	drop count
	save "${gsdTemp}/`cat'-share.dta", replace

	*calculate weights: aggregate across households (using hh weights)
	use "${gsdTemp}/`cat'-share.dta", clear
	collapse (mean) cons_share tcons [pweight=weight], by(itemid mod_item)
	drop if cons_share==0
	*check that items appear only once
	duplicates tag itemid , gen(t)
	assert t==0
	drop t
	*calculate total denominator for core and all optional modules
	reshape wide tcons, i(itemid cons_share) j(mod_item)
	foreach v of varlist tcons? {
		egen t`v'= max(`v')
		assert `v'==t`v' if !missing(`v')
	}	
	egen ttcons = rowtotal(ttcons?)
	egen tcons = rowmin(tcons?)
	drop tcons? ttcons?
	*save module specific shares
	ren cons_share cons_mshare
	gen cons_tshare = cons_mshare * tcons / ttcons
	label var cons_mshare "Share of module `cat' consumption"
	label var cons_tshare "Share of total `cat' consumption"
	assert cons_mshare>=cons_tshare
	*calibrate weights to sum up to 1 
	*check whether calibration worked
	egen check = total(cons_tshare)
	assert round(check,0.001)==1
	drop check	
	ren (tcons ttcons ) (mdenom tdenom)
	label var tdenom "Total denominator"
	label var mdenom "Module-specific denominator"
	save "${gsdTemp}/`cat'-weights.dta", replace

	*prepare median and average prices:
	use "${gsdTemp}/`cat'-share.dta", clear
	*national for missing
	bysort itemid: egen uprice_med_all = median(uprice)
	*calculate median prices
	collapse (median) uprice_med = uprice  [pweight=weight], by(tm strata itemid uprice_med_all)
	replace uprice_med = uprice_med_all if missing(uprice_med)
	drop uprice_med_all
	*reference is May 2017 HFS urban prices
	local ref = "2017,5"
	gen xref = uprice_med if tm==ym(`ref') & strata==7
	*propagate to all records
	bysort itemid: egen ref = min(xref)
	drop xref
	save "${gsdTemp}/`cat'-prices.dta", replace
	
	*calculate deflator:
	use "${gsdTemp}/`cat'-prices.dta", clear
	*add consumption weights
	merge m:1 itemid using "${gsdTemp}/`cat'-weights.dta", assert(match) keep(master match) keepusing(cons_tshare) nogen
	*calculate deflator
	gen cons_defl = cons_tshare * uprice_med/ref
	collapse (sum) cons_defl, by(tm strata)
	label var cons_defl	"Laspeyres deflator for `cat' consumption"
	rename cons_defl `cat'_cons_defl
	*expand for consolidated month
	expand 2 if tm==ym(2017,7), gen(new)
	replace tm=ym(2017,8) if new==1
	drop new
	save "${gsdTemp}/`cat'-deflator.dta", replace
	export excel using "${gsdOutput}/deflator.xlsx", sheetreplace sheet("`cat'") first(varl)
	*graph deflator
	set graphics off
	xtset  strata tm
	scatter `cat'_cons_defl tm, by( strata)
	graph export "${gsdOutput}/`cat'-deflator.pdf" , as(pdf) replace
	set graphics on
}
