*this do file cleans assets data
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*Currencies: identification, labelling, and currency conversion
use "${gsdData}/1-CleanInput/assets.dta", clear
rename (G_1_own_yn G_2_owntotal G_4_ynew  G_5_prnew G_5_prnew_curr G_5_prnew_sp G_9_sellnew G_9_sellnew_curr G_9_sellnew_sp G_12_own_prev_yn G_13_owntotal_prev) (own owntotal year_purc price_purc curr_purc price_purc_curr_sp price_sell curr_sell price_sell_curr_sp own_pre owntotal_pre)
merge m:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta", assert(match using) keep(match) keepusing(month) nogen
label define lcurr 0 "N/A (price unknown)" .a "Don't Know" 1 "SSP" 2 "USD" 3 "KSH" 4 "UGX" 5 "SDD" 6 "SDG" 7 "SDP" 9 "Gift" 10 "Euros"
*Note: 	SSP = South Sudanese Pound	KSH = Kenyan Shilling
*		USD = US Dollar				UGX = Uganda Shilling
*		SDD = Sudanese Dinar		SDG = 2nd Sudanese Pound (2007 - )
*		SDP = 1st Sudanese Pound ( - 1992)
*recode price uknown as .a
*encode currencies entered manually for purchase prices
tab curr_purc
tab price_purc_curr_sp if curr_purc==1000
replace price_purc_curr_sp=trim(subinstr(price_purc_curr_sp,`"""',"",.))
replace curr_purc = 3 if strpos(price_purc_curr_sp,"Kenya shillings") | strpos(price_purc_curr_sp,"Kenyan shillings") | strpos(price_purc_curr_sp,"Ksh")
replace curr_purc = 6 if strpos(price_purc_curr_sp,"Sudanese  pounds") | strpos(price_purc_curr_sp,"Sudanese pound") | strpos(price_purc_curr_sp,"sp") | strpos(price_purc_curr_sp,"Sudanese  pound") | strpos(price_purc_curr_sp,"sd")
replace curr_purc = 5 if strpos(price_purc_curr_sp,"Sudanese Dinner") | strpos(price_purc_curr_sp,"dinars") | strpos(price_purc_curr_sp,"old Sudan dinners") | strpos(price_purc_curr_sp,"Dianmer") | strpos(price_purc_curr_sp,"Dinner") | strpos(price_purc_curr_sp,"Dinners")| strpos(price_purc_curr_sp, "Dinar Old Sudan currency.")
replace curr_purc = 4  if strpos(price_purc_curr_sp,"Uganda shillings") | strpos(price_purc_curr_sp, "Ugandan shillings") | strpos(price_purc_curr_sp,"ugx") | strpos(price_purc_curr_sp,"Uganda Shilling") | strpos(price_purc_curr_sp,"Ugandan shilling") | strpos(price_purc_curr_sp,"Ugandan shillings") | strpos(price_purc_curr_sp,"ugandan shilling")
tab price_purc_curr_sp if curr_purc==1000
*encode currencies entered manually for selling prices
tab curr_sell
tab price_sell_curr_sp if curr_sell==1000
replace price_sell_curr_sp=trim(subinstr(price_sell_curr_sp,`"""',"",.))
replace curr_sell = 3 if strpos(price_sell_curr_sp,"ksh") 
replace curr_sell = 4  if strpos(price_sell_curr_sp,"Ugandan shillings")
tab price_sell_curr_sp if curr_sell==1000
*merge with exchange rate data, because data on exchange rate between the different currencies and SSP is not available, first convert to USD then into SSP
*merge purchase currencies and convert
decode curr_purc, gen(curr)
rename year_purc year 
merge m:1 curr year using "${gsdData}/1-CleanInput/Other/exchange_rates_year.dta", assert(match master using) keep(match master) keepusing(conv2usd conv2ssp) nogen
rename (year conv2usd conv2ssp) (year_purc conv2usd_purc conv2ssp_purc)
label var conv2usd_purc "Exchange rate to USD, purchase price" 
label var conv2ssp_purc "Exchange rate USD to SSP, purchase price" 
drop curr
*merge sell currencies with monthly ER data, since inflation was very high across the survey period
decode curr_sell, gen(curr)
merge m:1 curr month using "${gsdData}/1-CleanInput/Other/exchange_rates_month_assets.dta", assert(match master using) keep(match master) keepusing(conv2usd conv2ssp) nogen
rename (conv2usd conv2ssp) (conv2usd_sell conv2ssp_sell)
drop curr 
label var conv2usd_sell "Exchange rate to USD, selling price"
label var conv2ssp_sell "Exchange rate SSP to USD, selling price" 
*convert into ssp prices, note that prices already in ssp will be effectively multiplied by one (conv2usd_* == conv2ssp_*)
local ls = "purc sell"
foreach t of local ls {
	gen long price_`t'_ssp=price_`t' * (1/conv2usd_`t') * conv2ssp_`t'
}
label var price_purc_ssp "Price of asset when purchased, in current SSP"
label var price_sell_ssp "Selling price of asset today, in current SSP"
*inspect conversion (Manual changes have already been made)
tabstat price_purc price_purc_ssp , by(curr_purc) s(N mean min p5 q p95 max) columns(statistics)
tabstat price_sell price_sell_ssp , by(curr_sell) s(N mean min p5 q p95 max) columns(statistics)
*check evolution of prices over the years
* create a new cleaner year variable for this
gen year=year_purc if year_purc>1980
table year_purc index , c(median price_purc_ssp) f(%10.0f) concise m
drop conv2* 
save "${gsdTemp}/assets_cleaning1.dta" , replace

*Identify and replace outliers - Quantities
use "${gsdTemp}/assets_cleaning1.dta" , clear
*inspect ownership statistics and prices
tabstat owntotal if own==1, by(index) stat(N mean min p5 q p95 max) columns(statistics)
tabstat owntotal_pre if own_pre==1, by(index) stat(N mean min p5 q p95 max) columns(statistics)
*Tag values that need to be cleaned
*rename for looping
rename (own owntotal) (own_now owntotal_now)
*loop over cleaning rules
local ls = "pre now"
foreach s of local ls {
	*tag as outlier quantity ownership of more than 100 of a single asset
	local outlier = 100
	gen tag_outlier_owntotal_`s' = 0 
	replace tag_outlier_owntotal_`s' = 1 if owntotal_`s'>`outlier' & !missing(owntotal_`s') & own_`s'==1
	*tag missing quantities
	gen tag_missing_q_`s' = 0 if own_`s'==1
	replace tag_missing_q_`s' = 1 if missing(owntotal_`s') & own_`s'==1 
	*tag negative or zero quantities
	gen tag_zero_q_`s' = 0 if own_`s'==1
	replace tag_zero_q_`s' = 1 if owntotal_`s'<1 & own_`s'==1 	
}
*calculate medians
local ls = "pre now"
foreach s of local ls {
	bysort index: egen owntotal_`s'_index_med = median(owntotal_`s') if own_`s'==1
	*no owntotal_now quantities for washing machine
	assert owntotal_`s'_index_med!=0 if index!=15
}
*replace quantities
local ls = "pre now"
foreach s of local ls {
	replace owntotal_`s' = owntotal_`s'_index_med if tag_outlier_owntotal_`s'==1 & own_`s'==1 
	replace owntotal_`s' = owntotal_`s'_index_med if tag_missing_q_`s'==1 & own_`s'==1 
	replace owntotal_`s' = owntotal_`s'_index_med if tag_zero_q_`s'==1 & own_`s'==1 
}
*replace washing machines price and quantity to missing, since all data is zero
replace owntotal_now=. if index==15 & own_now==1 
replace owntotal_pre=. if index==15 & own_pre==1 
rename (own_now owntotal_now) (own owntotal) 
label var owntotal "Number of asset owned today after cleaning"
label var owntotal_pre "Number of asset owned before the conflict after cleaning"
*inspect ownership statistics and prices
tabstat owntotal owntotal_pre, by(index) stat(N mean min p5 q p95 max) columns(statistics)
*checks
assert owntotal!=0 if own==1 & index!=15
assert !missing(owntotal) if own==1 & index!=15
assert owntotal_pre!=0 if own_pre==1 & index!=15
assert !missing(owntotal_pre) if own_pre==1 & index!=15
drop tag* *_med 
save "${gsdTemp}/assets_cleaning2.dta" , replace

*Identify and replace outliers - Prices
use "${gsdTemp}/assets_cleaning2.dta" , clear
*check prices
tabstat price_purc_ssp if own==1, by(index) s(N mean min p5 q p95 max) 
tabstat price_sell_ssp if own==1, by(index) s(N mean min p5 q p95 max)
*adjust hard maximum constraints for selling prices by inflation because all prices are higher
rename max_h max_h_purc
*scale constraints up by inflation, because they were created for Wave 1 prices
merge m:1 month using "${gsdData}/1-CleanInput/Other/CPI_NBS.dta", nogen assert(match using) keep(match)
gen scale_factor=CPI_nonfood/ref_CPI_nonfood_Feb2015
gen max_h_sell=max_h_purc*scale_factor*.75
*adjust minimum constraints for selling prices
gen min_h_purc=1
gen min_h_sell=50
*tag price that need to be replaced according to cleaning rules
local ls = "purc sell"
foreach t of local ls {
	*tag price outliers 
	gen tag_price_`t'_above_constraints = 0 if own==1
	replace tag_price_`t'_above_constraints = 1 if price_`t'_ssp > max_h_`t' & own==1 & !missing(price_`t'_ssp) 
	*minimum constraint was code as 0.01 for all assets in the questionnaire
	gen tag_price_`t'_below_constraints = 0 if own==1	
	replace tag_price_`t'_below_constraints = 1 if price_`t'_ssp < min_h_`t' & price_`t'_ssp!=0 & own==1 & !missing(price_`t'_ssp) 
	*tagzero prices
	gen tag_`t'_zero_price=0 if own==1	
	replace tag_`t'_zero_price = 1 if price_`t'_ssp==0 & own==1 & !missing(price_`t'_ssp) 
	*tag missing prices
	gen tag_missing_price_`t'=0 if own==1
	replace tag_missing_price_`t'=1 if missing(price_`t') & own==1
	*tag outliers at the bottom and top of the price distribution
	gen tag_outlier_`t'_price = 0 if own==1
	*generate count of prices, so we only calculate distributions for assets with more than 30 observations
	bys index: egen price_`t'_ssp_c=count(price_`t'_ssp)
	forvalues n=1/21 {
		cumul price_`t'_ssp if !missing(price_`t'_ssp) & index==`n' & price_`t'_ssp_c>=25 , gen (`t'_`n'_distribution) equal
		replace tag_outlier_`t'_price=1 if `t'_`n'_distribution>.95 & !missing(`t'_`n'_distribution) & index==`n'
		replace tag_outlier_`t'_price=1 if `t'_`n'_distribution<.05 & !missing(`t'_`n'_distribution) & index==`n'
		drop `t'_`n'_distribution
	}
	drop price_`t'_ssp_c
	*create a variable indicating replacements
	local rules = "tag_price_`t'_above_constraints  tag_price_`t'_below_constraints tag_missing_price_`t' tag_outlier_`t'_price tag_`t'_zero_price"
	gen replace_price_`t'=0
	foreach r of local rules {
		replace replace_price_`t'=1 if `r'==1
	}
}
*inspect
ds tag_*
foreach t in `r(varlist)' {
	display "`t'"
	tab `t' if own==1
}
tab replace_price_purc if own==1
tab replace_price_sell if own==1
label define ltag 0 "Not-tagged" 1 "Tagged" , replace
label val tag_* replace_* ltag 
label var replace_price_purc "Purchase price to be replaced with median"
label var replace_price_sell "Selling price to be replaced with median"
quietly tabout replace_price_purc using "${gsdOutput}/Cleaning/cleaning_rules-assets.xls" if own==1, replace c(freq col)
quietly tabout replace_price_sell using "${gsdOutput}/Cleaning/cleaning_rules-assets.xls" if own==1, append c(freq col)
local ls = "purc sell"
foreach t of local ls {
	local rules = "tag_price_`t'_above_constraints  tag_price_`t'_below_constraints tag_missing_price_`t' tag_outlier_`t'_price"
	foreach r of local rules {
		quietly tabout `r' using "${gsdOutput}/Cleaning/cleaning_rules-assets.xls" if own==1, append c(freq col)
	}
}
*calculate medians and counts at the item level and at the item-state level, add medians at the item-year level for purchase prices
local ls = "purc sell"
foreach t of local ls {
	*calculate median only for nontagged observations 
	*state
	bysort index state: egen xprice_`t'_ssp_state_med = median(price_`t'_ssp) if replace_price_`t'==0
	bysort index state: egen price_`t'_ssp_state_med = max(xprice_`t'_ssp_state_med)	
	bysort index state: egen xprice_`t'_ssp_state_c = count(price_`t'_ssp) if replace_price_`t'==0
	bysort index state: egen price_`t'_ssp_state_c = max(xprice_`t'_ssp_state_c)
	*dataset level, i.e. IDP or not
	bysort index dataset: egen xprice_`t'_ssp_urban_med = median(price_`t'_ssp) if price_`t'_ssp!=0 & replace_price_`t'==0
	bysort index dataset: egen price_`t'_ssp_urban_med = max(xprice_`t'_ssp_urban_med)
	bysort index dataset: egen xprice_`t'_ssp_urban_c = count(price_`t'_ssp) if price_`t'_ssp!=0 & replace_price_`t'==0
	bysort index dataset: egen price_`t'_ssp_urban_c = max(xprice_`t'_ssp_urban_c)
	*asset level
	bysort index: egen xprice_`t'_ssp_index_med = median(price_`t'_ssp) if price_`t'_ssp!=0 & replace_price_`t'==0
	bysort index: egen price_`t'_ssp_index_med = max(xprice_`t'_ssp_index_med)
	bysort index: egen xprice_`t'_ssp_index_c = count(price_`t'_ssp) if price_`t'_ssp!=0 & replace_price_`t'==0
	bysort index: egen price_`t'_ssp_index_c = max(xprice_`t'_ssp_index_c)
	if "`t'"=="purc" {
	*asset year level
		bysort index year_purc: egen xprice_`t'_ssp_year_med = median(price_`t'_ssp) if price_`t'_ssp!=0 & replace_price_`t'==0
		bysort index year_purc: egen price_`t'_ssp_year_med = max(xprice_`t'_ssp_year_med)
		bysort index year_purc: egen xprice_`t'_ssp_year_c = count(price_`t'_ssp) if price_`t'_ssp!=0 & replace_price_`t'==0
		bysort index year_purc: egen price_`t'_ssp_year_c = max(xprice_`t'_ssp_year_c)	
	}
	drop x*
}
*make sure prices at least at index level are not zero
assert price_purc_ssp_index_med!=0 
assert price_sell_ssp_index_med!=0 
assert !missing(price_purc_ssp_index_med) if own==1 & !inlist(index,6,15)
*we dont have any prices for trucks
assert !missing(price_sell_ssp_index_med) if own==1 & !inlist(index,15)
*replace purchase prices
gen long price_purc_ssp_cleaned=price_purc_ssp
replace price_purc_ssp_cleaned = price_purc_ssp_index_med if replace_price_purc==1 & own==1
replace price_purc_ssp_cleaned = price_purc_ssp_urban_med if replace_price_purc==1 & own==1 & price_purc_ssp_urban_c>7 & !missing(price_purc_ssp_urban_c) &!missing(price_purc_ssp_urban_med) & price_purc_ssp_urban_med!=0
replace price_purc_ssp_cleaned = price_purc_ssp_state_med if replace_price_purc==1 & own==1 & price_purc_ssp_state_c>5 & !missing(price_purc_ssp_state_c) &!missing(price_purc_ssp_state_med) & price_purc_ssp_state_med!=0
replace price_purc_ssp_cleaned = price_purc_ssp_year_med if replace_price_purc==1 & own==1 & price_purc_ssp_year_c>3 & !missing(price_purc_ssp_year_c) & !missing(price_purc_ssp_year_med) & price_purc_ssp_year_med!=0
label var price_purc_ssp_cleaned "Price of asset when purchased in current SSP after cleaning"
*replace selling prices
tab replace_price_sell
gen long price_sell_ssp_cleaned=price_sell_ssp
replace price_sell_ssp_cleaned = price_sell_ssp_index_med if replace_price_sell==1 & own==1
replace price_sell_ssp_cleaned = price_sell_ssp_urban_med if replace_price_sell==1 & own==1 & price_sell_ssp_urban_c>7 & !missing(price_sell_ssp_urban_c) &!missing(price_sell_ssp_urban_med) & price_sell_ssp_urban_med!=0
replace price_sell_ssp_cleaned = price_sell_ssp_state_med if replace_price_sell==1 & own==1 & price_sell_ssp_state_c>5 & !missing(price_sell_ssp_state_c)  &!missing(price_sell_ssp_state_med) & price_sell_ssp_state_med!=0
label var price_sell_ssp_cleaned "Selling price of {asset} today in current SSP after cleaning"
*check impact of cleaning
*check prices
tabstat price_purc_ssp_cleaned , by(index) s(N mean min p5 q p95 max) col(stat) 
tabstat price_sell_ssp_cleaned , by(index) s(N mean min p5 q p95 max) col(stat) 
*check that prices are never zero
assert price_purc_ssp_cleaned!=0
assert price_sell_ssp_cleaned!=0
*check evolution of prices over the years 
table year_purc index if year_purc>1980, c(median price_purc_ssp_cleaned) f(%10.0f) concise m
*drop redundant variables
drop tag_* *_med *_c replace_* CPI* ref_* scale_factor 
save "${gsdTemp}/assets_cleaning3.dta" , replace

*Calculate depreciation rates 
use "${gsdTemp}/assets_cleaning3.dta" , clear
*Calculate vintages. Note that as soon items are purchased, it is considered 
*one year old due to loss in value. I.e. items bought in 2016 are one year old.
tab year_purc
replace year_purc=. if year_purc<1945
gen vintage =(year-year_purc)+1
*Calculate vintage medians and replace where missing
bysort index: egen vintage_median=median(vintage)
gen tag_missing_vintage = 0 if own==1 
replace tag_missing_vintage =1 if missing(vintage) & own==1
label define ltag 0 "Not-tagged" 1 "Tagged" , replace
label val tag_missing_vintage ltag
quietly tabout tag_missing_vintage using "${gsdOutput}/Cleaning/cleaning_rules-assets.xls" if own==1, append c(freq col)
*Set missing vintages to medians
replace vintage = vintage_median if missing(vintage) & own==1
*Label variables
lab var vintage "Years since newest {asset} was purchased, after cleaning"
drop vintage_median 
*calculate depreciation rate
*Assume constant asset-specific inflation rate of pi=71.971%
*	90 percent of assets were purchased after 2010, 71.971% is the annual compound growth rate of the CPI rate between the CPI in May 2010 and May 2017
local pi = 0.71971
*Estimate formula from Deaton and Zaidi (2002)
gen drate= 1 - (1/(1+`pi'))*(price_sell_ssp_cleaned/price_purc_ssp_cleaned)^(1/vintage)
*clean depreciation rate:
tabstat drate, stat(n mean min p5 q p95 max) by(index)
*Convert drate to missing if 
* 1) calculated drate is negative:
gen tag_neg_drate=(drate<0)
label val tag_neg_drate ltag
quietly tabout tag_neg_drate using "${gsdOutput}/Cleaning/cleaning_rules-assets.xls" if own==1, append c(freq col)
replace drate=. if drate<0
* 2) calculated drate is in top of dist despite small vintages; or 
* 3) calculated drate is in bottom of dist despite large vintages:
cumul drate if !missing(drate), gen (drate_distribution) equal
label define ldum_distr 1 "Bottom 10% (0)"  2 "Top 10% (1)"
gen dum_distr=2 if drate_distribution>=.9 & !missing(drate_distribution)
replace dum_distr=1 if drate_distribution<=.1 & !missing(drate_distribution)
label var dum_distr "Observation in top/bottom of distribution"
label values dum_distr ldum_distr
*replace inconsistent cases in the top of the drate distribution
gen tag_high_drate = 0 if own==1
replace tag_high_drate = 1 if dum_distr==2 & vintage==1
tab tag_high_drate
label val tag_high_drate ltag
quietly tabout tag_high_drate using "${gsdOutput}/Cleaning/cleaning_rules-assets.xls" if own==1, append c(freq col)
*replace inconsistent cases in the bottom of the drate distribution
gen tag_low_drate= 0 if own==1
replace tag_low_drate=1 if dum_distr==1 & vintage>=3
tab tag_low_drate
label val tag_low_drate ltag
quietly tabout tag_low_drate using "${gsdOutput}/Cleaning/cleaning_rules-assets.xls" if own==1, append c(freq col)
*calculate median depreciation rates by item where >= 3 observations avail.
bysort index: egen drate_count=count(drate) 
bysort index: egen drate_median=median(drate) if drate_count>=3
*Set missing depreciation rates to median rates calculated above, check them
gen tag_missing_drate=0 if own==1
replace tag_missing_drate=1 if own==1 & missing(drate)
tab tag_missing_drate
label val tag_missing_drate ltag
quietly tabout tag_missing_drate using "${gsdOutput}/Cleaning/cleaning_rules-assets.xls" if own==1, append c(freq col)
replace drate = drate_median if missing(drate) & own==1 
replace drate = drate_median if (tag_high_drate==1 | tag_low_drate==1) & own==1
lab var drate "Depreciation rate for each durable item by household, after cleaning"
lab var drate_median "Median depreciation rate for each durable item"
* Summarise the median depreciation rates in a table 
tabstat drate, stat(n mean min p5 q p95 max) by(index)
*drop variables needed for cleaning
drop tag_* drate_count dum_distr drate_distribution 
*****NOTE:the depreciation rates are fairly different from wave 1 depreciation rates
* The really high inflation during the last few years of the period covered also makes it very difficult to estimate
* accurate depreciation rates based on the theoretical setup chosen. However, because the rate at which an asset
* depreciates is independent of inflation, we will use the depreciation rates calculated using wave 1 data.
merge m:1 index using "${gsdData}/1-CleanInput/Other/drate_w1.dta" , assert(match master) nogen keepusing(depreciationrate)
rename depreciationrate drate_median_w1
lab var drate_median_w1 "Median depreciation rate for each durable item calculated from Wave 1 data"
*compare wave 1 and 2 depreciation rates
table index, c(median drate_median median drate_median_w1) format (%10.2f)
*generate variable with wave 3 depreciation rates supplement with wave 1 data where missing 
gen drate_median_w4w1=drate_median
replace drate_median_w4w1=drate_median_w1 if missing(drate_median_w4w1)
*replace depreciation rate for some assets (differences are minor)
*replace drate_median_w4w1=drate_median_w1 if inlist(index,21,16,9,7,5)
table index, c(median drate_median_w4w1 median drate_median_w1 median drate_median) format (%10.2f)
drop drate_median_w4w1
save "${gsdTemp}/assets_cleaning4.dta" , replace 

*Calculate consumption flow 
use "${gsdTemp}/assets_cleaning4.dta" , clear
*We assume a real interest rate of 5%, based on nominal interest rate of i=pi+5%
*Assume constant asset-specific inflation rate of pi=71.97%
*	90 percent of assets were purchased after 2010, 71.97% is the annual compound growth rate of the CPI rate between the CPI in 2010 and 2017
local pi = 0.71971
local r = .05
*define which depreciation rate to use
local drate=drate_median_w1
*Calculate user cost (consumption flows) per item & vintage using depreciation rates from either waves
gen cons_flow = (price_sell_ssp_cleaned/(1-`drate'+`pi'))*(`r' + `drate')
label var cons_flow "Consumption flow from ownership of single asset, yearly"
tabstat cons_flow , s(N mean min p5 q p95 max) col(stat) by(index) format(%9.3f)
*generate consumption flow to check (per day in USD)
gen check_flow=cons_flow/356/120
tabstat check_flow , s(N mean min p5 q p95 max) col(stat) by(index) format(%9.3g)
drop check_flow
*Calculate median consumption flow per item & vintage
bysort index vintage: egen cons_flow_median = median(cons_flow)
lab var cons_flow_median "Median consumption flow"
*Now we estimate the final consumption flow of durable goods, taking into account
*ownership of more than one item
gen cons_d_yearly = (price_sell_ssp_cleaned/(1-`drate'+`pi'))*(`r' + `drate') if owntotal==1 & own==1
replace cons_d_yearly = (price_sell_ssp_cleaned/(1-`drate'+`pi'))*(`r' + `drate') + ((owntotal-1)*cons_flow_median) if owntotal>=2 & own==1
label var cons_d_yearly "Consumption flow of durables (yearly) SSP" 
*inspect
tabstat cons_d_yearly , s(N mean min p5 q p95 max) col(stat) by(index)
tabstat cons_d_yearly , s(N mean min p5 q p95 max) col(stat)
*Calculate weekly and daily consumption flow 
*Convert from annual to weekly
gen cons_d_weekly=cons_d_yearly/365.25*7
label var cons_d_weekly "Consumption flow of durables (weekly) SSP" 
gen cons_d_daily=cons_d_yearly/365.25
label var cons_d_daily "Consumption flow of durables (daily) SSP" 
*Calculate per capita consumption flow
merge m:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta", keepusing(hhsize) assert(match) keep(match) nogen
gen cons_d_daily_pc=cons_d_daily/hhsize
label var cons_d_daily_pc "Consumption flow of durables (daily) per capita SSP" 
drop hhsize month year 

*Clean up and save
rename (own owntotal year_purc price_purc curr_purc price_purc_curr_sp price_sell curr_sell price_sell_curr_sp own_pre owntotal_pre) (G_1_own_yn G_2_owntotal G_4_ynew  G_5_prnew G_5_prnew_curr G_5_prnew_sp G_9_sellnew G_9_sellnew_curr G_9_sellnew_sp G_12_own_prev_yn G_13_owntotal_prev) 
*reorder
order price_purc_* , after(G_5_prnew)
order price_sell_* , after(G_9_sellnew)
order vintage drate* , after(G_4_ynew)
order cons_* , before(G_10_sellall)
*replace consumption flow as zero for households where food core cons was == 0 or . 
merge m:1 state ea hh using  "${gsdData}/1-CleanTemp/hh_food.dta", keepusing(food_opt0_hh_wk) assert(match master using) keep(match) nogen
ds cons_flow cons_d_*
foreach v in `r(varlist)' {
	replace `v'=0 if (food_opt0_hh_wk == 0 | missing(food_opt0_hh_wk))
}
drop food_opt0_hh_wk 
save "${gsdData}/1-CleanOutput/assets.dta", replace
*and calculate aggregates
use "${gsdData}/1-CleanOutput/assets.dta" , clear
collapse (sum) assets_hh_wk = cons_d_weekly, by(state ea hh)
label var assets_hh_wk  "Household weekly consumption flow of durable items"
save "${gsdData}/1-CleanTemp/hh_assets.dta", replace
*create dataset in wide format with asset ownership
use "${gsdData}/1-CleanOutput/assets.dta" , clear
rename G_2_owntotal owntotal
keep state ea hh index owntotal
reshape wide owntotal , j(index) i( state ea hh)
label var owntotal1 "Num. cars owned"
label var owntotal2 "Num. trucks owned"
label var owntotal3 "Num. Motorcycle owned"
label var owntotal4 "Num. Rickshaw owned"
label var owntotal5 "Num. Bicycle owned"
label var owntotal6 "Num. Canoe or boat owned"
label var owntotal7 "Num. Plough owned"
label var owntotal8 "Num. Television owned"
label var owntotal9 "Num. Satellite dish owned"
label var owntotal10 "Num. DVD or CD player owned"
label var owntotal11 "Num. Radio or transistor owned"
label var owntotal12 "Num. Mobile phone owned"
label var owntotal13 "Num. Computer or laptop owned"
label var owntotal14 "Num. Refrigerator owned"
label var owntotal16 "Num. Fan owned"
label var owntotal17 "Num. Air cooler or air conditioner owned"
label var owntotal18 "Num. Mattress or bed owned"
label var owntotal19 "Num. Mosquito net owned"
label var owntotal20 "Num. Electric ironer owned"
label var owntotal21 "Num. Hoe, spade or axe owned"
save "${gsdData}/1-CleanTemp/assets_wide.dta", replace

* Create tables to report the impact of cleaning
use "${gsdData}/1-CleanOutput/assets.dta" , clear
merge m:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta" , assert(match using) keep(match) keepusing(hhsize) nogen
gen cons = cons_d_weekly/hhsize 
replace cons=. if cons_d_weekly==0
label var price_purc_ssp_cleaned "Purchase price clean"
label var price_sell_ssp_cleaned "Selling price clean"
label var cons "HH weekly consflow pc"
gen cons_usd = cons/120 
label var cons_usd "weekly consflow pc USD"
label var cons_d_weekly "HH weekly consflow"
save "${gsdData}/1-CleanTemp/assets_checking_tables.dta", replace
local va  "price_purc_ssp_cleaned price_sell_ssp_cleaned cons_d_weekly cons cons_usd" 
*Overall
foreach v of local va {
	use  "${gsdData}/1-CleanTemp/assets_checking_tables.dta" , clear
	local name : variable label `v'
	collapse (count) N = `v' (mean) mean = `v' (min) min = `v' (p1) p1 = `v' (p5) p5 = `v' (p25) p25 = `v' (p50) median = `v' (p75) p75 = `v' (p95) p95 = `v' (max) max = `v' , by(index)
	gsort -N 
	export excel using "${gsdOutput}/Cleaning/Check assets cleaning.xlsx", first(var) sheet("Overall `name'") sheetreplace 
}
