*This do-file cleans the Household questionnaire and prepares variables for the analysis
clear all 
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
use "${gsdData}/1-CleanInput/hhq.dta", clear
numlabel, add

*Check what % of Hunger variable is "Other" and clean if it's more than 5%
tab C_68_hunger_coping
*Remove outliers from no-of-rooms variables
*Identify outliers
tabstat C_2_rooms_n C_3_slrooms_n C_31_rooms_n_disp C_32_slrooms_n_disp , stat(n min q p95 p99 max) column(stat) long
*Replace outliers
foreach var of varlist C_2_rooms_n C_3_slrooms_n C_31_rooms_n_disp C_32_slrooms_n_disp {
	assert `var' != .o
	replace `var' = .o if `var' > 10 & !missing(`var')
	sum `var', d
	replace `var' = `r(p50)' if `var' == .o
}
*Check impact of cleaning
tabstat C_2_rooms_n C_3_slrooms_n C_31_rooms_n_disp C_32_slrooms_n_disp , stat(n min q p95 p99 max) column(stat) long
*Generate HH room density
gen hhdensity = C_2_rooms_n / hhsize
recode hhdensity (0/0.25 = 1 "More than 4 Individuals Per Room") (0.25/0.5 = 2 "2 - 4 Individuals Per Room") (0.5/1 = 3 "1 - 2 Individuals Per Room") (1/6 = 4 "Less than 1 Individual Per Room"), generate(memperroom)
label var hhdensity "Household Members Per Room"
label var memperroom "Household Members Per Room (Categorized)"
*Generate HH sleeping room density
replace C_3_slrooms_n=1 if C_2_rooms_n==1
gen hhdensity_sl = C_3_slrooms_n / hhsize
recode hhdensity_sl (0/0.25 = 1 "More than 4 Individuals Per Bedroom") (0.25/0.5 = 2 "2 - 4 Individuals Per Bedroom") (0.5/1 = 3 "1 - 2 Individuals Per Bedroom") (1/6 = 4 "Less than 1 Individual Per Bedroom"), generate(memperroom_sl)
label var hhdensity_sl "Household Members Per Sleeping Room"
label var memperroom_sl "Household Members Per Sleeping Room (Categorized)"
*Generate water access variables
replace C_10_water_home_ot=trim(subinstr(C_10_water_home_ot,`"""',"",.))
tab C_10_water_home_ot
replace C_10_water_home=4 if strpos(C_10_water_home_ot,"Borehole.")   | strpos(C_10_water_home_ot,"borehole") | strpos(C_10_water_home_ot,"bore hole") | strpos(C_10_water_home_ot,"borehole hole") 
replace C_10_water_home=3 if strpos(C_10_water_home_ot,"Tap") | strpos(C_10_water_home_ot,"Hand pump")  | strpos(C_10_water_home_ot,"Hand pump.") | strpos(C_10_water_home_ot,"Handpuomp") | strpos(C_10_water_home_ot,"handpuomp") |strpos(C_10_water_home_ot,"hand pump") | strpos(C_10_water_home_ot,"hand pump.") | strpos(C_10_water_home_ot,"tap water")  | strpos(C_10_water_home_ot,"tap")
replace C_10_water_home=11 if strpos(C_10_water_home_ot,"water sell by donkey man") | strpos(C_10_water_home_ot,"water bring by donkey") | strpos(C_10_water_home_ot,"we are buying from boys selling using donkey") | strpos(C_10_water_home_ot,"donkey water") | strpos(C_10_water_home_ot,"we buying from boys selling water using donkey")
replace C_10_water_home=13 if strpos(C_10_water_home_ot,"direct  from  river") | strpos(C_10_water_home_ot,"bushes")  | strpos(C_10_water_home_ot,"running  water from the stream.") |  strpos(C_10_water_home_ot,"Surface  water  treatment  facility.")
tab C_10_water_home_ot if C_10_water_home==1000
recode C_10_water_home (2/9 13 = 1 "Open Water") (1 = 2 "Filtered Water") (10/12 = 3 "Purchased Water") (1 2 = 4 "Water piped into dwelling") (1000=. ) , generate(watersource)
gen watertime_min=C_11_twater_m+(60*C_11_twater_h) +(1440*C_11_twater_d)
replace watertime_min=0 if C_10_water_home==1
*Tabulate watertime quintiles
tabstat watertime_min, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 1000 minutes)
assert watertime_min != .o
replace watertime_min = .o if watertime_min > 400 & !missing(watertime_min)
sum watertime_min, d
replace watertime_min = `r(p50)' if watertime_min == .o
*Check effect of outlier removal
tabstat watertime_min, stat(n min q p95 p99 max) column(stat) long
*Create watertime categories
recode watertime_min (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), generate(watertime)
label var watersource  "C.10 Drinking water source"
label define watersource .a "Don't know" .c "Refused to respond" , modify
label val watersource watersource
label var watertime "C.11 Time Spent on Getting Drinking Water, categorized"
label var watertime_min "C.11 Time Spent on Getting Drinking Water, in minutes"
tab watersource, m
*Generate cooking variable; questionnaire bug meant that the question to specify was not asked if respondents selected other hence recode as missing
tab C_19_cook, m
recode C_19_cook (0 = 1 "No cooking") (6 = 2 "Grass") (1 = 3 "Firewood") (2 = 4 "Charcoal") (5 17 = 5 "Gas") (4 = 6 "Electricity") (7 10 11 14 15 = 7 "Biogas") (nonmissing=1000 "Other"), generate(cooking)
label define cooking .a "Don't know" .c "Refused to respond" , modify
label val cooking cooking
label var cooking "C.19 Source of energy for cooking"
tab cooking, m
*Generate sanitation access variable
tab C_20_toilet, m
replace C_20_toilet_ot=trim(subinstr(C_20_toilet_ot,`"""',"",.))
tab C_20_toilet_ot
replace C_20_toilet=12 if strpos(C_20_toilet_ot,"Busch") | strpos(C_20_toilet_ot,"Bush") | strpos(C_20_toilet_ot,"Bush  or elsewhere") | strpos(C_20_toilet_ot,"Near by bush") | strpos(C_20_toilet_ot,"Nearby Bush") | strpos(C_20_toilet_ot,"Somewhere else or bush") | strpos(C_20_toilet_ot,"Somewhere or Busch") | strpos(C_20_toilet_ot,"any nearby bush")
replace C_20_toilet=12 if strpos(C_20_toilet_ot,"any where else") | strpos(C_20_toilet_ot,"anywhere within Vicinity") | strpos(C_20_toilet_ot,"bush") | strpos(C_20_toilet_ot,"bushes") | strpos(C_20_toilet_ot,"goes to bush") | strpos(C_20_toilet_ot,"nearby Bush or any hidden ground") | strpos(C_20_toilet_ot,"nearby bush elsewhere")
replace C_20_toilet=12 if strpos(C_20_toilet_ot,"no facilities available.") | strpos(C_20_toilet_ot,"no facility available in the household.") | strpos(C_20_toilet_ot,"no toilet") | strpos(C_20_toilet_ot,"somewhere or Busch") |  strpos(C_20_toilet_ot,"Going to the neighbours  latrine.")
replace C_20_toilet=12 if strpos(C_20_toilet_ot,"they do not have toilet in the house but they are sharing with neighbours") | strpos(C_20_toilet_ot,"there is no latrine facility available in the house.") | strpos(C_20_toilet_ot,"there is no latrine facility available in the household.") | strpos(C_20_toilet_ot,"no latrine facility available in the household.") | strpos(C_20_toilet_ot,"there is no latrine facility available.") | strpos(C_20_toilet_ot,"no facilities available in the household.") | strpos(C_20_toilet_ot,"there is no latrine facility at all here.")
replace C_20_toilet=5 if strpos(C_20_toilet_ot,"share with neigber") |  strpos(C_20_toilet_ot,"the share with other people") |  strpos(C_20_toilet_ot,"use neighbour's toilet.") |  strpos(C_20_toilet_ot,"well constructed toilet")
tab C_20_toilet_ot if C_20_toilet==1000
recode C_20_toilet (12 = 1 "Bush") (10 11 = 2 "Portable Recepticle") (6/8 9 = 3 "Pit Latrine") (1/5 = 4 "Flush") (nonmissing=1000 "Other"), generate(sanitation)
label var sanitation "C.20 Toilet Type"
label define sanitation .a "Don't know" .c "Refused to respond" , modify
label val sanitation sanitation
tab sanitation, m
*Generate lighting access variable
tab C_15_light, m
recode C_15_light (15 = 1 "No Lighting") (12 11  = 2 "Grass / Firewood") (13 8 7 9 10  = 3 "Lamp / Candle / Torch") (6 2 3 = 5 "Electricity") (14 5 4  = 6 "Solar Power / Biogas")  , generate(lighting)
label var lighting "C.15 Source of Lighting"
label define lighting .a "Don't know" .c "Refused to respond" , modify
label val lighting lighting
tab lighting, m
*Generate duration to market variable
*Combine day, hour, minute variables and get all in terms of minutes
gen dist_mkt = C_11_tmarket_d*1440 + C_11_tmarket_h*60 + C_11_tmarket_m
*Remove outliers (more than 5000 minutes)
tabstat dist_mkt, stat(n min q p95 p99 max) column(stat) long
assert dist_mkt!=.o 	
replace dist_mkt = .o if dist_mkt > 400 & !missing(dist_mkt)
sum dist_mkt, d
replace dist_mkt = `r(p50)' if dist_mkt == .o
tabstat dist_mkt, stat(n min q p95 p99 max) column(stat) long
*Categorize variable
recode dist_mkt (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), gen(dist_mkt_cat)
label var dist_mkt "C.11 Distance to nearest Market in Minutes"
label var dist_mkt_cat "C.11 Distance to nearest Market in Minutes (Categorized)"
*Generate duration to primary school variable
*Combine day, hour, minute variables and get all in terms of minutes
gen dist_school = C_11_tedu_d*1440 + C_11_tedu_h*60 + C_11_tedu_m
tabstat dist_school, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 5000 minutes)
assert dist_school != .o
replace dist_school = .o if dist_school > 400 & !missing(dist_school)
sum dist_school, d
replace dist_school = `r(p50)' if dist_school == .o
tabstat dist_school, stat(n min q p95 p99 max) column(stat) long
*Categorize variable
recode dist_school (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), gen(dist_school_cat)
label var dist_school "C.11 Distance to nearest Primary School in Minutes"
label var dist_school_cat "C.11 Distance to nearest Primary School in Minutes (Categorized)"
*Generate duration to health center variable
*Combine day, hour, minute variables and get all in terms of minutes
gen dist_health = C_11_thealth_d*1440 + C_11_thealth_h*60 + C_11_thealth_m
tabstat dist_health, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 5000 minutes)
assert dist_health != .o
replace dist_health = .o if dist_health > 400 & !missing(dist_health)
replace dist_health=.o if dist_health<0
sum dist_health, d
replace dist_health = `r(p50)' if dist_health == .o
tabstat dist_health, stat(n min q p95 p99 max) column(stat) long
*Categorize variable
recode dist_health (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), gen(dist_health_cat)
label var dist_health "C.11 Distance to nearest Health Center in Minutes"
label var dist_health_cat "C.11 Distance to nearest Health Center in Minutes (Categorized)"
*Generate "corruption" variables
*Generate variable indicating reason for not going to the police in the event of a dispute
tab H_62_dispute_resolve_police
recode H_62_dispute_resolve_police (1 3 = 1 "Expensive or create more problems") (2 4 = 2 "Unreliable or unhelpful") (5 6 = 3 "Untrustworthy or corrupt") (7 = 4 "No police station nearby"), generate(nopolice_g)
label var nopolice_g "H.62 Reason for not going to the police when a dispute occurs"
*Generate variable indicating biggest fear for South Sudan
tab H_40_fear_future
recode H_40_fear_future (1 3 4 6 = 1 "Civil war, disintegration, insecurity, & ethnic violence") (5 = 2 "Corruption") (7 9 21 22 23 = 3 "Lack of economic opportunities") (8 = 4 "Health and disease problems") (99 = 5 "Other reasons"), generate(fear_g)
label var fear_g "H.40 Biggest fear, future of South Sudan"
*Generate agricultural land unit in square meters
gen land = . 
replace land = C_51_land_access if C_52_land_unit == 3
*1 feddan = 4200 square meters
replace land = C_51_land_access * 4200 if C_52_land_unit == 1
*1 kirat = 175 square meters
replace land = C_51_land_access * 175 if C_52_land_unit == 2
*1 hectare = 10000 square meters
replace land = C_51_land_access * 10000 if C_52_land_unit == 4
*1 acre = 4047 square meters
replace land = C_51_land_access * 4047 if C_52_land_unit == 5
*convert to acres
replace land = land / 4047 if !missing(land)
label variable land "Agricultural Land accessible to Household (Acres)"
*Tabulate land quintiles
tabstat land, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 20 acres)
assert land != .o
replace land = .o if land > 20  & !missing(land)
sum land, d
replace land = `r(p50)' if land == .o
*Check effect of outlier removal
tabstat land, stat(n min q p95 p99 max) column(stat) long

*Calculate reduced CSI Score (as per CSI Manual)
gen csi = C_70_cop_lessprefrerred *1 + C_71_cop_borrow_food*2 + C_72_cop_limitportion*1 + C_73_cop_limitadult*3 + C_74_cop_reducemeals*1
lab var csi "Reduced Coping Strategies Index (CSI) Score"
*Categorizing the CSI score
gen csi_cat=.
replace csi_cat=1 if csi<=3
replace csi_cat=2 if csi>3 & csi<=9 
replace csi_cat=3 if csi>=10 & !missing(csi)
assert csi_cat==. if csi==.
label define lcsicategories 1 "No or low" 2 "Medium" 3 "High"
label val csi_cat lcsicategories
label variable csi_cat "Reduced Coping Strategy Index (CSI) Score: Categorized"
*Reverse the scale of CSI score for intuitive graphing
sum csi
gen csi_invert = `r(max)' - csi
lab var csi_invert "Inverted CSI score"
*Categorize water into improved and unimproved sources as per WASH Manual
gen waterimproved =  .
replace waterimproved = 0 if inlist(C_10_water_home, 6,8,11,12,13)
replace waterimproved = 1 if inlist(C_10_water_home,1,2,3,4,5,7,9)
label variable waterimproved "Water source: Categorized (as per WASH Indicator manual)"
label define lwatersourcecat 0 "Unimproved" 1 "Improved" 
label values waterimproved lwatersourcecat
*Get water facility variable
gen waterfacility = C_10_water_home
lab var waterfacility "Source of water"
lab val waterfacility water_home
tab waterfacility

*Categorize toilet into improved and unimproved sources as per WASH Manual 
gen sanitationimproved = . 
replace sanitationimproved = 0 if inlist(C_20_toilet, 4,8,10,11,12)
replace sanitationimproved = 1 if inlist(C_20_toilet, 1,2,3,5,6,7,9)
label variable sanitationimproved "Sanitation facility: Categorized (as per WASH Indicator manual)"
label values sanitationimproved lwatersourcecat

*Generating pre-displacement characteristics variables for IDPs
*Generate IDP variable in HFS (non CRS) dataset
gen idp = A_5_migr_idp
label define idp 0 "Residential" 1 "IDP"
label values idp idp
label var idp "Household has been internally displaced (not just due to Dec 2013 conflict)"
*Correct the coding of C_35 to y
replace C_35 = 0 if C_35 == 4
lab var C_35 lyn
*Categorize water into improved and unimproved sources as per WASH Manual
gen waterimproved_disp =  .
replace waterimproved_disp = 0 if inlist(C_42_water_home_disp, 6,8,11,12,13)
replace waterimproved_disp = 1 if inlist(C_42_water_home_disp,1,2,3,4,5,7,9)
label variable waterimproved_disp "Water source before displacement: Categorized (as per WASH Indicator manual)"
label values waterimproved_disp lwatersourcecat
*Categorize toilet into improved and unimproved sources as per WASH Manual 
gen sanitationimproved_disp = . 
replace sanitationimproved_disp = 0 if inlist(C_49_toilet_disp, 4,8,10,11,12)
replace sanitationimproved_disp = 1 if inlist(C_49_toilet_disp, 1,2,3,5,6,7,9)
label variable sanitationimproved_disp "Sanitation facility before displacement: Categorized (as per WASH Indicator manual)"
label values sanitationimproved_disp lwatersourcecat
*Generate water access variables before displacement
replace C_42_water_home_ot_disp =trim(subinstr(C_42_water_home_ot_disp,`"""',"",.))
tab C_42_water_home_ot_disp
replace C_42_water_home_disp=4 if strpos(C_42_water_home_ot_disp,"Borehole.")   | strpos(C_42_water_home_ot_disp,"borehole") | strpos(C_42_water_home_ot_disp,"bore hole") | strpos(C_42_water_home_ot_disp,"borehole hole") 
replace C_42_water_home_disp=3 if strpos(C_42_water_home_ot_disp,"Tap") | strpos(C_42_water_home_ot_disp,"Hand pump")  | strpos(C_42_water_home_ot_disp,"Hand pump.") | strpos(C_42_water_home_ot_disp,"Handpuomp") | strpos(C_42_water_home_ot_disp,"handpuomp") |strpos(C_42_water_home_ot_disp,"hand pump") | strpos(C_42_water_home_ot_disp,"hand pump.") | strpos(C_42_water_home_ot_disp,"tap water")  | strpos(C_42_water_home_ot_disp,"tap")
replace C_42_water_home_disp=11 if strpos(C_42_water_home_ot_disp,"water sell by donkey man") | strpos(C_42_water_home_ot_disp,"water bring by donkey") | strpos(C_42_water_home_ot_disp,"we are buying from boys selling using donkey") | strpos(C_42_water_home_ot_disp,"donkey water") | strpos(C_42_water_home_ot_disp,"we buying from boys selling water using donkey")
replace C_42_water_home_disp=13 if strpos(C_42_water_home_ot_disp,"direct  from  river") | strpos(C_42_water_home_ot_disp,"bushes")  | strpos(C_42_water_home_ot_disp,"running  water from the stream.") |  strpos(C_42_water_home_ot_disp,"Surface  water  treatment  facility.")
tab C_42_water_home_ot_disp if C_42_water_home_disp==1000
recode C_42_water_home_disp (2/9 13 = 1 "Open Water") (1 = 2 "Filtered Water") (10/12 = 3 "Purchased Water") (1 2 = 4 "Water piped into dwelling") (1000=. ) , generate(watersource_disp)
label var watersource_disp  "C.42 Drinking water source Pre-Displacement"
label define watersource_disp .a "Don't know" .c "Refused to respond" , modify
label val watersource_disp watersource_disp
tab watersource, m
gen watertime_min_disp= C_44_twater_m_disp+(60*C_44_twater_h_disp) +(1440*C_44_twater_d_disp)
replace watertime_min_disp =0 if C_42_water_home_disp ==1
*Tabulate watertime quintiles
tabstat watertime_min_disp, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 5000 minutes)
assert watertime_min_disp != .o
replace watertime_min_disp = .o if watertime_min_disp > 5000  & !missing(watertime_min_disp)
sum watertime_min_disp, d
replace watertime_min_disp = `r(p50)' if watertime_min_disp == .o
*Check effect of outlier removal
tabstat watertime_min_disp, stat(n min q p95 p99 max) column(stat) long
*Create watertime categories
recode watertime_min_disp (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), generate(watertime_disp)
label var watertime_disp "C.44 Time Spent on Getting Drinking Water Pre-Displacement, categorized"
label var watertime_min_disp "C.44 Time Spent on Getting Drinking Water, in minutes Pre-Displacement"
*Generate sanitation access variable
tab C_49_toilet_disp, m
*No option to specify other for the above variable in questionnaire, thus recoding 'other' to missing
replace C_49_toilet_disp = . if C_49_toilet_disp ==1000
recode C_49_toilet_disp (12 = 1 "Bush") (10 11 = 2 "Portable Recepticle") (6/8 9 = 3 "Pit Latrine") (1/5 = 4 "Flush") (nonmissing=1000 "Other"), generate(sanitation_disp)
label var sanitation_disp "C.49 Toilet Type Pre-Displacement"
label define sanitation_disp .a "Don't know" .c "Refused to respond" , modify
label val sanitation_disp sanitation_disp
tab sanitation_disp, m
*Generate lighting access variable
tab C_48_light_disp, m
recode C_48_light_disp (15 = 1 "No Lighting") (12 11  = 2 "Grass / Firewood") (13 8 7 9 10  = 3 "Lamp / Candle / Torch") (6 2 3 = 5 "Electricity") (14 5 4  = 6 "Solar Power / Biogas")  , generate(lighting_disp)
label var lighting_disp "C.48 Source of Lighting Pre-Displacement"
label define lighting_disp .a "Don't know" .c "Refused to respond" , modify
label val lighting_disp lighting_disp
tab lighting_disp, m
*Generate duration to market variable
*Combine day, hour, minute variables and get all in terms of minutes
gen dist_mkt_disp = C_45_tmarket_d_disp*1440 + C_45_tmarket_h_disp*60 + C_45_tmarket_m_disp
*Tabulate quintiles
tabstat dist_mkt_disp, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 5000 minutes)
assert dist_mkt_disp != .o
replace dist_mkt_disp = .o if dist_mkt_disp > 400 & !missing(dist_mkt_disp)
sum dist_mkt_disp, d
replace dist_mkt_disp = `r(p50)' if dist_mkt_disp == .o
*Check effect of outlier removal
tabstat dist_mkt_disp, stat(n min q p95 p99 max) column(stat) long
*Categorize variable
recode dist_mkt_disp (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), gen(dist_mkt_cat_disp)
label var dist_mkt_disp "C.45 Distance to nearest Market in Minutes Pre-Displacement"
label var dist_mkt_cat_disp "C.45 Distance to nearest Market in Minutes (Categorized) Pre-Displacement"
*Generate duration to primary school variable
*Combine day, hour, minute variables and get all in terms of minutes
gen dist_school_disp = C_46_tedu_d_disp*1440 + C_46_tedu_h_disp*60 + C_46_tedu_m_disp
*Tabulate quintiles
tabstat dist_school_disp, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 5000 minutes)
assert dist_school_disp != .o
replace dist_school_disp = .o if dist_school_disp > 400 &!missing(dist_school_disp)
sum dist_school_disp, d
replace dist_school_disp = `r(p50)' if dist_school_disp == .o
*Check effect of outlier removal
tabstat dist_school_disp, stat(n min q p95 p99 max) column(stat) long
*Categorize variable
recode dist_school_disp (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), gen(dist_school_cat_disp)
label var dist_school_disp "C.46 Distance to nearest Primary School in Minutes Pre Displacement"
label var dist_school_cat_disp "C.46 Distance to nearest Primary School in Minutes (Categorized) Pre Displacement"
*Generate duration to health center variable
*Combine day, hour, minute variables and get all in terms of minutes
gen dist_health_disp = C_47_thealth_d_disp*1440 + C_47_thealth_h_disp*60 + C_47_thealth_m_disp
*Tabulate quintiles
tabstat dist_health_disp, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 5000 minutes)
assert dist_health_disp != .o
replace dist_health_disp = .o if dist_health_disp > 400 & !missing(dist_health_disp)
sum dist_health_disp, d
replace dist_health_disp = `r(p50)' if dist_health_disp == .o
*Check effect of outlier removal
tabstat dist_health_disp, stat(n min q p95 p99 max) column(stat) long
*Categorize variable
recode dist_health_disp (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), gen(dist_health_cat_disp)
label var dist_health_disp "C.47 Distance to nearest Health Center in Minutes Pre Displacement"
label var dist_health_cat_disp "C.47 Distance to nearest Health Center in Minutes (Categorized) Pre Displacement"
*Generate agricultural land unit in square meters
gen land_disp = . 
replace land_disp = C_59_land_access_disp if C_60_land_unit_disp == 3
*1 feddan = 4200 square meters
replace land_disp = C_59_land_access_disp * 4200 if C_60_land_unit_disp == 1
*1 kirat = 175 square meters
replace land_disp = C_59_land_access_disp * 175 if C_60_land_unit_disp == 2
*1 hectare = 10000 square meters
replace land_disp = C_59_land_access_disp * 10000 if C_60_land_unit_disp == 4
*1 acre = 4047 square meters
replace land_disp = C_59_land_access_disp * 4047 if C_60_land_unit_disp == 5
*convert to acres
replace land_disp = land_disp / 4047 if !missing(land_disp)
label variable land_disp "Agricultural Land accessible to Household (Acres) Pre Displacement"
*Tabulate land quintiles
tabstat land_disp, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 50 acres)
assert land_disp != .o
replace land_disp = .o if land_disp > 20  & !missing(land_disp)
sum land_disp, d
replace land_disp = `r(p50)' if land_disp == .o
*Check effect of outlier removal
tabstat land_disp, stat(n min q p95 p99 max) column(stat) long
*Checking outliers in Household Characteristics (C) Module: electricity hours per day
*Tabulate quintiles -- this does not need outlier correction
tabstat C_18_electricity_hours, stat(n min q p95 p99 max) column(stat) long
*Checking outliers in Displacement(I) Module: how many hh members harmed in conflict
*Tabulate quintiles
tabstat I_7_conf_phys_harm_n, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 15 members)
assert I_7_conf_phys_harm_n != .o
replace I_7_conf_phys_harm_n = .o if I_7_conf_phys_harm_n > 15 & !missing(I_7_conf_phys_harm_n)
sum I_7_conf_phys_harm_n, d
replace I_7_conf_phys_harm_n = `r(p50)' if I_7_conf_phys_harm_n == .o
*Check effect of outlier removal
tabstat I_7_conf_phys_harm_n, stat(n min q p95 p99 max) column(stat) long
*Checking outliers in Displacement(I) Module: how many hh members died in conflict
*Tabulate quintiles
tabstat I_11_disp_death_num, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 15 members)
assert I_11_disp_death_num != .o
replace I_11_disp_death_num = .o if I_11_disp_death_num > 15 & !missing(I_11_disp_death_num)
sum I_11_disp_death_num, d
replace I_11_disp_death_num = `r(p50)' if I_11_disp_death_num == .o
*Check effect of outlier removal
tabstat I_11_disp_death_num, stat(n min q p95 p99 max) column(stat) long
*Checking outliers in Displacement(I) Module: how many times changed residence
*Tabulate quintiles
tabstat I_21_disp_site, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 10 times)
assert I_21_disp_site != .o
replace I_21_disp_site = .o if I_21_disp_site > 10 & !missing(I_21_disp_site)
sum I_21_disp_site, d
replace I_21_disp_site = `r(p50)' if I_21_disp_site == .o
*Check effect of outlier removal
tabstat I_21_disp_site, stat(n min q p95 p99 max) column(stat) long
*Checking outliers in Displacement(I) Module: how many times returned to original residence
*Tabulate quintiles
tabstat I_31_disp_temp_return_n, stat(n min q p95 p99 max) column(stat) long
*Remove outliers (more than 15 times)
assert I_31_disp_temp_return_n != .o
replace I_31_disp_temp_return_n = .o if I_31_disp_temp_return_n > 15 & !missing(I_31_disp_temp_return_n)
sum I_31_disp_temp_return_n, d
replace I_31_disp_temp_return_n = `r(p50)' if I_31_disp_temp_return_n == .o
*Check effect of outlier removal
tabstat I_31_disp_temp_return_n, stat(n min q p95 p99 max) column(stat) long
*add missing values value labels to newly created variables
foreach var in watersource watertime sanitation lighting dist_mkt dist_school dist_health nopolice_g fear_g watersource_disp watertime_disp sanitation_disp lighting_disp dist_mkt_disp dist_school_disp dist_health_disp {
	label define `var' .a "Don't know" .b "Refused to respond" .z "Not Applicable", modify
	label val `var' `var'
}

*Add consumption data for food, non-food and assets
*Merge consumption data
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hh_food.dta", nogen keep(match master) assert(match master)
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hh_nonfood.dta", nogen keep(match master) assert(match master)
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hh_assets.dta", nogen keep(match master) assert(match master)
drop mod_item
*Set missing values for non-food and assets to zero, if food was consumed
replace nonfood_opt0_hh_wk = 0 if nonfood_opt0_hh_wk == . 
replace nonfood_opt0_hh_wk = . if missing(food_opt0_hh_wk)
replace assets_hh_wk = 0 if assets_hh_wk  == . 
replace assets_hh_wk = . if missing(food_opt0_hh_wk) 
*Consistency check for data completion and data cleanliness
capture: drop nofood 
tabstat nonfood_opt?_hh_wk food_opt?_hh_wk assets_hh_wk , stat(n min max median mean)
*Add remaining labels
forval i=0/4 {
	label var food_opt`i'_hh_wk "HH Food Cons of Opt Mod `i' Weekly"
	label var nonfood_opt`i'_hh_wk "HH Non-Food Cons of Opt Mod `i' Weekly"
}
*Save as temporary file to be used for consistency checks
save "${gsdTemp}/hhq_cons_aggregates_1.dta", replace

*add deflators
rename month tm
*create strata variable for deflator merging
gen strata=state
replace strata=7 if state>80
merge m:1 tm strata using "${gsdTemp}/food-deflator.dta", nogen keep(match) assert(using match) keepusing(food_cons_defl)
merge m:1 tm strata using "${gsdTemp}/nonfood-deflator.dta", nogen keep(match) assert(match) keepusing(nonfood_cons_defl)
drop strata
rename tm month
*Save dataset
numlabel, remove
sort state ea hh
save "${gsdData}/1-CleanTemp/hhq.dta", replace
