*this do file prepares the conflict variables

*prepare PAYAM conflict index
import excel using "${gsdDataRaw}/ACLED_Boma_2008-2017.xls", clear first
keep STATE COUNTY PAYAM BOMA BOM_CODE latitude longitude geo_precis fatalities event_date time_preci deadly event_type
rename (STATE COUNTY PAYAM BOMA) (State County Payam Boma)
order deadly fatalities, last
*filter events occuring between waves 1 and 4
gen date=date(event_date,"DMY")
drop event_date
rename date event_date
format event_date %td
*keep relevant time period
foreach v of varlist State County Payam Boma {
	replace `v' = strtrim(strupper(`v'))
}
keep State County Payam Boma fatalities event_type event_date
drop if inlist(State,"ABYEI","JONGLEI","UPPER NILE","UNITY")
rename fatalities deaths
joinby State County Payam using "${gsdTemp}/conflict_boma_hfs_nbhs.dta", unmatched(using)
drop fatalities events deadly _merge
rename deaths fatalities
*add date for HFS households
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_gps.dta", nogen assert(match master using) keep(match master) keepusing(today)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master using) keep(match master) keepusing(pweight urban)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/NBHS.dta", nogen assert(match master match_update) keep(match master match_update) keepusing(pweight urban) update
*replace april 1st as NBHS 2009 data
replace today=td(01042009) if wave==0
*keep only wave 0 and 1 data
keep if wave==0 | wave==3
*use months instead of day date to account for potentially inaccurate reporting of dates
gen m_int=mofd(today)
gen m_ev=mofd(event_date)
*create cumulative sum of fatalities for fatal events in last 9 months
gen deadly=fatalities>10 if inrange(m_ev,tm(2013,12),m_int)
*calculate average time between event and interview
format m_* %tm
hist m_ev if deadly==1
hist m_int if deadly==1
gen months=m_int-m_ev if deadly==1
hist months if deadly==1
su months if deadly==1 [aw=pweight], detail
kdensity months if deadly==1 [aw=pweight]
*collapse the whole
collapse (count) events=fatalities (sum) deadly fatalities (min) months, by(State County Payam  wave state urban ea hh pweight m_int)
gen conflict=deadly>0
*spread to 2009
bys state County Payam  : egen z=max(conflict)
replace conflict=z if wave==0
*spread deadly to 2009
bys state County Payam  : egen y=max(deadly)
replace deadly=y if wave==0
bys state County Payam  : egen w=max(events)
replace events=w if wave==0
table wave conflict  urban, row
*clean up
label define lconflict 0 "Control" 1 "conflict"
label val conflict lconflict
order wave state urban ea hh State County Payam conflict deadly months
keep  wave state urban ea hh State County Payam conflict deadly	months
su
tab  wave conflict
save "${gsdTemp}/conflict_indicators_W3.dta", replace 	
*/

*
*Index fewer months
import excel using "${gsdDataRaw}/ACLED_Boma_2008-2017.xls", clear first
keep STATE COUNTY PAYAM BOMA BOM_CODE latitude longitude geo_precis fatalities event_date time_preci deadly event_type
rename (STATE COUNTY PAYAM BOMA) (State County Payam Boma)
order deadly fatalities, last
*filter events occuring between waves 1 and 4
gen date=date(event_date,"DMY")
drop event_date
rename date event_date
format event_date %td
*keep relevant time period
foreach v of varlist State County Payam Boma {
	replace `v' = strtrim(strupper(`v'))
}
keep State County Payam Boma fatalities event_type event_date
drop if inlist(State,"ABYEI","JONGLEI","UPPER NILE","UNITY")
rename fatalities deaths
joinby State County Payam using "${gsdTemp}/conflict_boma_hfs_nbhs.dta", unmatched(using)
drop fatalities events deadly _merge
rename deaths fatalities
*add date for HFS households
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_gps.dta", nogen assert(match master using) keep(match master) keepusing(today)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master using) keep(match master) keepusing(pweight urban)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/NBHS.dta", nogen assert(match master match_update) keep(match master match_update) keepusing(pweight urban) update
*replace april 1st as NBHS 2009 data
replace today=td(01042009) if wave==0
*keep only wave 0 and 1 data
keep if wave==0 | wave==3
*use months instead of day date to account for potentially inaccurate reporting of dates
gen m_int=mofd(today)
gen m_ev=mofd(event_date)
*create cumulative sum of fatalities for fatal events 
gen deadly1=fatalities>5 if inrange(m_ev,m_int-6,m_int)
gen deadly2=fatalities>5 if inrange(m_ev,m_int-12,m_int)
*collapse the whole
collapse (sum) deadly*, by(State County Payam  wave state urban ea hh pweight m_int)
gen conflict1=deadly1>0
gen conflict2=deadly2>0
*spread to 2009
bys state County Payam  : egen z=max(conflict1)
replace conflict1=z if wave==0
bys state County Payam  : egen y=max(conflict2)
replace conflict2=y if wave==0

label define lconflict 0 "Control" 1 "conflict"
label val conflict1 conflict2 lconflict
order wave state urban ea hh State County Payam conflict*
keep  wave state urban ea hh State County Payam conflict*
su
tab wave conflict1
tab wave conflict2
save "${gsdTemp}/conflict_indicators_time.dta", replace 	
*/
*
*Index per Boma
import excel using "${gsdDataRaw}/ACLED_Boma_2008-2017.xls", clear first
keep STATE COUNTY PAYAM BOMA BOM_CODE latitude longitude geo_precis fatalities event_date time_preci deadly event_type
rename (STATE COUNTY PAYAM BOMA) (State County Payam Boma)
order deadly fatalities, last
*filter events occuring between waves 1 and 4
gen date=date(event_date,"DMY")
drop event_date
rename date event_date
format event_date %td
*keep relevant time period
foreach v of varlist State County Payam Boma {
	replace `v' = strtrim(strupper(`v'))
}
keep State County Payam Boma fatalities event_type event_date
drop if inlist(State,"ABYEI","JONGLEI","UPPER NILE","UNITY")
rename fatalities deaths
joinby State County Payam Boma using "${gsdTemp}/conflict_boma_hfs_nbhs.dta", unmatched(using)
drop fatalities events deadly _merge
rename deaths fatalities
*add date for HFS households
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_gps.dta", nogen assert(match master using) keep(match master) keepusing(today)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master using) keep(match master) keepusing(pweight urban)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/NBHS.dta", nogen assert(match master match_update) keep(match master match_update) keepusing(pweight urban) update
*replace april 1st as NBHS 2009 data
replace today=td(01042009) if wave==0
*keep only wave 0 and 1 data
keep if wave==0 | wave==3
*use months instead of day date to account for potentially inaccurate reporting of dates
gen m_int=mofd(today)
gen m_ev=mofd(event_date)
*create cumulative sum of fatalities for fatal events in last 9 months
gen deadly=fatalities>5 if inrange(m_ev,tm(2013,12),m_int)
*collapse the whole
collapse (count) events=fatalities (sum) deadly fatalities , by(State County Payam Boma wave state urban ea hh pweight m_int)
gen conflict=deadly>0
*spread to 2009
bys state County Payam Boma: egen z=max(conflict)
replace conflict=z if wave==0
table wave conflict  urban, row
*clean up
label define lconflict 0 "Control" 1 "conflict"
label val conflict lconflict
order wave state urban ea hh State County Payam Boma conflict
keep  wave state urban ea hh State County Payam Boma conflict	
su
tab  wave conflict
rename conflict conflict_boma
save "${gsdTemp}/conflict_indicators_boma.dta", replace 	
*Index per county
import excel using "${gsdDataRaw}/ACLED_Boma_2008-2017.xls", clear first
keep STATE COUNTY PAYAM BOMA BOM_CODE latitude longitude geo_precis fatalities event_date time_preci deadly event_type
rename (STATE COUNTY PAYAM BOMA) (State County Payam Boma)
order deadly fatalities, last
*filter events occuring between waves 1 and 4
gen date=date(event_date,"DMY")
drop event_date
rename date event_date
format event_date %td
*keep relevant time period
foreach v of varlist State County Payam Boma {
	replace `v' = strtrim(strupper(`v'))
}
keep State County Payam Boma fatalities event_type event_date
drop if inlist(State,"ABYEI","JONGLEI","UPPER NILE","UNITY")
rename fatalities deaths
joinby State County using "${gsdTemp}/conflict_boma_hfs_nbhs.dta", unmatched(using)
drop fatalities events deadly _merge
rename deaths fatalities
*add date for HFS households
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_gps.dta", nogen assert(match master using) keep(match master) keepusing(today)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master using) keep(match master) keepusing(pweight urban)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/NBHS.dta", nogen assert(match master match_update) keep(match master match_update) keepusing(pweight urban) update
*replace april 1st as NBHS 2009 data
replace today=td(01042009) if wave==0
*keep only wave 0 and 1 data
keep if wave==0 | wave==3
*use months instead of day date to account for potentially inaccurate reporting of dates
gen m_int=mofd(today)
gen m_ev=mofd(event_date)
*create cumulative sum of fatalities for fatal events in last 9 months
gen deadly=fatalities>5 if inrange(m_ev,tm(2013,12),m_int)
*collapse the whole
collapse (count) events=fatalities (sum) deadly fatalities , by(State County wave state urban ea hh pweight m_int)
su deadly [aw=pweight], meanonly
gen conflict=deadly>r(mean)
*spread to 2009
bys state County: egen z=max(conflict)
replace conflict=z if wave==0
table wave conflict  urban, row
*clean up
label define lconflict 0 "Control" 1 "conflict"
label val conflict lconflict
order wave state urban ea hh State County conflict
keep  wave state urban ea hh State County conflict	
su
tab  wave conflict
rename conflict conflict_county
save "${gsdTemp}/conflict_indicators_county.dta", replace 	
*/
*Index per county
import excel using "${gsdDataRaw}/ACLED_Boma_2008-2017.xls", clear first
keep STATE COUNTY PAYAM BOMA BOM_CODE latitude longitude geo_precis fatalities event_date time_preci deadly event_type
rename (STATE COUNTY PAYAM BOMA) (State County Payam Boma)
order deadly fatalities, last
*filter events occuring between waves 1 and 4
gen date=date(event_date,"DMY")
drop event_date
rename date event_date
format event_date %td
*keep relevant time period
foreach v of varlist State County Payam Boma {
	replace `v' = strtrim(strupper(`v'))
}
keep State County Payam Boma fatalities event_type event_date
drop if inlist(State,"ABYEI","JONGLEI","UPPER NILE","UNITY")
rename fatalities deaths
joinby State County Payam using "${gsdTemp}/conflict_boma_hfs_nbhs.dta", unmatched(using)
drop fatalities events deadly _merge
rename deaths fatalities
*add date for HFS households
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_gps.dta", nogen assert(match master using) keep(match master) keepusing(today)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master using) keep(match master) keepusing(pweight urban)
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/NBHS.dta", nogen assert(match master match_update) keep(match master match_update) keepusing(pweight urban) update
*replace april 1st as NBHS 2009 data
replace today=td(01042009) if wave==0
*keep only wave 0 and 1 data
keep if wave==0 | wave==3
*use months instead of day date to account for potentially inaccurate reporting of dates
gen m_int=mofd(today)
gen m_ev=mofd(event_date)
*create cumulative sum of fatalities for fatal events in last 9 months
gen deadly0=fatalities>0 if inrange(m_ev,tm(2013,12),m_int)
gen deadly15=fatalities>15 if inrange(m_ev,tm(2013,12),m_int)
*collapse the whole
collapse (sum) deadly*, by(State County Payam  wave state urban ea hh pweight m_int)
gen conflict0=deadly0>0
gen conflict15=deadly15>0
*spread to 2009
bys state County Payam  : egen z=max(conflict0)
replace conflict0=z if wave==0
bys state County Payam  : egen y=max(conflict15)
replace conflict15=y if wave==0
label define lconflict 0 "Control" 1 "conflict"
label val conflict0 conflict15 lconflict
order wave state urban ea hh State County Payam conflict*
keep  wave state urban ea hh State County Payam conflict*
su
tab wave conflict15
tab wave conflict0
save "${gsdTemp}/conflict_indicators_intense.dta", replace 	

