*this do file prepares the price index based on core prices

use "${gsdDataRaw}\calories.dta", clear
* Generate consistent item names for merge
gen str67 item_merge = subinstr(item_name,"  ","",.)
replace item_merge=strtrim(item_merge)
replace item_merge="Black tea imported (no tea bags)" if item_merge=="Black tea imported"
replace item_merge="Dried fish (local)" if item_merge=="Dried fish (local) "
replace item_merge="Pumpkin (Garaoa)" if item_merge=="Pumpkin (Gara�a)" | item==11741
replace item_merge="Small animals (rabbits, mice,etc.)" if item_merge=="Small animals (rabbits, mice,�.)" | item==11215
replace item_merge="Feet/foot from cow/veal (fresh and clean without skin)" if item_merge=="Feet/foot of cow/veal, fresh and clean without skin"
replace item_merge="Feet/foot of sheep/goat (fresh and clean without skin)" if item_merge=="Feet/foot of sheep/goat, fresh and cleaned (without skin)"
replace item_merge="Head from sheep/goat (fresh and clean without skin)" if item_merge=="Goat head cleaned and fresh (without skin) full head" // Goat and sheep head have the same calories (700 p.kg)
replace item_merge="Mutton tripes/intestines but no liver from sheep/goat (fresh and clean without skin)" if item_merge=="Mutton tripes (intestines) sheep/goat, fresh and cleaned"
replace item_merge="Other cereals and cereal products (except infant feeding, wheat, millet, reels of pasta, buns and breakfast cereals)" if item_merge=="Other cereals and cereal products"
replace item_merge="Head from cow/veal (fresh and clean without skin)" if item_merge=="Accessories meat (head of cattle/veal) fresh and clean without skin"
replace item_merge="Intestines beef/cow/veal but no liver" if item_merge=="Mutton tripes (intestines) cow/veal fresh and clean"
replace item_merge="Feet/foot from sheep/goat (fresh and clean without skin)" if item_merge=="Feet/foot of sheep/goat (fresh and clean without skin)"
replace item_merge="Other fresh meat and animal products but no sheep/goat or beef/cow/veal" if item_merge=="Other meat and animal products"
save "${gsdTemp}/calories_renamed.dta", replace
use "${gsdTemp}/food_itemlabels.dta", clear
gen item_merge=itemlabel
merge 1:1 item_merge using  "${gsdTemp}/calories_renamed.dta", assert(match using) keep(match)
keep item_merge itemid mod_opt item
rename (item_merge mod_opt) (item_name mod_item)
save "${gsdTemp}/items_1.dta", replace

use "${gsdNBHS}/NBHS_FOOD.dta", clear
merge m:1 item using "${gsdTemp}/items_1.dta", assert(match master) keep(match) keepusing(item_name mod_item itemid) nogen
keep if mod_item==0
*replace missing prices
bysort itemid: egen price_median_overall=median(uv)
bysort state itemid: egen price_median_state=median(uv)
bysort state cluster itemid: egen price_median_ea=median(uv)
gen price=uv
replace price=price_median_ea if missing(price) & !missing(price_median_ea)
replace price=price_median_state if missing(price) & !missing(price_median_state)
replace price=price_median_overall if missing(price) & !missing(price_median_overall)
*still missing some prices so calculate them manually from value and quantity consumed
egen q=rowtotal( kgq07 kgq09 kgq11 kgq13)
gen p=value/q if missing(price)
bysort itemid cluster: egen price_median_calculated_ea=median(p) if missing(price)
bysort itemid state: egen price_median_calculated_state=median(p) if missing(price) 
bysort itemid: egen price_median_calculated_overall=median(p) if missing(price) 
replace price=price_median_calculated_ea if missing(price) & !missing(price_median_calculated_ea)
replace price=price_median_calculated_state if missing(price) & !missing(price_median_calculated_state)
replace price=price_median_calculated_overall if missing(price) & !missing(price_median_calculated_overall)
assert !missing(price)
drop price_median* p q 
*drop outliers
replace price=. if price>550
save "${gsdTemp}/nbhs_food_withprices.dta", replace

*create nbhs core food consumption data
use "${gsdTemp}/nbhs_food_withprices.dta", clear
collapse (sum) value_fc=value , by(state cluster hhid)
label var value "Core food consumption"
save "${gsdTemp}/nbhs_corefood.dta", replace

*calculate weight and median price
use "${gsdTemp}/nbhs_food_withprices.dta", clear
format item_name %32s
egen totalvalue=sum(value)
collapse (p50) price (sum) value (mean) total, by(item_name itemid)
gen weight= value/ total
egen check=sum(weight)
assert check==round(1,0.001)
drop check value totalvalue
gen weighted_price=price*weight
rename (weight price weighted_price) (weight_base price_base weighted_price_base)
save "${gsdTemp}/nbhs_food_base.dta", replace

*apply to NBHS BOMAs
use "${gsdTemp}/nbhs_food_withprices.dta", replace
keep state cluster hhid itemid item_name price
rename (cluster hhid) (ea hh)
gen wave=0
format item_name %32s
labmask itemid, val(item_name)
keep if state>81
merge m:1 wave state ea hh using  "${gsdTemp}/conflict_boma_hfs_nbhs.dta", nogen assert(match using) keep(match) keepusing(State County Payam Boma)
collapse (p50) price , by(wave state State County Payam Boma itemid )
*fill in blanks
egen boma_id=group(wave State County Payam Boma)
egen county_id=group(wave State County)
fillin boma_id itemid
*replace missing values due to fillin
qui foreach v in wave state county_id {
	bysort boma_id: egen x_`v'=max(`v')
	replace `v'=x_`v' if missing(`v')
	drop x_`v'
}
qui foreach v in  State County Payam Boma  {
	encode `v', gen(y_`v')
	drop `v'
	bysort boma_id: egen x_`v'=max(y_`v')
	replace y_`v'=x_`v' if missing(y_`v')
	decode y_`v', gen(`v')
	drop x_`v' y_`v'
}
bysort wave State County Payam Boma: egen check=count(itemid)
assert(check==33)
*replace missing prices with median
bysort wave itemid: egen price_median_overall=median(price)
bysort wave state itemid: egen price_median_state=median(price)
bysort wave State County itemid: egen price_median_county=median(price)
replace price=price_median_county if missing(price) & !missing(price_median_county)
replace price=price_median_state if missing(price) & !missing(price_median_state)
replace price=price_median_overall if missing(price) & !missing(price_median_overall)
assert !missing(price)
drop price_median_* _fillin
*merge with weights
merge m:1 itemid using "${gsdTemp}/nbhs_food_base.dta", assert(match) nogen keepusing(weight_base weighted_price_base)
*calculate weighted prices
gen weighted_price=weight_base*price
collapse (sum) weighted_price_base weighted_price, by(wave state State County Payam Boma )
gen price_index=weighted_price/weighted_price_base
*check index
*hist price_index, by(state)
*clean up and save
keep wave state State County Payam Boma  price_index
save "${gsdTemp}/nbhs_boma_price_index_core_food.dta", replace

*create an inflation measure for the HFS
*create food dataset with food disaggregated by own production and not
local commonvars = "state ea hh itemid mod_item cons_value_org cons_value_fin cons price_ssp_per_kg_cleaned cons_q_kg"
*wave4
use "${gsdData}/1-CleanOutput/food.dta", clear
keep `commonvars'
gen wave=4
save "${gsdTemp}/food_cpi_W4.dta", replace
*wave3
use "${gsdW3}/Data/1-CleanOutput/food.dta", clear
keep `commonvars'
gen wave=3
save "${gsdTemp}/food_cpi_W3.dta", replace
*wave2
use "${gsdW2}/Data/1-CleanOutput/food.dta", clear
keep `commonvars' 
gen wave=2
save "${gsdTemp}/food_cpi_W2.dta", replace
*wave1
use "${gsdW1}/Data/1-CleanOutput/food.dta", clear
keep `commonvars'
gen wave=1
save "${gsdTemp}/food_cpi_W1.dta", replace

*prepare appended dataset
use "${gsdTemp}/food_cpi_W4.dta", clear
append using "${gsdTemp}/food_cpi_W3.dta"
append using "${gsdTemp}/food_cpi_W2.dta"
append using "${gsdTemp}/food_cpi_W1.dta"
order wave, first
keep if state>81
*keep core items
keep if mod_item==0
*merge with admin data to make price indices at the Boma level
merge m:1 wave state ea hh using  "${gsdTemp}/conflict_boma_hfs_nbhs.dta", nogen assert(match using) keep(match) keepusing(State County Payam Boma)
*calculate weighted price index
rename price_ssp_per_kg_cleaned price
collapse (p50) price, by(wave state State County Payam Boma itemid)
egen boma_id=group(wave State County Payam Boma)
egen county_id=group(wave State County)
fillin boma_id itemid
*replace missing values due to fillin
qui foreach v in wave state county_id {
	bysort boma_id: egen x_`v'=max(`v')
	replace `v'=x_`v' if missing(`v')
	drop x_`v'
}
qui foreach v in  State County Payam Boma  {
	encode `v', gen(y_`v')
	drop `v'
	bysort boma_id: egen x_`v'=max(y_`v')
	replace y_`v'=x_`v' if missing(y_`v')
	decode y_`v', gen(`v')
	drop x_`v' y_`v'
}
bysort wave State County Payam Boma: egen check=count(itemid)
assert(check==33)
*remove outrageous prices
replace price=. if price>550
*replace missing prices
bysort wave itemid: egen price_median_overall=median(price)
bysort wave state itemid: egen price_median_state=median(price)
bysort wave State County itemid: egen price_median_county=median(price)
replace price=price_median_county if missing(price) & !missing(price_median_county)
replace price=price_median_state if missing(price) & !missing(price_median_state)
replace price=price_median_overall if missing(price) & !missing(price_median_overall)
*missing 55 chicken prices in wave 4, replace with median wave 4 price for other meats and poultry type of things
quietly su price if itemid==10214 & wave==4, detail
replace price=r(p50) if itemid==11404 & wave==4
*check
assert !missing(price)
drop price_median_* _fillin check 
*merge with weights
merge m:1 itemid using "${gsdTemp}/nbhs_food_base.dta", assert(match) nogen keepusing(weight_base weighted_price_base)
*calculate weighted prices
gen weighted_price=weight_base*price
collapse (sum) weighted_price_base weighted_price, by(wave state State County Payam Boma)
gen price_index=weighted_price/weighted_price_base
*check index
*hist price_index, by(wave)
keep wave state State County Payam Boma price_index
save "${gsdTemp}/hfs_boma_price_index_core_food.dta", replace
*append the two datasets
use "${gsdTemp}/nbhs_boma_price_index_core_food.dta", clear
append using "${gsdTemp}/hfs_boma_price_index_core_food.dta",
label var price_index "Laspeyres price index based on core food items, Boma" 
save "${gsdTemp}/boma_price_index_core_food.dta", replace
