*This do files prepares the household data for the conflict estimation

*prepare NBHS 2009 hhm data
use "${gsdNBHS}/NBHS_IND.dta", clear
*rename variables for ease
rename (b41 c2 c3) (age school_ever school_current)
*rename variables already calculated
rename (head_education head_sex) (hhh_edu_levels hhh_gender)
*generate dummy for child not attending school
gen child_noed=(school_current==2 | school_ever==2) if inrange(age,6,14)
gen school_age=inrange(age,6,14)
gen dependent=inrange(age,0,14) | inrange(age,65,120)
gen working_age=inrange(age,15,64)
*fix hhhead education
replace hhh_edu_levels=hhh_edu_levels+1
*create household level data
collapse (mean) hhh_edu_levels (sum) dependent working_age , by(state cluster hhid)
label var hhh_edu_levels "HH head education"
gen dep_ratio=working_age/dependent
replace dep_ratio=0 if dependent==0
label var dep_ratio "Working age to dependents ratio"
drop dependent working_age
*merge with full data
merge 1:1 state cluster hhid using "${gsdNBHS}/NBHS_HH.dta", nogen assert(match)
*merge with core food data
merge 1:1 state cluster hhid using "${gsdTemp}/nbhs_corefood.dta", nogen assert(match master) keep(match master)
replace value_fc=value_fc*(30/7)
replace value_fc=value_fc/1.106 if urban==1
replace value_fc=value_fc/0.983 if urban==2
gen value_fc_pc=value_fc/hhsize
*merge with nonfood core data
merge 1:1 state cluster hhid using "${gsdTemp}/nbhs_corenonfood.dta", nogen assert(match master) keep(match master)
replace value_nfc=value_nfc*30
replace value_nfc=value_nfc/1.106 if urban==1
replace value_nfc=value_nfc/0.983 if urban==2
gen value_nfc_pc=value_nfc/hhsize
*create a core food nonfood aggregate
egen core_cons=rowtotal(value_nfc_pc value_fc_pc)
*create ratio to check core poverty figures later
gen r=core_cons/pcexpm
su r, meanonly
gen poor_core=core_cons<(upperz*r(mean))
gen poor_core_extreme=core_cons<(upperz*r(mean)*(1.25/1.90))
label var poor_core "Poor"
mean poor_core [aw=hhweight*hhsize]
* /30 * 1 /72.583*3355.756*r(mean)
*adjust consumption
*Poverty line 1.90 USD in USD PPP (2011)
* The 2009 PPP for SSD is 1/1.0858328
* Thus, to convert May 2009 SDG into July 2009 SSP we:
* do not convert since SSPs were introduced at par with SSPs when the currency was first introduced
* multiply by the SSD PPP conversion factor, and adjust for inflation
* CPI July 2015: 239.906; May 2009
* = pcexpm/30 * 1.08 / 72.583*239.906
*gen tc_imp=pcexpm/30*1.08/72.583*239.906
replace core_cons=core_cons/30 * 1 /72.583*3355.756
label var core_cons "Core consumption of food and nonfood items, July 2017 pc pd"
*keep only relevant observations and make compatible with HFS
keep if state>81
rename (cluster hhid) (ea hh)
*clean control variables
recode i1 (1 2 = 1 "Agriculture") (3 4 = 2 "Wages/Own business") ( nonmissing = 3 "Remittances/Aid/Other") , gen(livelihood)
label var livelihood "Livelihood"
gen hhtoilet=!inlist(h9,5,6)
gen hhwater=1 if inlist(h5,1,2,3,4)
replace hhwater=2 if inlist(h5,5)
replace hhwater=3 if inlist(h5,6,7,8,9,10,11)
replace hhwater=4 if inlist(h5,12,13)
*replace missings with median (10 for toilet and 23 for water)
quietly foreach v of varlist hhh_edu_levels livelihood  {
	su `v', detail
	replace `v'=r(p50) if missing(`v')
}
*generate violent crime dummy / missing iwll get rpelaced to median which is zero
*gen violence=l107_1==1 
*clean up and save
rename hhweight weight
gen wave=0
keep wave state ea hh core_cons poor_core livelihood hhh_edu_levels dep_ratio 
save "${gsdTemp}/NBHS_conflict_hhq.dta", replace
*prepare HFS data
*prepare core food and nonfood
*forvalues i=1/4 {
use "${gsdData}/1-CleanTemp/hhq-poverty.dta", clear
gen wave=4
keep data wave state ea hh mi_cons_f0 mi_cons_nf0 
save "${gsdTemp}/hhq_core_food_nonfood_w4.dta", replace
forvalues n=1/3 {
	use "${gsdW`n'}/Data/1-CleanTemp/hhq-poverty.dta", clear
	gen wave=`n'
	gen dataset=2
	keep dataset wave state ea hh mi_cons_f0 mi_cons_nf0 
	save "${gsdTemp}/hhq_core_food_nonfood_w`n'.dta", replace
}
use "${gsdTemp}/hhq_core_food_nonfood_w4.dta", clear
append using "${gsdTemp}/hhq_core_food_nonfood_w3.dta"
append using "${gsdTemp}/hhq_core_food_nonfood_w2.dta"
append using "${gsdTemp}/hhq_core_food_nonfood_w1.dta"
keep if state>81
egen core_cons=rowtotal(mi_cons_f0 mi_cons_nf0)
replace core_cons= core_cons* 1/ 239.91 *  3355.756
keep dataset wave state ea hh core_cons
save "${gsdTemp}/hfs_core_food_nonfood.dta", replace
*prepare member level data
use  "${gsdData}/1-CleanTemp/hhm_analysis.dta", clear
gen dependent=inrange(age,0,14) | inrange(age,65,120)
gen child_noed=(edu_current==0) if inrange(age,6,14)
collapse (sum)  dependent working_age , by(dataset wave state ea hh)
gen dep_ratio=working_age/dependent
replace dep_ratio=0 if missing(dep_ratio)
*merge with hhq 
local mergevars = "urban hhsize weight pweight poor plinePPP tc_core tc_imp hhh_edu_level_g lhood mi_cons_d migr_hhh_3m migr_permanent migr_dec13 migr_dec13_cause idp hhh_migra_time hhh_birthplace_ssd hhh_migra_from" 
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match) keepusing(`mergevars')
*Control variables
gen hhh_edu_levels=hhh_edu_level_g if hhh_edu_level_g<5
recode lhood (1 2 3 = 1 "Agriculture") (4 5 = 2 "Wages/Own business") ( nonmissing = 3 "Remittances/Aid/Other") , gen(livelihood)
drop hhh_edu_level_g lhood
*replace missings with median 
quietly foreach v of varlist hhh_edu_levels livelihood {
	su `v', detail
	replace `v'=r(p50) if missing(`v')
}
*merge with only food and nonfood consumption measure
merge 1:1 dataset wave state ea hh using "${gsdTemp}/hfs_core_food_nonfood.dta", nogen assert(match master) keep(match)
gen r=tc_core/tc_imp
su r if wave==1 [aw=pweight], meanonly
gen poor_core=tc_core<plinePPP*r(mean) if wave==1
forvalues n=2/4 {
	su r if wave==`n' [aw=pweight], meanonly 
	replace poor_core=tc_core<plinePPP*r(mean) if wave==`n'
}
*merge weights for panel
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match using) keep(match) keepusing(panel_w* weight_* violent mi_cons_f)
rename (panel_w124 panel_w12 panel_w24) (sample_w124 sample_w12 sample_w24)
*household weights
bys state ea hh: egen weight_w12=max(weight_panel3)
bys state ea hh: egen weight_w24=max(weight_panel2)
bys state ea hh: egen weight_w124=max(weight_panel1)
drop weight_panel?
*population weights
gen xpweight_w12=weight_w12*hhsize if wave==1
bys state ea hh: egen pweight_w12=max(xpweight_w12)
gen xpweight_w24=weight_w24*hhsize if wave==2
bys state ea hh: egen pweight_w24=max(xpweight_w24)
gen xpweight_w124=weight_w124*hhsize if wave==1
bys state ea hh: egen pweight_w124=max(xpweight_w124)
drop x*
*clean up sample variables
quietly foreach v of varlist sample* {
	replace `v'=0 if wave==0
}
*clean up and save
* sample_w* weight_w*   pweight_w* 
local keepcore="wave state ea hh core_cons poor_core  dep_ratio hhh_edu_levels livelihood violent migr_hhh_3m migr_permanent migr_dec13 migr_dec13_cause idp hhh_migra_time hhh_birthplace_ssd hhh_migra_from"
keep dataset mi_cons_f weight pweight* sample* `keepcore'
save "${gsdTemp}/HFS_conflict_hhq.dta", replace

*Combine the datasets with MPI data
use "${gsdTemp}/multidimensional_deprivation.dta", clear
drop if dataset==1
drop if missing(tc_imp)
drop poor quintiles_tc housing adult_noed information transportation assets living_standards education wash deprivations deprivations2 mpi mpi_np
*merge
merge 1:1 wave state ea hh using "${gsdTemp}/NBHS_conflict_hhq.dta", nogen assert(match master)
merge 1:1 wave state ea hh using "${gsdTemp}/HFS_conflict_hhq.dta", nogen assert(match master match_update) update
*consolidate head educ
recode hhh_edu_levels (1=1 "No education") (2=2 "Primary") (2 3=4 "Secondary/Tertiary"), gen(hhh_edu)
label var hhh_edu "HH head education"
order hhh_edu, after(hhh_edu_levels)
drop hhh_edu_levels
*create ea id
egen ea_id=group(state ea)
label var ea_id "EA Id"
*create household id
egen hh_id=group(state ea hh)
label var hh_id "Household Id"
order ea_id hh_id, after(hh)
*merge with conflict data
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators.dta", nogen assert(match using master) keep(match) keepusing( State County Payam Boma)
*merge with price index data
merge m:1 wave state State County Payam Boma using "${gsdTemp}/boma_price_index_core_food.dta", nogen assert(match using) keep(match)
gen lcpi=ln(price_index)
*create geodata
encode County, gen(county)
encode Payam, gen(payam)
encode Boma, gen(boma)
drop State County Payam Boma
order county payam boma, after(state)
*truncate outlier consumption
forvalues n=0/4 {
	quietly su core_cons if wave==`n', detail
	replace core_cons=r(p99) if core_cons>r(p99) & wave==`n'
	replace core_cons=r(p1) if core_cons<r(p1) & wave==`n'
}
*create richest half of households
gen pctile=.
forvalues i=0/4 {
	xtile pctile_w`i'=core_cons [aw=pweight]  if wave==`i', nq(10)
	replace pctile=pctile_w`i' if wave==`i'
	drop pctile_w`i'
}
*create richest half of counties (calculate a weighted and an unweighted one)
levelsof county, local(co)
gen county_means=.
quietly foreach c of local co {
	su tc_imp [aw=pweight] if wave==0 & county==`c'
	replace county_means=r(mean) if county==`c' 
}
bys state payam: gen county_means_n1=county_means if _n==1
quietly su county_means_n1, detail
gen pctile_county_W0=1 if county_means<=r(mean)
replace pctile_county_W0=2 if county_means>r(mean)
drop county_means*
*create log consumption 
gen lcons=ln(core_cons)
label var lcons "Ln Tot. Core Cons."
order lcons, after(core_cons)
*set survey
rename core_cons cons
svyset ea [pw=pweight], strata(stratum)
*hist core_cons if inlist(wave,0,1,3), by(wave)
gen post=wave!=0
save  "${gsdData}/1-CleanTemp/hhq_conflict_analysis.dta", replace
