*this do file runs regressions for the conflict estimation
clear all
set more off, perm
set matsize 10000

*Run the prepare do files
run "${gsdDo}/2-1-10-1-conflict_indicators.do"
run "${gsdDo}/2-1-10-2-conflict_price_index.do"
run "${gsdDo}/2-1-10-3-conflict_nbhs_hfs_core_nonfood.do"
run "${gsdDo}/2-1-10-4-conflict_prepare_hh.do"

*run the analysis
use  "${gsdData}/1-CleanTemp/hhq_conflict_analysis.dta", clear
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_W3.dta", nogen assert(match master using) keep(match)
*define controls
global dep = "lcons"
global fe = "county"
local treat = "conflict"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" i1.`treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
*check treatment distribution
table wave conflict, row col
svy: tab wave conflict, row
*base results in levels, no regression
diff cons [pw=pweight] if inlist(wave,0,3), p(post) t(conflict) cluster(ea_id)
svy: mean cons , over(post conflict)
*control before after
lincom [cons]_subpop_1-[cons]_subpop_3
*conflict before after
lincom [cons]_subpop_2-[cons]_subpop_4
*control conflict before 
lincom [cons]_subpop_1-[cons]_subpop_2
*conflict conflict after
lincom [cons]_subpop_3-[cons]_subpop_4
*diffs in diffs 1
lincom ([cons]_subpop_1-[cons]_subpop_3)-([cons]_subpop_2-[cons]_subpop_4)
*define controls
quietly tab livelihood, gen(liv)
quietly tab hhh_edu, gen(hed)
local potential_controls = "cons urban price_index hhsize hhh_gender dep_ratio child_noed hed1 hed2 hed3 liv1 liv2 liv3 improved_sanitation improved_watersource"
*corr `potential_controls'
svy: mean `potential_controls' if wave==0, 
svy: mean  `potential_controls' if wave==3, 
tabstat  `potential_controls' if wave==0, stat(min max) col(stat)
tabstat  `potential_controls' if wave==3, stat(min max) col(stat)
*Balance table overall in baseline sample
orth_out `potential_controls' using "${gsdOutput}/balance_conflict.xls" if wave==0, replace by(conflict) stars  pcompare
*selection of controls and interactions
local control_check "urban price_index hhsize hhh_gender dep_ratio child_noed i.hhh_edu i.livelihood improved_sanitation improved_watersource"
areg cons `control_check' if wave==0, absorb(county)
foreach v of local control_check {
	areg conflict `v' if wave==0 [pw=pweight], absorb(county)
	testparm `v'
}

*densities for graphs
kdensity lcons if wave==0 & conflict==0  [aw=pweight] , nograph gen(x control_2009 )
kdensity lcons if wave==0 & conflict==1  [aw=pweight] , nograph at(x) gen(conflict_2009 )
kdensity lcons if wave==3 & conflict==0  [aw=pweight] , nograph at(x) gen(control_2016 )
kdensity lcons if wave==3 & conflict==1  [aw=pweight] , nograph at(x) gen(conflict_2016 )
label var control_2009 "Non-exposed"
label var conflict_2009 "Conflict exposed"
label var control_2016 "Non-exposed"
label var conflict_2016 "Conflict exposed"
export excel x conflict_2009 control_2009 conflict_2016 control_2016 using "${gsdOutput}/densities_conflict.xlsx", sheetmodify sheet("Densities") first(varl) 



* BASELINE RESULTS
*simple dummy
local treat = "conflict"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" i1.`treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
local tabnum=1
*simple
quietly svy: reg ${dep} i.post##i.`treat' 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*add controls
 svy: reg ${dep} i.post##i.`treat' `controls' `interactions' 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*County FE
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*County-time FE
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.wave#i.${fe}
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons

* ROBUSTNESS
*removing migration
local treat = "conflict"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
local tabnum=5
*No IDPs
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if (idp==0 | wave==0)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Not IDP) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*No non-permanent residents
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if (migr_perm==1 | wave==0)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Perm. Loc.) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*HH head moved here less than2.5 years ago from further than in the same county
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if !(hhh_migra_time<30 & hhh_migra_from!=1) | wave==0
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(After Dec.13) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons

*selecting sub-samples
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_intense.dta", nogen assert(match master using) keep(match)
local treat = "conflict"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
local tabnum=6
*rural
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if urban==0
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Rural) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*rural
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if urban==1
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Urban) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
gen sta=floor(state/10)
tab sta
*BG rural
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if sta==8 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Bahr el Ghazal) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*EQ urban
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if sta==9  
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Equatoria) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*BG rural
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if sta==8 & urban==0
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Bahr el Ghazal Rural) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*BG urban
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if sta==8  & urban==1
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Bahr el Ghazal Urban) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*EQ rural
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if sta==9 & urban==0
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Equatoria Rural) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*EQ urban
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} if sta==9  & urban==1
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Equatoria Urban) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons

BREAK
*simple dummy different definitions
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local tabnum=7
drop conflict
*time
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_time.dta", nogen assert(match master using) keep(match)
* 6 months
local treat = "conflict1"
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(6 months) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
* 12 months
local treat = "conflict2"
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(12 months) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*space
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_boma.dta", nogen assert(match master using) keep(match)
* boma
local treat = "conflict_boma"
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Boma) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
* county
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_county.dta", nogen assert(match master using) keep(match)
local treat = "conflict_county"
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(County) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*intensity
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_intense.dta", nogen assert(match master using) keep(match)
*zero
local treat = "conflict0"
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Zero deaths) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
*fifteen
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_county.dta", nogen assert(match master using) keep(match)
local treat = "conflict15"
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly svy: reg ${dep} i.post##i.`treat' `controls' `interactions' i.${fe} 
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Ten deaths) addtext(County FE, YES, County-Time FE, NO, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons


*Quantile regression
use  "${gsdData}/1-CleanTemp/hhq_conflict_analysis.dta", clear
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_W3.dta", nogen assert(match master using) keep(match)
global dep = "lcons"
global fe = "county"
local treat="conflict"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" i1.`treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
local tabnum=9
*county FE
quietly	qreg ${dep} i.post##i.conflict `controls' `interactions'  i.${fe} if urban==1 [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.conflict `controls' `interactions'  i.${fe}  if urban==1  [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}
*no FE
local fe = ""
local tabnum=3
quietly	qreg ${dep} i.post##i.conflict  `controls' `interactions'  `fe'  [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(conflict_int ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.conflict  `controls' `interactions'  `fe'  [pw=pweight], q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(conflict_int ) nocons
}

*try out matching estimator, 
*can't use factor variables in diff command so create required variables
gen conflict_int=conflict==1 & post==1
quietly tab hhh_edu, gen(hed)
quietly tab livelihood, gen(liv)
quietly tab county, gen(c)
quietly foreach v of varlist urban dep_ratio child_noed hed1 hed2 hed3 liv1 liv2 liv3 improved_sanitation {
	gen int_`v'=conflict*`v'
}
quietly foreach v of varlist c1-c39 {
	gen fet_`v'_pre=post==0 & `v'==1
	gen fet_`v'_post=post==1 & `v'==1
}
*fe-time
local controls_sc = "urban hhsize dep_ratio hhh_gender child_noed hed2 hed3 liv2 liv3 improved_sanitation  c2-c39"
local interactions="int_urban int_hed1  int_hed3  int_liv2 int_liv3 int_improved_sanitation"
local controls_reg = ""
local tabnum=6
diff lcons [pw=pweight] , t(conflict) p(post) kernel rcs cov(`controls_sc') addcov(`control_reg') cluster(ea_id) 



*quantile the whole way through 
use  "${gsdData}/1-CleanTemp/hhq_conflict_analysis.dta", clear
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_W3.dta", nogen assert(match master using) keep(match)
*define controls
global dep = "lcons"
global fe = "county"
local treat = "conflict"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" i1.`treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
*Quantile regression
use  "${gsdData}/1-CleanTemp/hhq_conflict_analysis.dta", clear
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_W3.dta", nogen assert(match master using) keep(match)
global dep = "lcons"
global fe = "county"
local treat="conflict"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" i1.`treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"


*idps
local tabnum=32
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}  if (idp==0 | wave==0) [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}   if (idp==0 | wave==0) [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}
local tabnum=31
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe} if !(hhh_migra_time<30 & hhh_migra_from!=1) | wave==0 [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}  if !(hhh_migra_time<30 & hhh_migra_from!=1) | wave==0  [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}


local tabnum=21
*baseline
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'   [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat'    [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}
local tabnum=20
*baseline
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'   [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'    [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}
local tabnum=10
*baseline
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe} [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}  [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}


*definitions
drop conflict
*time
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_time.dta", nogen assert(match master using) keep(match)
* 6 months
local tabnum=12
local treat = "conflict1"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe} [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}  [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}
*12 months
local tabnum=13
local treat = "conflict2"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe} [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}  [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}
*space
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_boma.dta", nogen assert(match master using) keep(match)
* boma
local tabnum=14
local treat = "conflict_boma"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe} [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}  [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}
* county
local tabnum=15
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_county.dta", nogen assert(match master using) keep(match)
local treat = "conflict_county"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe} [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}  [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}
*intensity
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_intense.dta", nogen assert(match master using) keep(match)
*zero
local tabnum=16
local treat = "conflict0"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe} [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}  [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}
*fifteen
local tabnum=17
merge 1:1 wave state ea hh using  "${gsdTemp}/conflict_indicators_intense.dta", nogen assert(match master using) keep(match)
local treat = "conflict15"
local controls = "urban hhsize dep_ratio hhh_gender child_noed i.hhh_edu i.livelihood improved_sanitation "
local interactions=" `treat'#urban `treat'#i.hhh_edu `treat'#i.livelihood `treat'#i.improved_sanitation"
quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe} [pw=pweight]  , q(.1) nolog vce(robust)
outreg2 using "${gsdOutput}/regressions`tabnum'.xls", replace ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
forvalues q=.2(.1).9 {
	quietly	qreg ${dep} i.post##i.`treat' `controls' `interactions'  i.${fe}  [pw=pweight]  , q(`q') nolog vce(robust)
	outreg2 using "${gsdOutput}/regressions`tabnum'.xls", append ctitle(Cons.) addtext(County FE, NO, County-Time FE, YES, Controls+Interactions, YES) label keep(i1.post#i1.`treat' ) nocons
}



