*This does file performs the PMT analysis

*create a hhm dataset
*calculate some additional hhm indices
use  "${gsdData}/1-CleanTemp/hhm_analysis.dta", clear
*highest level of education in household 
recode edu_level_g (1=0 "No education") (2 5=1 "Primary") (3=2 "Secondary") (4=3 "Tertiary") (0=.), gen(edu_levels)
replace edu_levels=. if inrange(age,0,14)
bys wave state ea hh: egen highest_ed=max(edu_levels)
*create indices for counts
gen adult=1 if inrange(age,15,120)
gen child=1 if inrange(age,6,14)
gen small_child=1 if inrange(age,0,5)
gen child_6to10=1 if inrange(age,6,10) 
gen child_11to15=1 if inrange(age,11,15) 
gen child_16to18=inrange(age,16,18)
gen elderly=1 if inrange(age,65,120)
gen disabled=inlist(job_search_no,2)
*create dataset
collapse (max) highest_ed (sum) adult child small_child elderly working_age disabled child_6to10 child_11to15 child_16to18 (count) hhsize=hhmid, by(wave state ea hh)
*clean up
gen small_child_share=small_child/hhsize
gen child_share=child/hhsize
gen elderly_share=elderly/hhsize
label var highest_ed "Highest level of education in household (15+)"
label val highest_ed edu_levels
label var small_child_share "Share of children aged 0-5"
label var child_share "Share of children aged 6-14"
label var elderly_share "Share of elderly aged 65+"
keep wave state ea hh highest_ed small_child_share child_share elderly_share child small_child elderly disabled child_6to10 child_11to15 child_16to18
save "${gsdTemp}/hhm_pmt.dta", replace
*hhq level data
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strat(stratum)
*keep only waves 1 and 3 data
keep if wave==1 | wave==3
*merge with other variables
local mergevars = "plinePPP pline125PPP poorPPP_prob poor125PPP_prob tc_imp hhh_marital tc_core hhh_edu_level_g hhh_literacy housingtype tenure lhood idp water_home hhwater tenure sanitation phone_network rooms_n" 
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match using) keep(match) keepusing(`mergevars')
*clean up
replace hhwater=5 if water_home==1 
label define hhwater 4 "Purchased" 5 "Piped into dwelling", modify
replace sanitation=1 if sanitation==2
recode lhood (1 2 3 = 1 "Agriculture") (4 = 4 "Wages and salaries") (5 = 5 "Own business") ( nonmissing = 10 "Remittances/Aid/Other") , gen(livelihood)
label var livelihood "Livelihood"
recode hhh_edu_level_g (1=0 "No education") (2 5=1 "Primary") (3=2 "Secondary") (4=3 "Tertiary") (0=.), gen(hhh_edu_levels)
label var hhwater "Household water source"
gen own_house=tenure==1 
label val own_house lyn
label var own_house "Owns dwelling"
*replace some deprivation variables as their opposite to facilitate interpretation
foreach v of varlist phone_network electricity {
	replace `v'=`v'==0 if !missing(`v')
}
label var electricity "Household has access to electricity"
label var phone_network "Telephone network at the household"
recode housingtype (1= 1 "Tent") (3 4=2 "Tukul/gottiya") (5 6 8 10=4 "Concrete/brick house") (7 10=3 "Mud/wood hut") (nonmissing=.), gen(house)
gen widowed_fhhh=hhh_marital==4 & hhh_gender==1
label var widowed_fhhh "Household head is female divorced/widow"
drop water_home hhh_marital tenure hhh_edu_level_g lhood memperroom housing cook housingtype crowding tvsat radio mobile_phone computer cartruck motorcycleshaw bicycle information transportation assets living_standards education wash deprivations deprivations2 mpi improved_sanitation_i improved_watersource_i housing_i electricity_i mpi_np mpi_poor
*merge with hhm variables
merge 1:1 wave state ea hh using "${gsdTemp}/hhm_pmt.dta", nogen  assert(match using) keep(match)
*replace missing as median
mdesc
ds 
quietly foreach v in `r(varlist)' {
	su `v', detail
	replace `v'=r(p50) if missing(`v')
}
*merge and clean assets data
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/assets_analysis_wide.dta", nogen assert(match master using) keep(match master)
local assets = "Cars Trucks Motorcycle_motor Rickshaw Bicycle Canoe_boat Plough Television Satellite_dish DVD_CD_player Radio_transistor Mobile_phone Computer_laptop Refrigerator Washing_machine Fan Air_cooler_air_conditioner Mattress_or_bed Mosquito_net Electric_ironer Hoe_spade_axe"
foreach v of local assets {
	quietly replace `v'=!missing(`v')
}
*create ownership indices
gen CarTruck=(Cars==1 | Trucks==1)
gen MotoRick=(Motorcycle_motor==1 | Rickshaw==1)
gen TVSatDvd=(Television==1 | Satellite_dish==1 | Radio_transistor==1)
local assets = "CarTruck MotoRick Bicycle TVSatDvd Radio_transistor Mobile_phone Computer_laptop Refrigerator Fan  Mattress_or_bed Mosquito_net Hoe_spade_axe"
label var CarTruck "Owns Car/Truck" 
label var MotoRick "Owns Motorbike/Rickshaw" 
label var TVSatDvd "Owns TV/Satellite Dish/CD-DVD player" 
label var Mobile_phone "Owns Mobile phone" 
label var Mattress_or_bed "Owns Mattress/bed" 
label var Mosquito_net "Owns Mosquito net" 
label var Hoe_spade_axe "Owns Hoe/Spade/Axe" 
drop Cars Trucks Motorcycle_motor Rickshaw Canoe_boat Plough Television Satellite_dish DVD_CD_player Refrigerator Washing_machine Fan Air_cooler_air_conditioner Electric_ironer 
*create log consumption
gen ltcore=ln(tc_core)
*Redefine poverty line and poverty variable
gen ratio=tc_core/tc_imp
gen pline_core=.
gen pline125_core=.
quietly forvalues w=1(2)3 {
	su ratio [aw=pweight] if wave==`w', meanonly 
	replace pline_core=r(mean)*plinePPP if wave==`w'
	replace pline125_core=r(mean)*pline125PPP if wave==`w'
}
gen poor_core=tc_core<pline_core 
gen poor125_core=tc_core<pline125_core
label val poor*_core lpoor
label var poor_core "Poor, core consumption"
label var poor125_core "Extreme poor, core consumption"
*set survey
svyset ea [pw=weight], strata(stratum)
svy: tab poor_core wave, col
svy: tab poor poor_core , col
save "${gsdData}/1-CleanTemp/pmt.dta", replace

*Create the different PMTs
use "${gsdData}/1-CleanTemp/pmt.dta", clear
svyset ea [pw=pweight], strata(stratum)
keep if inlist(wave,3)
local d = "hhh_gender hhsize small_child_share child_share elderly_share i.head_marital "
local s = "own_house phone_network electricity i.sanitation i.hhwater i.house"
local e = "child_noed i.hhh_edu_levels"
local l = "i.livelihood"
local a = "CarTruck TVSatDvd MotoRick Radio_transistor Mobile_phone Mattress_or_bed Mosquito_net Hoe_spade_axe"
local extended_model="urban `d' `s' `e' `l' `a' i.state"
local basic_pmt = "urban hhh_gender hhsize small_child_share child_share i.sanitation i.house CarTruck TVSatDvd Radio MotoRick Mattress_or_bed Mosquito_net i.state"
*normal model 
reg  ltcore `extended_model' 
outreg2 using "${gsdOutput}/regressions_PMT.xls", replace ctitle(OLS extended) label nocons
predict pscore_pmt_ext
predict residuals, residuals
*graph it
twoway (sc  ltcore pscore_pmt_ext ) (lfitci  ltcore pscore_pmt_ext, ciplot(rline)) 
twoway (sc  ltcore residuals ) (lfitci  ltcore residuals, ciplot(rline)) 
reg ltcore pscore_pmt
reg ltcore residuals
drop residuals
*basic PMT
reg ltcore `basic_pmt'
predict pscore_pmt_basic
twoway (sc  ltcore pscore_pmt_basic ) (lfitci  ltcore pscore_pmt_basic, ciplot(rline))
reg ltcore pscore_pmt_basic
*poverty weighted least squares
reg ltcore `extended_model' if poor_core==1
predict pscore_pwls_ext
reg ltcore `basic_pmt' if poor_core==1
predict pscore_pwls_basic
*poverty weighted least squares + nearpoor (10 percent)
xtile pct=tc_core  [pw=pweight], nq(100)
reg ltcore `extended_model' if pct<92
predict pscore_pnp_ext
reg ltcore `basic_pmt' if pct<92
predict pscore_pnp_basic
*quantile 
qreg ltcore `extended_model' [pw=pweight], quantile(.82)
predict pscore_qnt_ext
qreg ltcore `basic_pmt' [pw=pweight], quantile(.82)
predict pscore_qnt_basic
*stepwise regression with the main model
*remove factor variables
quietly foreach v of varlist sanitation hhwater house head_marital livelihood state hhh_edu_levels {
	tab `v', gen(`v'_new_)
	drop `v'_new_1
}
local d = "hhh_gender hhsize small_child_share child_share elderly_share head_marital_* "
local s = "own_house phone_network electricity sanitation_* hhwater_* house_*"
local e = "child_noed hhh_edu_levels_*"
local l = " livelihood_*"
local a = "CarTruck TVSatDvd MotoRick Radio_transistor Mobile_phone Mattress_or_bed Mosquito_net Hoe_spade_axe"
local stewpise="urban `d' `s' `e' `l' `a' state_*"
stepwise, pr(.1): reg  ltcore `stewpise' 
predict pscore_stepwise_b
stepwise, pe(.1): reg  ltcore `stewpise' 
predict pscore_stepwise_f
drop *_new_*
***create inclusion and exlusion error 
*four main specifications
foreach model in pmt pwls pnp qnt {
	foreach type in basic ext {
		gen targeted_`model'_`type'=pscore_`model'_`type'<ln(pline_core)
		gen inclusion_error_`model'_`type'=(targeted_`model'_`type'==1) if poor_core==0
		gen exclusion_error_`model'_`type'=(targeted_`model'_`type'==0) if poor_core==1
	}
}
*stepwise regression
foreach type in b f {
	gen targeted_stepwise_`type'=pscore_stepwise_`type'<ln(pline_core)
	gen inclusion_error_stepwise_`type'=(targeted_stepwise_`type'==1) if poor_core==0
	gen exclusion_error_stepwise_`type'=(targeted_stepwise_`type'==0) if poor_core==1
}
*define local for tabout INCLUSION ERRORS
local table=""
foreach v of varlist   inclusion_error_*_basic inclusion_error_*_ext {
	local table="`table' mean `v'"
}
local table="`table' mean inclusion_error_stepwise_b mean inclusion_error_stepwise_f"
display "`table'"
qui tabout urban using "${gsdOutput}/Raw-Data PMT.xls" [aw=pweight], oneway sum c(`table') npos(col) f(4) replace sebnone h2("Incl. errors")
*define local for tabout EXCLUSION ERRORS
local table=""
foreach v of varlist   exclusion_error_*_basic exclusion_error_*_ext {
	local table="`table' mean `v'"
}
local table="`table' mean exclusion_error_stepwise_b mean exclusion_error_stepwise_f"
display "`table'"
qui tabout urban using "${gsdOutput}/Raw-Data PMT.xls" [aw=pweight], oneway sum c(`table') npos(col) f(4) append sebnone h2("Excl. errors")


*PMT model estimated in 2015 used on 2016 data
use "${gsdData}/1-CleanTemp/pmt.dta", clear
svyset ea [pw=pweight], strata(stratum)
keep if inlist(wave,1,3)
local d = "hhh_gender hhsize small_child_share child_share elderly_share i.head_marital "
local s = "own_house phone_network electricity i.sanitation i.hhwater i.house"
local e = "child_noed i.hhh_edu_levels"
local l = "i.livelihood"
local a = "CarTruck TVSatDvd MotoRick Radio_transistor Mobile_phone Mattress_or_bed Mosquito_net Hoe_spade_axe"
local extended_model="urban `d' `s' `e' `l' `a' i.state"
local basic_pmt = "urban hhh_gender hhsize small_child_share child_share i.sanitation i.house CarTruck TVSatDvd Radio MotoRick Mattress_or_bed Mosquito_net i.state"
*normal model 
reg  ltcore `extended_model'  if wave==1
outreg2 using "${gsdOutput}/regressions_PMT.xls", replace ctitle(OLS extended) label nocons
predict pscore_pmt_ext 
predict residuals, residuals
*basic PMT
reg ltcore `basic_pmt' if wave==1
predict pscore_pmt_basic
reg ltcore pscore_pmt_basic
*poverty weighted least squares
reg ltcore `extended_model' if poor_core==1 & wave==1
predict pscore_pwls_ext
reg ltcore `basic_pmt' if poor_core==1 & wave==1
predict pscore_pwls_basic
*poverty weighted least squares + nearpoor (10 percent)
xtile pct=tc_core  [pw=pweight], nq(100)
reg ltcore `extended_model' if pct<92 & wave==1
predict pscore_pnp_ext
reg ltcore `basic_pmt' if pct<92 & wave==1
predict pscore_pnp_basic
*quantile 
qreg ltcore `extended_model' if wave==1, quantile(.82)
predict pscore_qnt_ext
qreg ltcore `basic_pmt'  if wave==1, quantile(.82)
predict pscore_qnt_basic
*stepwise regression with the main model
*remove factor variables
quietly foreach v of varlist sanitation hhwater house head_marital livelihood state hhh_edu_levels {
	tab `v', gen(`v'_new_)
	drop `v'_new_1
}
local d = "hhh_gender hhsize small_child_share child_share elderly_share head_marital_* "
local s = "own_house phone_network electricity sanitation_* hhwater_* house_*"
local e = "child_noed hhh_edu_levels_*"
local l = " livelihood_*"
local a = "CarTruck TVSatDvd MotoRick Radio_transistor Mobile_phone Mattress_or_bed Mosquito_net Hoe_spade_axe"
local stewpise="urban `d' `s' `e' `l' `a' state_*"
stepwise, pr(.1): reg  ltcore `stewpise'  if wave==1
predict pscore_stepwise_b
stepwise, pe(.1): reg  ltcore `stewpise'  if wave==1
predict pscore_stepwise_f
drop *_new_*
***create inclusion and exlusion error 
drop if wave==1
*four main specifications
foreach model in pmt pwls pnp qnt {
	foreach type in basic ext {
		gen targeted_`model'_`type'=pscore_`model'_`type'<ln(pline_core)
		gen inclusion_error_`model'_`type'=(targeted_`model'_`type'==1) if poor_core==0
		gen exclusion_error_`model'_`type'=(targeted_`model'_`type'==0) if poor_core==1
	}
}
*stepwise regression
foreach type in b f {
	gen targeted_stepwise_`type'=pscore_stepwise_`type'<ln(pline_core)
	gen inclusion_error_stepwise_`type'=(targeted_stepwise_`type'==1) if poor_core==0
	gen exclusion_error_stepwise_`type'=(targeted_stepwise_`type'==0) if poor_core==1
}
*define local for tabout INCLUSION ERRORS
local table=""
foreach v of varlist   inclusion_error_*_basic inclusion_error_*_ext {
	local table="`table' mean `v'"
}
local table="`table' mean inclusion_error_stepwise_b mean inclusion_error_stepwise_f"
display "`table'"
qui tabout urban using "${gsdOutput}/Raw-Data PMT.xls" [aw=pweight], oneway sum c(`table') npos(col) f(4) append sebnone h2("Incl. errors Wave 1")
*define local for tabout EXCLUSION ERRORS
local table=""
foreach v of varlist   exclusion_error_*_basic exclusion_error_*_ext {
	local table="`table' mean `v'"
}
local table="`table' mean exclusion_error_stepwise_b mean exclusion_error_stepwise_f"
display "`table'"
qui tabout urban using "${gsdOutput}/Raw-Data PMT.xls" [aw=pweight], oneway sum c(`table') npos(col) f(4) append sebnone h2("Excl. errors Wave 3")


*save social protection analysis dataset
keep dataset wave stratum urban state ea hh weight pweight hhsize poor pscore* tc_core plinePPP pline125PPP pline*_core poor*_core ltcore  small_child elderly disabled child_6to10 child_11to15 widowed_fhhh
save "${gsdTemp}/social_protection_raw.dta", replace
graph close
*place raw data into the excel figures file
insheet using "${gsdOutput}/Raw-Data PMT.xls", clear nonames
export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data PMT") 
rm "${gsdOutput}/Raw-Data PMT.xls"

