*this do file conducts the social safety net analysis

*use the 100 extracted multiple imputations of consumption data to model the transfers
use "${gsdTemp}/social_protection_raw.dta", clear
svyset ea [pw=pweight], strata(stratum)
*revise weights by population growth (WB estimates, the 2008 figure is higher than the Census figures) 
*	divide by 100 to account for imputations
replace  pweight=pweight*(12230730/9263136)*1/100
*merge with mi-extract data to model the transfers
merge 1:m state ea hh using "${gsdW3}/Data/1-CleanOutput/mi-extract.dta", nogen assert(match using) keep(match)
*revise monetary amounts from mi-extract to 2017 SSPs for interpretation
local monetary = "tc_imp mi_cons_f mi_cons_nf mi_cons_d"
quietly foreach v of local monetary {
	*bring prices to July 2017: CPI = 3355.756; in July 2015 was = 239.91; Ratio = 13.988
	replace `v'= (`v' * 13.988)
	local oldname : variable label `v' 
	local newname =  substr("`oldname'",1,length("`oldname'")-8)
	label var `v' "`newname' 2017 SSP"
} 
assert round(mi_cons_f+mi_cons_nf+mi_cons_d)==round(tc_imp)
svy: mean `monetary' tc_core plinePPP pline125PPP
drop hhsleep hhwater mod_hh hhlight cons_f0 cons_f1 cons_f2 cons_f3 cons_f4 cons_nf0 cons_nf1 cons_nf2 cons_nf3 cons_nf4 cons_d food_cons_defl nonfood_cons_defl hhsex hhempl pchild psenior hhtoilet mi_cons_f0 mi_cons_nf0 mi_cons_f1 mi_cons_nf1 mi_cons_f2 mi_cons_nf2 mi_cons_f3 mi_cons_nf3 mi_cons_f4 mi_cons_nf4 mi_cons_d pmi_cons_f0 pmi_cons_nf0 pmi_cons_d mi_cons_f mi_cons_nf cons_f cons_nf tc_summ pline31PPP poor31PPP_prob mi
*calculate extreme poverty gap
local line="plinePPP"
gen gap = (`line' - tc_imp)/`line'
replace gap = 0 if (tc_imp>`line')
*get total gap in monetary amount
gen x=gap*`line'
mean x [pw=pweight]
gen gap_value=_b[x]
label var gap_value "Average EXTREME poverty gap in 2017 SSP"
order gap gap_value, before(`line')
drop x
save "${gsdData}/1-CleanTemp/social_protection.dta", replace

*calculate a few general poverty stats
use "${gsdData}/1-CleanTemp/social_protection.dta", clear
*basic stats
*Exchange rate based on average commercial exchange rate collected in July 2017
local er_sspusd=134
quietly mean tc_imp gap `line' [pw=pweight]
display "BENCHMARK: poverty line per capita per day in 2017 SSP:" %12.0f _b[`line'] "   ;per year:"  %12.0f _b[`line']*365
display "Mean consumption value per capita per day in 2017 SSP:" %12.0f _b[tc_imp] "   ;per year:"  %12.0f _b[tc_imp]*365
display "Mean gap value per capita per day in 2017 SSP:" %12.0f (1/2)*_b[gap]*_b[`line'] "   ;per year:"  %12.0f (1/2)*_b[gap]*_b[`line']*365
display "Mean gap value per capita per day in USD: "  %12.2f _b[gap]*_b[`line']/`er_sspusd' "   ;per year:"  %12.0f (1/2)*_b[gap]*_b[`line']*365/`er_sspusd'
quietly svy: total gap_value , cformat(%12.0g)
display "Total yearly poverty gap in SSP million: "  %12.0f _b[gap_value]*365/1000000 "   ;in USD million:"  %12.0f _b[gap_value]*365/`er_sspusd'/1000000


*define transfer size
local transfer="gap_value"
local transfer_dem = "1.5*gap_value"
local pline = "plinePPP"
local poor= "poorPPP_prob"

*calculate poverty reduction impact of programs
*** Perfect Targeting
use "${gsdData}/1-CleanTemp/social_protection.dta", clear
*identify targeted households
gen targeted_pt=`poor'
*create new consumption value after transfer
gen tc_ssn_pt=tc_imp
gen transfer_pt=`transfer' if targeted_pt==1
replace tc_ssn_pt=tc_imp+transfer_pt if targeted_pt==1
*calculate poverty after transfer
gen poor_ssn_pt=(tc_ssn_pt<plinePPP)
qui tabout poor_ssn_pt urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) replace sebnone h2("HC190 PT")
gen poor125_ssn_pt=(tc_ssn_pt<pline125PPP)
qui tabout poor125_ssn_pt urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("HC125 PT")
*calculate gap after transfer
gen gap_ssn_pt = (plinePPP - tc_ssn_pt)/plinePPP 
replace gap_ssn_pt = 0 if (tc_ssn_pt>plinePPP )
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean gap_ssn_pt se lb ub) npos(col) f(4) append sebnone h2("Gap PT")
*gen severity
gen severity_ssn_pt = (gap_ssn_pt)^2
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean severity_ssn_pt se lb ub) npos(col) f(4) append sebnone h2("Severity PT")
*calculate total cost of the program
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls" [aw=pweight], sum oneway c(sum transfer_pt) npos(col) f(4) append sebnone h2("Total cost PT")


*** PMT - poor
use "${gsdData}/1-CleanTemp/social_protection.dta", clear
*created pmt targeted variable as ratio of core poverty line of actual poverty line
gen pline_pmt=ln((`pline'/plinePPP)*pline_core)
gen targeted_pmt=pscore_pmt_ext<pline_pmt
*create new consumption value after transfer
gen tc_ssn_pmt=tc_imp
gen transfer_pmt=`transfer' if targeted_pmt==1
replace tc_ssn_pmt=tc_imp+transfer_pmt if targeted_pmt==1	
*calculate poverty after transfer
gen poor_ssn_pmt=(tc_ssn_pmt<plinePPP)
qui tabout poor_ssn_pmt urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("HC190 PMT")
gen poor125_ssn_pmt=(tc_ssn_pmt<pline125PPP)
qui tabout poor125_ssn_pmt urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("HC125 PMT")
*calculate gap after transfer
gen gap_ssn_pmt = (plinePPP - tc_ssn_pmt)/plinePPP 
replace gap_ssn_pmt = 0 if (tc_ssn_pmt>plinePPP )	
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean gap_ssn_pmt se lb ub) npos(col) f(4) append sebnone h2("Gap PMT")
*gen severity
gen severity_ssn_pmt = (gap_ssn_pmt)^2
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean severity_ssn_pmt se lb ub) npos(col) f(4) append sebnone h2("Severity PMT")
*errors
gen inclusion_error_pmt=(targeted_pmt==1) if poor_core==0
qui tabout inclusion_error_pmt urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("Incl. error PMT")
gen exclusion_error_pmt=(targeted_pmt==0) if poor_core==1
qui tabout exclusion_error_pmt urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("Excl. error PMT")
*calculate total cost of the program 
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls" [aw=pweight], sum oneway c(sum transfer_pmt) npos(col) f(4) append sebnone h2("Total cost PMT")
*calculate program coverage
gen pweight_poor=pweight if poor_core==1	
gen pweight_poor_covered=pweight if poor_core==1 & targeted_pmt==1
*calculate average yearly transfer to households
gen transfer_yearly_pmt=transfer_pmt*365.25
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", sum oneway c(sum pweight sum pweight_poor sum pweight_poor_covered mean transfer_yearly_pmt) npos(col) f(4) append sebnone h2("Coverage PMT")

*** Demographic Targeting - 0-15 years old
use "${gsdData}/1-CleanTemp/social_protection.dta", clear
egen children=rowtotal(small_child child_6to10 child_11to15)
*remove the additional characteristics in widowed households (they get the grant anyways because of the widowed head)
replace children=0 if widowed_fhhh==1
replace elderly=0 if widowed_fhhh==1
replace disabled=0 if widowed_fhhh==1
gen widowed_hhsize=widowed_fhhh*hhsize
*add the number of recipients together
egen targeted_dem=rowtotal(children disabled elderly widowed_hhsize)
*calculate ratio of targeted to household to adjust the size of the transfer (which is calculated per capita)
gen ratio=targeted_dem/hhsize
replace ratio=0 if targeted_dem==0
gen transfer_dem=`transfer_dem'*ratio
*create new consumption value after transfer
gen tc_ssn_dem=tc_imp
replace tc_ssn_dem=tc_imp+transfer_dem
*calculate poverty after transfer
gen poor_ssn_dem=(tc_ssn_dem<plinePPP)
qui tabout poor_ssn_dem urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("HC190 Dem. 0-15")
gen poor125_ssn_dem=(tc_ssn_dem<pline125PPP)
qui tabout poor125_ssn_dem urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("HC125 Dem. 0-15")
*calculate gap after transfer
gen gap_ssn_dem = (plinePPP - tc_ssn_dem)/plinePPP 
replace gap_ssn_dem = 0 if (tc_ssn_dem>plinePPP )
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean gap_ssn_dem se lb ub) npos(col) f(4) append sebnone h2("Gap Dem. 0-15")
*gen severity
gen severity_ssn_dem = (gap_ssn_dem)^2
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean severity_ssn_dem se lb ub) npos(col) f(4) append sebnone h2("Severity Dem.")
*errors
gen inclusion_error_dem=(targeted_dem!=0) if poor_core==0
qui tabout inclusion_error_dem urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("Incl. error Dem. 0-15")
gen exclusion_error_dem=(targeted_dem==0) if poor_core==1
qui tabout exclusion_error_dem urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("Excl. error Dem 0-15.")
*calculate total cost of the program 
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls" [aw=pweight], sum oneway c(sum transfer_dem) npos(col) f(4) append sebnone h2("Total cost Dem. 0-15")
*calculate program coverage
gen pweight_poor=pweight if poor==1
gen pweight_poor_covered=pweight if poor==1 & targeted_dem!=0
gen pweight_dem_covered=pweight if targeted_dem!=0
*calculate average yearly transfer to households
gen transfer_yearly_dem=transfer_dem*365.25
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", sum oneway c(sum pweight sum pweight_poor sum pweight_poor_covered sum pweight_dem_covered mean transfer_yearly_dem) npos(col) f(4) append sebnone h2("Coverage Dem 0-15")

*** Geographic targeting - 80 percent poorest counties
*first determine the targeted counties
import excel using "${gsdDataRaw}/SSD_PoorPPPprobability_imputation_popweighted_bycounty_TableToExcel.xls", clear first
keep if !inlist(STATNAME,"Warrap","Jonglei","Unity","Upper Nile")
*target the 80% poorest
gsort -AvgPov_Co 
local county_num = _N
local percent_targeted = .80
display `percent_targeted'*`county_num'
gen targeted_geo=_n<=(`percent_targeted'*`county_num')
tab targeted_geo
tab county targeted_geo
rename (STATNAME county Pop_Count AvgPov_Co SumPopPov) (State County pop_total poverty_sat pop_poor)
replace State=strupper(State)
replace County=strupper(County)
replace County="LAFON/LOPA" if County=="LOPA"
keep State County pop_total poverty_sat pop_poor targeted_geo
order State County pop_total pop_poor poverty_sat targeted_geo 
save "${gsdTemp}/hfs_satellite_counties.dta", replace
*merge with conflict data
use "${gsdData}/1-CleanTemp/social_protection.dta", clear
merge m:1 wave state ea hh using  "${gsdTemp}/conflict_indicators.dta", nogen assert(match using master) keep(match) keepusing( State County)
merge m:1 State County using "${gsdTemp}/hfs_satellite_counties.dta", nogen assert(match using) keep(match master)
*create new consumption value after transfer
gen tc_ssn_geo=tc_imp
local transfer = "gap_value"
gen transfer_geo=`transfer' if targeted_geo==1
replace tc_ssn_geo=tc_imp+transfer_geo if targeted_geo==1
*calculate poverty after transfer
gen poor_ssn_geo=(tc_ssn_geo<plinePPP)
qui tabout poor_ssn_geo urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("HC190 Geo")
gen poor125_ssn_geo=(tc_ssn_geo<pline125PPP)
qui tabout poor125_ssn_geo urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("HC125 Geo")
*calculate gap after transfer
gen gap_ssn_geo = (plinePPP - tc_ssn_geo)/plinePPP 
replace gap_ssn_geo = 0 if (tc_ssn_geo>plinePPP )
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean gap_ssn_geo se lb ub) npos(col) f(4) append sebnone h2("Gap Geo")
*gen severity
gen severity_ssn_geo = (gap_ssn_geo)^2
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean severity_ssn_geo se lb ub) npos(col) f(4) append sebnone h2("Severity Geo")
*errors
gen inclusion_error_geo=(targeted_geo!=0) if poor_core==0
qui tabout inclusion_error_geo urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("Incl. error Geo")
gen exclusion_error_geo=(targeted_geo==0) if poor_core==1
qui tabout exclusion_error_geo urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("Excl. error Geo")
*calculate total cost of the program 
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls" [aw=pweight], sum oneway c(sum transfer_geo) npos(col) f(4) append sebnone h2("Total cost Geo")
*calculate program coverage
gen pweight_poor=pweight if poor==1
gen pweight_poor_covered=pweight if poor==1 & targeted_geo!=0
gen pweight_geo_covered=pweight if targeted_geo!=0
*calculate average yearly transfer to households
gen transfer_yearly_geo=transfer_geo*365.25
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", sum oneway c(sum pweight sum pweight_poor sum pweight_poor_covered sum pweight_geo_covered mean transfer_yearly_geo) npos(col) f(4) append sebnone h2("Coverage Geo")


*** Basic income
*create new consumption value after transfer
gen tc_ssn_ubi=tc_imp
gen transfer_ubi=`transfer'
replace tc_ssn_ubi=tc_imp+transfer_ubi
*calculate cost of transfers
gen cost_ubi=transfer_ubi
format cost_ubi %12.0g
gen transfer_yearly_ubi=transfer_ubi*365.25
*calculate poverty after transfer
gen poor_ssn_ubi=(tc_ssn_ubi<plinePPP)
qui tabout poor_ssn_ubi urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("HC190 UBI. 0-15")
gen poor125_ssn_ubi=(tc_ssn_ubi<pline125PPP)
qui tabout poor125_ssn_ubi urban using "${gsdOutput}/Raw-Data 22.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("HC125 UBI. 0-15")
*calculate gap after transfer
gen gap_ssn_ubi = (plinePPP - tc_ssn_ubi)/plinePPP 
replace gap_ssn_ubi = 0 if (tc_ssn_ubi>plinePPP )
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean gap_ssn_ubi se lb ub) npos(col) f(4) append sebnone h2("Gap UBI. 0-15")
*calculate severity after transfer
gen severity_ssn_ubi = gap_ssn_ubi^2
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls", svy sum c(mean severity_ssn_ubi se lb ub) npos(col) f(4) append sebnone h2("Severity UBI.")
*calculate total cost of the program 
qui tabout urban using "${gsdOutput}/Raw-Data 22.xls" [aw=pweight], sum oneway c(sum transfer_ubi) npos(col) f(4) append sebnone h2("Total cost UBI. 0-15")

*place raw data into the excel figures file
insheet using "${gsdOutput}/Raw-Data 22.xls", clear nonames
export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data 22") 
rm "${gsdOutput}/Raw-Data 22.xls"




*define transfer size
local transfer="gap_value"
local transfer_dem = "1.5*gap_value"
local pline = "plinePPP"
local poor= "poorPPP_prob"

*Model programs at different sizes of transfers 
quietly forvalues n=.1(.1)3 {
	use "${gsdData}/1-CleanTemp/social_protection.dta", clear
	egen pop_total=total(pweight)
	
	*** Basic income
	*create new consumption value after transfer
	gen tc_ssn_ubi=tc_imp
	gen transfer_ubi=(`n'*`transfer') 
	replace tc_ssn_ubi=tc_imp+transfer_ubi
	*calculate cost of transfers
	gen cost_ubi=transfer_ubi*365.25
	format cost_ubi %12.0g
	gen transfer_yearly_ubi=transfer_ubi*365.25
	*calculate poverty after transfer
	gen poor_ssn_ubi=(tc_ssn_ubi<plinePPP)
	gen poor125_ssn_ubi=(tc_ssn_ubi<pline125PPP)
	*calculate gap after transfer
	gen gap_ssn_ubi = (plinePPP - tc_ssn_ubi)/plinePPP 
	replace gap_ssn_ubi = 0 if (tc_ssn_ubi>plinePPP )
	*calculate severity after transfer
	gen severity_ssn_ubi = gap_ssn_ubi^2
	
	*** Perfect Targeting
	*identify targeted households
	gen targeted_pt=poorPPP_prob
	*create new consumption value after transfer
	gen tc_ssn_pt=tc_imp
	gen transfer_pt=(`n'*`transfer') if targeted_pt==1
	replace tc_ssn_pt=tc_imp+transfer_pt if targeted_pt==1
	*calculate cost of transfers
	gen cost_pt=transfer_pt*365.25
	format cost_pt %12.0g
	gen transfer_yearly_pt=transfer_pt*365.25
	*calculate poverty after transfer
	gen poor_ssn_pt=(tc_ssn_pt<plinePPP)
	gen poor125_ssn_pt=(tc_ssn_pt<pline125PPP)
	*calculate gap after transfer
	gen gap_ssn_pt = (plinePPP - tc_ssn_pt)/plinePPP 
	replace gap_ssn_pt = 0 if (tc_ssn_pt>plinePPP )
	*calculate severity after transfer
	gen severity_ssn_pt = gap_ssn_pt^2
	
	*** PMT
	*created pmt targeted variable as ratio of core poverty line of actual poverty line
	gen pline_pmt=ln(pline_core)
	gen targeted_pmt=pscore_pmt_ext<pline_pmt
	*create new consumption value after transfer
	gen tc_ssn_pmt=tc_imp
	gen transfer_pmt=(`n'*`transfer') if targeted_pmt==1
	replace tc_ssn_pmt=tc_imp+transfer_pmt if targeted_pmt==1	
	*calculate cost of transfers
	gen cost_pmt=transfer_pmt*365.25
	format cost_pmt %12.0g	
	gen transfer_yearly_pmt=transfer_pmt*365.25
	*calculate poverty after transfer
	gen poor_ssn_pmt=(tc_ssn_pmt<plinePPP)
	gen poor125_ssn_pmt=(tc_ssn_pmt<pline125PPP)
	*calculate gap after transfer
	gen gap_ssn_pmt = (plinePPP - tc_ssn_pmt)/plinePPP 
	replace gap_ssn_pmt = 0 if (tc_ssn_pmt>plinePPP )	
	*calculate severity after transfer
	gen severity_ssn_pmt = gap_ssn_pmt^2
	
	*** Demographic Targeting
	egen children=rowtotal(small_child child_6to10 child_11to15)
	*remove the additional characteristics in widowed households (they get the grant anyways because of the widowed head)
	replace children=0 if widowed_fhhh==1
	replace elderly=0 if widowed_fhhh==1
	replace disabled=0 if widowed_fhhh==1
	gen widowed_hhsize=widowed_fhhh*hhsize
	*add the number of recipients together
	egen targeted_dem=rowtotal(children disabled elderly widowed_hhsize)
	*calculate ratio of targeted to household to adjust the size of the transfer (which is calculated per capita here)
	gen ratio=targeted_dem/hhsize
	replace ratio=0 if targeted_dem==0
	gen transfer_dem=(`n'*`transfer_dem')*ratio
	*create new consumption value after transfer
	gen tc_ssn_dem=tc_imp
	replace tc_ssn_dem=tc_imp+transfer_dem
	*calculate cost of transfers
	gen cost_dem=transfer_dem*365.25
	format cost_dem %12.0g
	gen transfer_yearly_dem=transfer_dem*365.25*ratio
	*calculate poverty after transfer
	gen poor_ssn_dem=(tc_ssn_dem<plinePPP)
	gen poor125_ssn_dem=(tc_ssn_dem<pline125PPP)
	*calculate gap after transfer
	gen gap_ssn_dem = (plinePPP - tc_ssn_dem)/plinePPP 
	replace gap_ssn_dem = 0 if (tc_ssn_dem>plinePPP )
	*calculate severity after transfer
	gen severity_ssn_dem = gap_ssn_dem^2
	
	*** Geographic targeting
	*identify targeted households
	merge m:1 wave state ea hh using  "${gsdTemp}/conflict_indicators.dta", nogen assert(match using master) keep(match) keepusing( State County)
	merge m:1 State County using "${gsdTemp}/hfs_satellite_counties.dta", nogen assert(match using) keep(match master)
	*create new consumption value after transfer
	gen tc_ssn_geo=tc_imp
	gen transfer_geo=(`n'*`transfer') if targeted_geo==1
	replace tc_ssn_geo=tc_imp+transfer_geo if targeted_geo==1
	*calculate cost of transfers
	gen cost_geo=transfer_geo*365.25
	format cost_geo %12.0g
	gen transfer_yearly_geo=transfer_geo*365.25
	*calculate poverty after transfer
	gen poor_ssn_geo=(tc_ssn_geo<plinePPP)
	gen poor125_ssn_geo=(tc_ssn_geo<pline125PPP)
	*calculate gap after transfer
	gen gap_ssn_geo = (plinePPP - tc_ssn_geo)/plinePPP 
	replace gap_ssn_geo = 0 if (tc_ssn_geo>plinePPP )
	*calculate severity after transfer
	gen severity_ssn_geo = (gap_ssn_geo)^2	

	*collapse into one row
	gen fraction_of_gap=`n'
	collapse fraction_of_gap poor_ssn_* poor125_ssn_* gap_ssn_* transfer_yearly_* (sum) cost_* (mean) severity_ssn_* [pw=pweight]
	save "${gsdTemp}/ssn_`n'_gap.dta", replace
}
use "${gsdTemp}/ssn_.1_gap.dta"
quietly forvalues n=.2(.1)3 {
	append using "${gsdTemp}/ssn_`n'_gap.dta"
}	
order *_pt *_pmt *_dem *_geo *_ubi, after(fraction_of_gap)
save "${gsdTemp}/ssn_programs_modeled.dta", replace
export excel using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("SSN - data") first(variables)

