*this do file creates consumption expenditure distributions and growth incidence curves for the poverty assessment

*create growth incidence curve data
*create HFS light datasets including only relevant data
forvalues n=1/4 {
	use  "${gsdData}/1-CleanTemp/hhq_analysis.dta", clear
	keep if dataset==2 & wave==`n'
	svyset ea [pw=pweight], strata(stratum)
	merge 1:1 wave state ea hh using "${gsdTemp}/adult_equivalent_hfs.dta", nogen assert(match using) keepusing(ae) keep(match)
	assert ae<=hhsize
	gen tc_imp_ae=((mi_cons_f+mi_cons_nf)*hhsize)/ae
	keep stratum wave state urban ea hh pweight tc_imp tc_imp_ae plinePPP pline125PPP hhsize ae
	save "${gsdTemp}/gicw`n'.dta", replace
}
*do the same for NBHS2009 data
use "${gsdNBHS}/NBHS_HH.dta", clear
keep if state>81
egen stratum=group(state urban)
gen pweight=hhweight*hhsize
svyset cluster [pw=pweight], strata(stratum)
replace urban=0 if urban==2
label define lurban 0 "Rural" 1 "Urban", modify
label val urban lurban
*rescale NBHS 2009 data upwards
* The 2009 PPP for SSD is 1/1.0858328
* Thus, to convert May 2009 SDG into July 2009 SSP we:
* do not convert since SSPs were introduced at par with SSPs when the currency was first introduced
* multiply by the SSD PPP conversion factor, and adjust for inflation (note: divide by 30 because NBHS data is monthly)
* CPI July 2017: 3355.756; May 2009
* = pcexpm/30 * 1.08 / 72.583*239.906
*gen tc_imp=pcexpm/30*1.08/72.583*239.906
gen tc_imp=pcexpm/30 * 1/72.583 * 3355.756
gen pline=72.94/30 * 1/72.583 * 3355.756
gen pline125=(1.25/1.9)*72.94/30 * 1/72.583 * 3355.756
keep stratum state cluster urban hhid pweight tc_imp pline pline125
gen tc_imp_ae=tc_imp
save "${gsdTemp}/gic2009.dta", replace
*create curves
local default_dir `c(pwd)'
cd "${gsdTemp}"
*2009-Wave3
use "${gsdTemp}/gic2009.dta", clear
gicurve using "${gsdTemp}/gicw3.dta" [aw=pweight], var1(tc_imp) var2(tc_imp) nograph np(100) ci(100) nograph out("gic2009w3.dta")  bands(50)
*2009-Wave1
use "${gsdTemp}/gic2009.dta", clear
gicurve using "${gsdTemp}/gicw1.dta" [aw=pweight], var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph out("gic2009w1.dta") minmax bands(50)
*Wave1-Wave3 
use "${gsdTemp}/gicw1.dta", clear
gicurve using "${gsdTemp}/gicw3.dta" [aw=pweight], var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph out("gicw1w3.dta")  bands(50)
*urban 2009 wave 3
use "${gsdTemp}/gic2009.dta", clear
gicurve using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph  out("gic2009w3_u.dta")  bands(50) 
*rural 2009 wave 3
use "${gsdTemp}/gic2009.dta", clear
gicurve using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==0, var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph out("gic2009w3_r.dta")  bands(50) 
*2009 wave 1
use "${gsdTemp}/gic2009.dta", clear
gicurve using "${gsdTemp}/gicw1.dta" [aw=pweight], var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph out("gic2009w1.dta")  bands(50)
*urban 2009 wave 1
use "${gsdTemp}/gic2009.dta", clear
gicurve using "${gsdTemp}/gicw1.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph out("gic2009w1_u.dta")  bands(50)
*rural 2009 wave 1
use "${gsdTemp}/gic2009.dta", clear
gicurve using "${gsdTemp}/gicw1.dta" [aw=pweight] if urban==0, var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph out("gic2009w1_r.dta")  bands(50)
*urban wave 1 wave 3
use "${gsdTemp}/gicw1.dta", clear
gicurve using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph out("gicw1w3_u.dta")  bands(50)
*rural wave 1 wave 3
use "${gsdTemp}/gicw1.dta", clear
gicurve using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==0, var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph out("gicw1w3_r.dta")  bands(50)
*urban wave 1 wave 4
use "${gsdTemp}/gicw1.dta", clear
gicurve using "${gsdTemp}/gicw4.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  np(100) ci(100) nograph out("gicw1w4.dta")  bands(50)
*change cd back
cd "`default_dir'"
*merge data and save to excel
use "${gsdTemp}/gic2009w3.dta", clear
drop gr_in_median mean_of_growth 
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gci2009w3 gci2009w3_h gci2009w3_l gr_in_mean_2009w3 gr_bt40_2009w3)
merge 1:1 pctl using "${gsdTemp}/gicw1w3.dta", nogen assert(match) keepusing(pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1)
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gciw1w3 gciw1w3_h gciw1w3_l gr_in_mean_w1w3 gr_bt40_w1w3)
merge 1:1 pctl using "${gsdTemp}/gic2009w3_u.dta", nogen assert(match) keepusing(pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1)
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gci2009w3_u gci2009w3_u_h gci2009w3_u_l gr_in_mean_2009w3_u gr_bt40_2009w3_u)
merge 1:1 pctl using "${gsdTemp}/gic2009w3_r.dta", nogen assert(match) keepusing(pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1)
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gci2009w3_r gci2009w3_r_h gci2009w3_r_l gr_in_mean_2009w3_r gr_bt40_2009w3_r)
merge 1:1 pctl using "${gsdTemp}/gic2009w1.dta", nogen assert(match) keepusing(pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1)
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gci2009w1 gci2009w1_h gci2009w1_l gr_in_mean_2009w1 gr_bt40_2009w1)
merge 1:1 pctl using "${gsdTemp}/gic2009w1_u.dta", nogen assert(match) keepusing(pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1)
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gci2009w1_u gci2009w1_u_h gci2009w1_u_l gr_in_mean_2009w1_u gr_bt40_2009w1_u)
merge 1:1 pctl using "${gsdTemp}/gic2009w1_r.dta", nogen assert(match) keepusing(pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1)
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gci2009w1_r gci2009w1_r_h gci2009w1_r_l gr_in_mean_2009w1_r gr_bt40_2009w1_r)
merge 1:1 pctl using "${gsdTemp}/gicw1w3_u.dta", nogen assert(match) keepusing(pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1)
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gciw1w3_u gciw1w3_u_h gciw1w3_u_l gr_in_mean_w1w3_u gr_bt40_w1w3_u)
merge 1:1 pctl using "${gsdTemp}/gicw1w3_r.dta", nogen assert(match) keepusing(pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1)
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gciw1w3_r gciw1w3_r_h gciw1w3_r_l gr_in_mean_w1w3_r gr_bt40_w1w3_r)
merge 1:1 pctl using "${gsdTemp}/gicw1w4.dta", nogen assert(match) keepusing(pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1)
rename (pr_growth pg_ci_u pg_ci_l gr_in_mean intgrl1) (gciw1w4 gciw1w4_h gciw1w4_l gr_in_mean_w1w4 gr_bt40_w1w4)
save "${gsdData}/1-CleanTemp/GIC.dta", replace
export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data 2-2") first(variables)

*lorenz curves
use "${gsdTemp}/gic2009.dta", clear
gen wave=0
append using "${gsdTemp}/gicw1.dta"
replace wave=1 if missing(wave)
append using "${gsdTemp}/gicw3.dta"
replace wave=3 if missing(wave)
replace pline=plinePPP if wave!=0
*lorenz curves
*glcurve tc_imp [aw=pweight],  by(wave)  split //gl(glw) p(pw)
glcurve tc_imp_ae [aw=pweight], lorenz plot(function equality = x) by(wave) split gl(glw) p(pw) nograph
*tip curve
*glcurve tc_imp [aw=pweight], rtip(pline) by(wave) split gl(tipw) p(tipw) nograph
glcurve tc_imp [aw=pweight], atip(pline) by(wave) split gl(tipw) p(tipw) nograph
*create smaller number of quantiles
gen p=floor(pw*10000)
collapse glw_* tipw_*, by(p)
sort p
export excel p glw_0 glw_1 glw_3 tipw_0 tipw_1 tipw_3 using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("Raw-Data 2-3") first(variables) cell(B1)
*lorenz curves in 2016 urban-rural
use  "${gsdTemp}/gicw3.dta", clear
*lorenz curves
*glcurve tc_imp [aw=pweight],  by(wave)  split //gl(glw) p(pw)
glcurve tc_imp_ae [aw=pweight], lorenz plot(function equality = x) by(urban) split gl(glu) p(pu) nograph
*create smaller number of quantiles
gen p=floor(pu*10000)
collapse glu_* , by(pu)
sort p
export excel pu glu_0 glu_1 using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("Raw-Data 2-3") first(variables) cell(I1)

*analyze consumption changes & graph consumption densities
use "${gsdTemp}/gic2009.dta", clear
append using "${gsdTemp}/gicw1.dta", 
append using "${gsdTemp}/gicw3.dta", 
replace ea=cluster if missing(ea)
replace wave=0 if missing(wave)
label define lwave 0 "NBHS" , modify
replace hh=hhid if missing(hh)
drop cluster hhid plinePPP
svyset ea [pw=pweight], strata(stratum)
*change in mean
svy: mean tc_imp, over(wave)
lincom [tc_imp]NBHS - [tc_imp]Wave3
lincom [tc_imp]NBHS - [tc_imp]Wave1
lincom [tc_imp]Wave1 - [tc_imp]Wave3
*per strata
svy: mean tc_imp, over(wave urban)
lincom [tc_imp]_subpop_2 - [tc_imp]_subpop_6
display "average income change between 2009 and 2016 in urban areas:  " ([tc_imp]_subpop_2 - [tc_imp]_subpop_6)/[tc_imp]_subpop_2
lincom [tc_imp]_subpop_1 - [tc_imp]_subpop_5
display "average income change between 2009 and 2016 in rural areas:  " ([tc_imp]_subpop_1 - [tc_imp]_subpop_5)/[tc_imp]_subpop_1
*test difference in changes
lincom (([tc_imp]_subpop_2 - [tc_imp]_subpop_6)) - (([tc_imp]_subpop_1 - [tc_imp]_subpop_5))
svy: reg tc_imp i.wave##i.urban if inlist(wave,0,3)
testparm i.wave##i.urban
*growth rate of consumption between waves 1 and 3
quietly svy: mean tc_imp, over(wave urban)
lincom [tc_imp]_subpop_2 - [tc_imp]_subpop_6
display "average income change between 2009 and 2015 in urban areas:  " ([tc_imp]_subpop_1 - [tc_imp]_subpop_3)/[tc_imp]_subpop_1
lincom [tc_imp]_subpop_1 - [tc_imp]_subpop_5
display "average income change between 2009 and 2015 in rural areas:  " ([tc_imp]_subpop_2 - [tc_imp]_subpop_4)/[tc_imp]_subpop_2
lincom [tc_imp]_subpop_2 - [tc_imp]_subpop_6
display "average income change between 2015 and 2016 in urban areas:  " ([tc_imp]_subpop_3 - [tc_imp]_subpop_5)/[tc_imp]_subpop_3
lincom [tc_imp]_subpop_1 - [tc_imp]_subpop_5
display "average income change between 2015 and 2016 in rural areas:  " ([tc_imp]_subpop_4 - [tc_imp]_subpop_6)/[tc_imp]_subpop_4
*growth rate of consumption CAGR
quietly svy: mean tc_imp, over(wave)
display "CAGR of consumption between 2009 and wave 1:  " ([tc_imp]Wave1/[tc_imp]NBHS)^(1/6)-1
display "CAGR of consumption between 2009 and wave 3:  " ([tc_imp]Wave3/[tc_imp]NBHS)^(1/7)-1
quietly svy: mean tc_imp, over(wave urban)
display "CAGR of consumption between 2009 and wave 1 urban:  " ([tc_imp]_subpop_4/[tc_imp]_subpop_2)^(1/6)-1
display "CAGR of consumption between 2009 and wave 1 rural:  " ([tc_imp]_subpop_3/[tc_imp]_subpop_1)^(1/6)-1

*consumption distributions
kdensity tc_imp if wave==0 & tc_imp<1000  [aw=pweight] , nograph gen(x distr2009 )
kdensity tc_imp if wave==1 & tc_imp<1000  [aw=pweight]  , nograph at(x) gen(distr2015 )
kdensity tc_imp if wave==3 & tc_imp<1000  [aw=pweight]  , nograph at(x) gen(distr2016 )
kdensity tc_imp if wave==3 & urban==1 & tc_imp<1000  [aw=pweight]  , nograph at(x) gen(distr2016urb )
kdensity tc_imp if wave==3 & urban==0 & tc_imp<1000  [aw=pweight]  , nograph at(x) gen(distr2016rur )
label var distr2009 "2009"
label var distr2015 "2015"
label var distr2016 "2016"
export excel x distr* using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("Distributions-2") first(varl) cell(A1)
*graph
twoway (kdensity tc_imp if wave==0) (kdensity tc_imp if wave==1) (kdensity tc_imp if wave==3) if tc_imp<450 & urban==1 , legend(order(1 "2009" 2 "2015" 3 "2016"))
twoway (kdensity tc_imp if wave==0) (kdensity tc_imp if wave==1) (kdensity tc_imp if wave==3) if tc_imp<450 & urban==0 , legend(order(1 "2009" 2 "2015" 3 "2016"))
*poverty gap distribution
use "${gsdTemp}/gic2009.dta", clear
gen wave=0
append using "${gsdTemp}/gicw1.dta"
replace wave=1 if missing(wave)
append using "${gsdTemp}/gicw3.dta"
replace wave=3 if missing(wave)
replace pline=plinePPP if wave!=0
*calculate gap
gen gap=pline-tc_imp if tc_imp<pline
*graph gap
twoway kdensity gap if wave==0 [aw=pweight] || kdensity gap if wave==1 [aw=pweight] || kdensity gap if wave==3 [aw=pweight]
*save gap
kdensity gap if wave==0   [aw=pweight] , nograph gen(x gap2009 )
kdensity gap if wave==1   [aw=pweight]  , nograph at(x) gen(gap2015 )
kdensity gap if wave==3   [aw=pweight]  , nograph at(x) gen(gap2016 )
label var gap2009 "2009"
label var gap2015 "2015"
label var gap2016 "2016"
export excel x gap2* using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("Distributions-2") first(varl) cell(H1)

*Create dataset with consumption expenditure distribution curves overall and by strata
*create overall percentiles
use  "${gsdData}/1-CleanTemp/hhq_analysis.dta", clear
keep if dataset==2
svyset ea [pw=pweight], strata(stratum)
drop if missing(tc_imp)
keep dataset wave stratum urban state ea hh pweight tc_imp 
gen pctile=.
forvalues i=1(2)3 {
	xtile pctile_w`i'=tc_imp [aw=pweight]  if wave==`i', nq(100)
	replace pctile=pctile_w`i' if wave==`i'
	gen tc_imp_w`i'=tc_imp if wave==`i'
}
drop if missing(pctile)
collapse tc_imp_w* , by(pctile)
save "${gsdTemp}/pctiles_overall.dta", replace
*create urban percentiles
use  "${gsdData}/1-CleanTemp/hhq_analysis.dta", clear
keep if dataset==2
svyset ea [pw=pweight], strata(stratum)
drop if missing(tc_imp)
keep dataset wave stratum urban state ea hh pweight tc_imp 
gen pctile=.
forvalues i=1/4 {
	xtile pctile_w`i'_u=tc_imp [aw=pweight]  if wave==`i' & urban==1, nq(100)
	replace pctile=pctile_w`i'_u if wave==`i'  & urban==1
	gen tc_imp_w`i'_u=tc_imp if wave==`i'  & urban==1
}
drop if missing(pctile)
collapse tc_imp_w* , by(pctile)
save "${gsdTemp}/pctiles_urban.dta", replace
*create rural percentiles
use  "${gsdData}/1-CleanTemp/hhq_analysis.dta", clear
svyset ea [pw=pweight], strata(stratum)
drop if missing(tc_imp)
keep dataset wave stratum urban state ea hh pweight tc_imp 
gen pctile=.
forvalues i=1(2)3 {
	xtile pctile_w`i'_r=tc_imp [aw=pweight]  if wave==`i' & urban==0, nq(100)
	replace pctile=pctile_w`i'_r if wave==`i'  & urban==0
	gen tc_imp_w`i'_r=tc_imp if wave==`i'  & urban==0
}
drop if missing(pctile)
collapse tc_imp_w* , by(pctile)
save "${gsdTemp}/pctiles_rural.dta", replace
*prepare 2009 data
use "${gsdNBHS}/NBHS_HH.dta", clear
*keep only surveyed states
keep if state>81
egen stratum=group(state urban)
gen pweight=hhweight*hhsize
svyset cluster [pw=pweight], strata(stratum)
replace urban=0 if urban==2
gen tc_imp=pcexpm/30*1.08/72.583*3355.756
*create overall percentiles
xtile pctile = tc_imp [aw=pweight], nq(100)
drop if missing(pctile)
collapse tc_imp_nbhs=tc_imp , by(pctile)
save "${gsdTemp}/pctiles_overall_nbhs.dta", replace
*Rural
use "${gsdTemp}/gic2009.dta", clear
svyset cluster [pw=pweight], strata(stratum)
keep if urban==0
xtile pctile = tc_imp [aw=pweight], nq(100)
drop if missing(pctile)
collapse tc_imp_nbhs_r=tc_imp , by(pctile)
save "${gsdTemp}/pctiles_rural_nbhs.dta", replace
*Urban
use "${gsdTemp}/gic2009.dta", clear
svyset cluster [pw=pweight], strata(stratum)
keep if urban==1
xtile pctile = tc_imp [aw=pweight], nq(100)
drop if missing(pctile)
collapse tc_imp_nbhs_u=tc_imp , by(pctile)
save "${gsdTemp}/pctiles_urban_nbhs.dta", replace

*create percentiles after 15% uniform consumption shock  
use "${gsdTemp}/gicw3.dta", clear
gen tc_shock=tc_imp*0.85
xtile pctile = tc_shock [aw=pweight], nq(100)
drop if missing(pctile)
collapse tc_shock_w3=tc_shock , by(pctile)
save "${gsdTemp}/pctiles_shock.dta", replace 
*graph distribution of consumption after the shock
use "${gsdTemp}/gicw3.dta", clear
gen tc_shock=tc_imp*0.7
kdensity tc_imp if tc_imp<450, nograph gen(x tc_dens_w3)
kdensity tc_shock  if tc_imp<450, nograph gen(tc_dens_shock_w3) at(x)
gen pctile=_n
keep if pctile<51	
order pctile x tc_dens_w3 tc_dens_shock_w3
keep pctile x tc_dens_w3 tc_dens_shock_w3
save "${gsdTemp}/distribution_shock.dta", replace  
*merge the data
use "${gsdTemp}/pctiles_overall.dta", clear
merge 1:1 pctile using "${gsdTemp}/pctiles_urban.dta", nogen assert(match)
merge 1:1 pctile using "${gsdTemp}/pctiles_rural.dta", nogen assert(match)
merge 1:1 pctile using  "${gsdTemp}/pctiles_overall_nbhs.dta", nogen assert(match)
merge 1:1 pctile using  "${gsdTemp}/pctiles_rural_nbhs.dta", nogen assert(match)
merge 1:1 pctile using  "${gsdTemp}/pctiles_urban_nbhs.dta", nogen assert(match)
merge 1:1 pctile using  "${gsdTemp}/pctiles_shock.dta", nogen assert(match)
merge 1:1 pctile using  "${gsdTemp}/distribution_shock.dta", nogen assert(match master)
save "${gsdData}/1-CleanTemp/distributions.dta", replace
export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data 2-1") first(variables)

*Carry out the poverty decomposition analysis
*Growth inequality decomposition
*2009-2016
use "${gsdTemp}/gic2009.dta", clear	
rename (cluster hhid ) (ea hh)
gen wave=0
append using "${gsdTemp}/gicw3.dta"
gen pl=121.878713
drdecomp tc_imp [aw=pweight], by(wave) varpl(pl) in(fgt0 fgt1 fgt2)
drdecomp tc_imp [aw=pweight] if urban==1, by(wave) varpl(pl) in(fgt0 fgt1 fgt2)
drdecomp tc_imp [aw=pweight] if urban==0, by(wave) varpl(pl) in(fgt0 fgt1 fgt2)
*2009-2015
use "${gsdTemp}/gic2009.dta", clear	
rename (cluster hhid ) (ea hh)
gen wave=0
append using "${gsdTemp}/gicw1.dta"
gen pl=121.878713
drdecomp tc_imp [aw=pweight], by(wave) varpl(pl) in(fgt0 fgt1 fgt2)
drdecomp tc_imp [aw=pweight] if urban==1, by(wave) varpl(pl) in(fgt0 fgt1 fgt2)
drdecomp tc_imp [aw=pweight] if urban==0, by(wave) varpl(pl) in(fgt0 fgt1 fgt2)
*2015-2016
*2009-2015
use "${gsdTemp}/gicw1.dta", clear	
append using "${gsdTemp}/gicw3.dta"
gen pl=121.878713
drdecomp tc_imp [aw=pweight], by(wave) varpl(pl) in(fgt0 fgt1 fgt2)
drdecomp tc_imp [aw=pweight] if urban==1, by(wave) varpl(pl) in(fgt0 fgt1 fgt2)
drdecomp tc_imp [aw=pweight] if urban==0, by(wave) varpl(pl) in(fgt0 fgt1 fgt2)
*growth inequality decomposition
*INTERNATIONAL POVERTY LINE
local pline=121.878713
*2009-Wave3
use "${gsdTemp}/gic2009.dta", clear	
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight], var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline')
*urban/rural
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline')
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==0, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline')
*2009-Wave1
use "${gsdTemp}/gic2009.dta", clear	
gidecomposition using "${gsdTemp}/gicw1.dta" [aw=pweight], var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline')
*urban/rural
gidecomposition using "${gsdTemp}/gicw1.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline')
gidecomposition using "${gsdTemp}/gicw1.dta" [aw=pweight] if urban==0, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline')
*Wave1-Wave3
use "${gsdTemp}/gicw1.dta", clear
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight], var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline')
*urban/rural
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline')
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==0, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline')
*Poverty gap
*2009-Wave3
use "${gsdTemp}/gic2009.dta", clear	
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight], var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline') pg
*urban/rural
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline') pg
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==0, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline') pg
*2009-Wave1
use "${gsdTemp}/gic2009.dta", clear	
gidecomposition using "${gsdTemp}/gicw1.dta" [aw=pweight], var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline') pg
*urban/rural
gidecomposition using "${gsdTemp}/gicw1.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline') pg
gidecomposition using "${gsdTemp}/gicw1.dta" [aw=pweight] if urban==0, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline') pg
*Wave1-Wave3
use "${gsdTemp}/gicw1.dta", clear
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight], var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline') pg
*urban/rural
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==1, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline') pg
gidecomposition using "${gsdTemp}/gicw3.dta" [aw=pweight] if urban==0, var1(tc_imp) var2(tc_imp)  pline1(`pline') pline2(`pline') pg
*Sectoral decomposition
*prepare 2009
use "${gsdTemp}/gic2009.dta", clear
save  "${gsdTemp}/gic2009_secdec.dta", replace 
*prepare W1
use "${gsdTemp}/gicw1.dta", clear
merge 1:m wave state ea hh using "${gsdData}/1-CleanTemp/hhm_analysis.dta", nogen assert(match using) keep(match) 
recode emp_sector_5 (1 = 1 "Agriculture") (2 4 5 =2  "Services") (3= 3 "Manufacturing"), gen(emp_sector_3)
bys state ea hh: egen emp_sector=mode(emp_sector_3), minmode
keep if ishead==1
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match using) keep(match) 
recode lhood (1 2 3 = 1 "Agriculture") (4 = 4 "Wages and salaries") (5 = 5 "Own business") (6 7 9 8 = 7 "Remittances/Aid/Other") (nonmissing=.) , gen(livelihood)
keep stratum wave state urban ea hh pweight tc_imp plinePPP livelihood emp_sector
save  "${gsdTemp}/gicw1_secdec.dta", replace
*prepare W3
use "${gsdTemp}/gicw3.dta", clear
merge 1:m wave state ea hh using "${gsdData}/1-CleanTemp/hhm_analysis.dta", nogen assert(match using) keep(match) 
recode emp_sector_5 (1 = 1 "Agriculture") (2 4 5 =2  "Services") (3= 3 "Manufacturing"), gen(emp_sector_3)
bys state ea hh: egen emp_sector=mode(emp_sector_3), minmode
keep if ishead==1
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match using) keep(match) 
recode lhood (1 2 3 = 1 "Agriculture") (4 = 4 "Wages and salaries") (5 = 5 "Own business") (6 7 9 8 = 7 "Remittances/Aid/Other") (nonmissing=.) , gen(livelihood)
keep stratum wave state urban ea hh pweight tc_imp plinePPP livelihood emp_sector
save  "${gsdTemp}/gicw3_secdec.dta", replace
*decomposition by urban/rural
*2009-wave3
use "${gsdTemp}/gic2009_secdec.dta", clear
sedecomposition using "${gsdTemp}/gicw3_secdec.dta" [aw=pweight], sector(urban) var1(tc_imp) var2(tc_imp)  pline1(plinePPP) pline2(plinePPP)
*2009-wave1
use "${gsdTemp}/gic2009_secdec.dta", clear
sedecomposition using "${gsdTemp}/gicw1_secdec.dta" [aw=pweight], sector(urban) var1(tc_imp) var2(tc_imp)  pline1(plinePPP) pline2(plinePPP)
*wave1-wave3
use "${gsdTemp}/gicw1_secdec.dta", clear
sedecomposition using "${gsdTemp}/gicw3_secdec.dta" [aw=pweight], sector(urban) var1(tc_imp) var2(tc_imp)  pline1(plinePPP) pline2(plinePPP)
