*This do file prepares ACLED data and the conflict data necessary for the conflict estimation

*prepare 2009-2018 acled data
use "${gsdDataRaw}/ACLED_2009-2018.dta", clear
replace admin2=subinstr(admin2,"Lafon/Lopa","Lopa",.)
replace admin2=subinstr(admin2,"Panyijiar","Panyijar",.)
replace admin2=subinstr(admin2,"Canal","Khorflus",.)
replace admin2=subinstr(admin2,"Khorflus/Pigi","Khorflus",.)
save "${gsdData}/1-CleanTemp/ACLED.dta", replace
*create data to graph escalation of the conflict
*events by type
use "${gsdData}/1-CleanTemp/ACLED.dta", clear
encode event_type, gen(x)
recode x (1 2 3=1 "Battle") (4 5 8=2 "Strategic development") ( 6=3 "Remote violence") (7=4 "Riots/Protests" ) (9=5 "Violence against civilians"), gen(events_recode)
tab events_recode, 
*get events by month
gen m=mofd(event_date)
format m %tm
*reshape events by type per month
collapse (count) x (sum) fatalities, by(events_recode m)
reshape wide x fatalities, j(events_recode ) i(m )
*keep only overall fatalities
egen fatalities=rowtotal(fatalities*)
drop fatalities?
*reformat date
generate event_date=dofm(m)
generate d = string(event_date, "%td")
gen my = substr(d,3,.)
gen m1=strupper(substr(my,1,1))
gen m2=substr(my,2,2)
gen month=m1+m2
drop m1 m2
gen year=substr(my,4,4)
gen ym=month+"-"+year
*clean up and save
label var x1 "Battle" 
label var x2 "Strategic development"
label var x3 "Remote violence"
label var x4 "Riots/protests"
label var x5 "Violence against civilians"
label var ym "Month"
label var fatalities "Fatalities (LHS)"
order ym x1 x2 x3 x4 x5 fatalities
keep  ym x1 x2 x3 x4 x5 fatalities
*export excel using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("ACLED") first(varl) 
*** by quarter
*events by type
use "${gsdData}/1-CleanTemp/ACLED.dta", clear
encode event_type, gen(x)
recode x (1 2 3=1 "Battle") (4 5 8=2 "Strategic development") ( 6=3 "Remote violence") (7=4 "Riots/Protests" ) (9=5 "Violence against civilians"), gen(events_recode)
tab events_recode, 
*get events by month
gen q=qofd(event_date)
format q %tq
*reshape events by type per month
collapse (count) x (sum) fatalities, by(events_recode q)
reshape wide x fatalities, j(events_recode ) i(q )
*keep only overall fatalities
egen fatalities=rowtotal(fatalities*)
drop fatalities?
*reformat date
generate qq = string(q, "%tq")
gen quarter=substr(qq,1,4) + " Q-"+ substr(qq,6,1)
*clean up and save
label var x1 "Battle" 
label var x2 "Strategic development"
label var x3 "Remote violence"
label var x4 "Riots/protests"
label var x5 "Violence against civilians"
label var quarter "Quarter"
label var fatalities "Fatalities (LHS)"
order quarter x1 x2 x3 x4 x5 fatalities
keep  quarter x1 x2 x3 x4 x5 fatalities
export excel using "${gsdOutput}/ACLED_quarter.xlsx", sheetmodify sheet("ACLED") first(varl) 

*ACLED quarter only in our 6 states
*prepare Boma conflict index
import excel using "${gsdDataRaw}/ACLED_Boma_2008-2017.xls", clear first
keep STATE COUNTY PAYAM BOMA BOM_CODE latitude longitude geo_precis fatalities event_date time_preci deadly event_type
rename (STATE COUNTY PAYAM BOMA) (State County Payam Boma)
order deadly fatalities, last
*filter events occuring between waves 1 and 4
gen date=date(event_date,"DMY")
drop event_date
rename date event_date
format event_date %td
*keep relevant time period
foreach v of varlist State County Payam Boma {
	replace `v' = strtrim(strupper(`v'))
}
keep State County Payam Boma fatalities event_type event_date
drop if inlist(State,"ABYEI","JONGLEI","UPPER NILE","UNITY")
encode event_type, gen(x)
recode x (1 2 3=1 "Battle") (4 5 8=2 "Strategic development") ( 6=3 "Remote violence") (7=4 "Riots/Protests" ) (9=5 "Violence against civilians"), gen(events_recode)
tab events_recode, 
*get events by month
gen q=qofd(event_date)
format q %tq
*reshape events by type per month
collapse (count) x (sum) fatalities, by(events_recode q)
reshape wide x fatalities, j(events_recode ) i(q )
*keep only overall fatalities
egen fatalities=rowtotal(fatalities*)
drop fatalities?
*reformat date
generate qq = string(q, "%tq")
gen quarter=substr(qq,1,4) + " Q-"+ substr(qq,6,1)
*clean up and save
label var x1 "Battle" 
label var x2 "Strategic development"
label var x3 "Remote violence"
label var x4 "Riots/protests"
label var x5 "Violence against civilians"
label var quarter "Quarter"
label var fatalities "Fatalities (LHS)"
order quarter x1 x2 x3 x4 x5 fatalities
keep  quarter x1 x2 x3 x4 x5 fatalities
export excel using "${gsdOutput}/ACLED_quarter.xlsx", sheetmodify sheet("ACLED-HFS") first(varl) 

*ACLED quarter only the other 4 states
*prepare Boma conflict index
import excel using "${gsdDataRaw}/ACLED_Boma_2008-2017.xls", clear first
keep STATE COUNTY PAYAM BOMA BOM_CODE latitude longitude geo_precis fatalities event_date time_preci deadly event_type
rename (STATE COUNTY PAYAM BOMA) (State County Payam Boma)
order deadly fatalities, last
*filter events occuring between waves 1 and 4
gen date=date(event_date,"DMY")
drop event_date
rename date event_date
format event_date %td
*keep relevant time period
foreach v of varlist State County Payam Boma {
	replace `v' = strtrim(strupper(`v'))
}
keep State County Payam Boma fatalities event_type event_date
keep if inlist(State,"ABYEI","JONGLEI","UPPER NILE","UNITY")
encode event_type, gen(x)
recode x (1 2 3=1 "Battle") (4 5 8=2 "Strategic development") ( 6=3 "Remote violence") (7=4 "Riots/Protests" ) (9=5 "Violence against civilians"), gen(events_recode)
tab events_recode, 
*get events by month
gen q=qofd(event_date)
format q %tq
*reshape events by type per month
collapse (count) x (sum) fatalities, by(events_recode q)
reshape wide x fatalities, j(events_recode ) i(q )
*keep only overall fatalities
egen fatalities=rowtotal(fatalities*)
drop fatalities?
*reformat date
generate qq = string(q, "%tq")
gen quarter=substr(qq,1,4) + " Q-"+ substr(qq,6,1)
*clean up and save
label var x1 "Battle" 
label var x2 "Strategic development"
label var x3 "Remote violence"
label var x4 "Riots/protests"
label var x5 "Violence against civilians"
label var quarter "Quarter"
label var fatalities "Fatalities (LHS)"
order quarter x1 x2 x3 x4 x5 fatalities
keep  quarter x1 x2 x3 x4 x5 fatalities
export excel using "${gsdOutput}/ACLED_quarter.xlsx", sheetmodify sheet("ACLED-nonHFS") first(varl) 

*ACLED quarter Both
*prepare Boma conflict index
import excel using "${gsdDataRaw}/ACLED_Boma_2008-2017.xls", clear first
keep STATE COUNTY PAYAM BOMA BOM_CODE latitude longitude geo_precis fatalities event_date time_preci deadly event_type
rename (STATE COUNTY PAYAM BOMA) (State County Payam Boma)
order deadly fatalities, last
*filter events occuring between waves 1 and 4
gen date=date(event_date,"DMY")
drop event_date
rename date event_date
format event_date %td
*keep relevant time period
foreach v of varlist State County Payam Boma {
	replace `v' = strtrim(strupper(`v'))
}
keep State County Payam Boma fatalities event_type event_date
gen hfs=!inlist(State,"ABYEI","JONGLEI","UPPER NILE","UNITY")
encode event_type, gen(x)
recode x (1 2 3=1 "Battle") (4 5 8=2 "Strategic development") ( 6=3 "Remote violence") (7=4 "Riots/Protests" ) (9=5 "Violence against civilians"), gen(events_recode)
tab events_recode, 
*get events by month
gen q=qofd(event_date)
format q %tq
*reshape events by type per month
collapse (count) x (sum) fatalities, by(hfs q)
reshape wide x fatalities, j(hfs ) i(q )
*reformat date
generate qq = string(q, "%tq")
gen quarter=substr(qq,1,4) + " Q-"+ substr(qq,6,1)
*clean up and save
label var x0 "Non-HFS States" 
label var x1 "HFS States"
label var quarter "Quarter"
label var fatalities0 "Fatalities Non-HFS States (LHS)"
label var fatalities1 "Fatalities HFS States (LHS)"
order quarter x0 x1 fatalities0 fatalities1
keep  quarter x0 x1 fatalities0 fatalities1
export excel using "${gsdOutput}/ACLED_quarter.xlsx", sheetmodify sheet("ACLED-Both") first(varl) 

*alternative method with bilateral distances
*Create external conflict indicator
*	This code takes a long time to run so set cross=1 to run it the first time
local cross = 0
if `cross'==1 {
	*prepare a lighted ACLED Dataset
	use "${gsdData}/1-CleanTemp/ACLED.dta", clear
	keep if inrange(event_date,td(01022015),td(30082017))
	save "${gsdTemp}/ACLED_tocross.dta", replace
	*cross the data with households
	use "${gsdData}/1-CleanTemp/hhq_gps.dta", clear
	*Warrap was dropped for analysis so it doesn't merge; CRS data won't merge either
	merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master using) keep(match)
	*lighten up data
	keep wave state urban ea hh latitude longitude today panel_w24 panel_w12 panel_w124
	rename (latitude longitude wave) (hh_latitude hh_longitude hfs_wave)
	*create every single pairwise combination of every violent event and household in SSD. 
	cross using  "${gsdData}/1-CleanTemp/ACLED.dta"
	*save temporarily so as to not have to cross again
	drop wave State County event_code
	*generate distance variable
	geodist hh_latitude hh_longitude latitude longitude, gen(distance) sphere
	*drop if distance is greater than 50 km to lighten up the data
	drop if distance>50
	save "${gsdOutput}/crossed_acled_hfs.dta", replace
	
	/*
	*distance distribution
	use "${gsdOutput}/crossed_acled_hfs.dta", clear
	kdensity distance , nograph gen(x y)
	kdensity distance if urban==1, nograph gen(urban_d) at(x)
	kdensity distance if urban==0, nograph gen(rural_d) at(x)
	replace x=0 if x<0
	replace x=ceil(x)
	export excel x urban_d rural_d using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("ACLED") first(varl) cell(AE1)
	*stats about distances etc
	use "${gsdOutput}/crossed_acled_hfs.dta", clear
	keep if distance<5
	rename (hfs_wave) (wave)
	merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match using) keepusing(dataset stratum weight urban panel_w24) update
	keep if dataset==2 
	svyset ea [pw=weight], strata(stratum)
	collapse (count) distance ,by(wave urban state ea hh weight stratum)
	gen none=distance==0
	table none wave urban
	svy: prop none, over(urban)
	svy: mean distance, over(urban)
	*/
}

*calculate some statistics about the conflict using households' distance to events
use "${gsdOutput}/crossed_acled_hfs.dta", clear
rename hfs_wave wave
*lighten up data
drop hh_latitude hh_longitude panel_w12 panel_w24 panel_w124 Payam latitude longitude 
*merge weights
local keep = "weight pweight tc_imp quintiles_tc poor"
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match using) keep(match) keepusing(`keep')
*percentage of households experiencing conflict related casualties within 10km
replace fatalities=. if distance>10
gen deadly=fatalities>0 if !missing(fatalities)
gen events=1 if !missing(fatalities)
collapse (sum) events deadly fatalities, by(wave state urban ea hh `keep')
*double rural weights to account for two vs four waves
replace weight=weight*2 if urban==0
*mean number of each
mean events deadly fatalities [pw=weight], over(urban)
*mean share of households that experienced an event or a deadly event
gen exp_event=events>0
gen exp_deadly=deadly>0
mean exp_event exp_deadly [pw=weight], over(urban)

*pre wave 1 correlation with wealth
use "${gsdOutput}/crossed_acled_hfs.dta", clear
rename hfs_wave wave
*lighten up data
drop hh_latitude hh_longitude panel_w12 panel_w24 panel_w124 Payam latitude longitude 
keep if date<td(01122016)
*merge weights
local keep = "weight pweight tc_imp quintiles_tc poor"
merge m:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match using) keep(match) keepusing(`keep')
*percentage of households experiencing conflict related casualties within 10km
replace fatalities=. if distance>10
gen deadly=fatalities>0 if !missing(fatalities)
gen events=1 if !missing(fatalities)
collapse (sum) events deadly fatalities, by(wave state urban ea hh `keep')
*double rural weights to account for two vs four waves
replace weight=weight*2 if urban==0
*correlation with wealth?
mean events deadly fatalities if inlist(wave,1), over( urban quintiles_tc)
*nonpoor more fatalities
mean events deadly fatalities if inlist(wave,1), over( poor)
lincom [fatalities]Poor-[fatalities]NonPoor
*highest quintiles saw more fatalities
gen isq5=quintiles_tc==5
mean events deadly fatalities if inlist(wave,1), over( isq5)
lincom [fatalities]0-[fatalities]1
*same but urban
mean events deadly fatalities if inlist(wave,1), over( urban isq5)
lincom [fatalities]_subpop_3-[fatalities]_subpop_4
mean events deadly fatalities if inlist(wave,1), over( urban)
