*this do file performs the muldimensional deprivation analysis

*multidimensional deprivation index
*Deprivation in 2009
use "${gsdNBHS}/NBHS_IND.dta", clear
egen stratum=group(state urban)
rename hhweight weight
rename (cluster hhid) (ea hh)
svyset ea [pw=weight], strata(stratum)
rename (b3 b41) (gender age)
replace urban=0 if urban==2
*education
rename (c1 c2 c3) (literacy edu_ever edu_current)
*generate dummy if adult had no education ever
gen adult_noedu=(edu_ever==2) if inrange(age,15,120)
*all adults are illiterate
gen adult_nolite=(literacy==2) if inrange(age,15,120)
*generate dummy for child not attending school
gen child_noed=(edu_current==2 | edu_ever==2) if inrange(age,6,14)
*get household head marital status (set no response as median=married)
gen xmarital=b5 if head==1
quietly su xmarital, detail
replace xmarital=r(p50) if missing(xmarital)
recode xmarital (2 99=1 "Married") (3 4=2 "Widowed/divorced") (1=3 "Never married") , gen(head_marital)
*create household level data
collapse (max)  head_marital child_noed (sum) adult_nolite adult_noedu (count) adult_num=adult_noedu , by(state ea hh)
gen adult_noed=adult_noedu==adult_num
gen adult_nolit=adult_nolite==adult_num
drop adult_noedu adult_num
replace child_noed=0 if missing(child_noed)
label var child_noed "At least one child is not attending school, ages 6-14"
label var adult_noed "All adults have no education, ages 15+"
label var adult_nolit "All adults are illiterate, ages 15+"
save "${gsdTemp}/multidimensional_educ_NBHS.dta", replace
*hhq data
use "${gsdNBHS}/NBHS_HH.dta", clear
egen stratum=group(state urban)
gen pweight=hhweight*hhsize
rename (cluster hhid hhweight) (ea hh weight)
svyset ea [pw=pweight], strata(stratum)
replace urban=0 if urban==2
label define lurban 0 "Rural" 1 "Urban", modify
label val urban lurban
*Poverty line 1.90 USD in USD PPP (2011)
* The 2009 PPP for SSD is 1/1.0858328
* Thus, to convert May 2009 SDG into July 2009 SSP we:
* do not convert since SSPs were introduced at par with SDGs when the currency was first introduced
* multiply by the SSD PPP conversion factor, and adjust for inflation
* CPI July 2015: 239.906; May 2009
* = pcexpm/30 * 1.08 / 72.583*239.906
*gen tc_imp=pcexpm/30*1.08/72.583*239.906
gen tc_imp=pcexpm/30 * 1 /72.583*3355.756
gen wave=0
*WASH
*improved sanitation
gen improved_sanitation=inlist(h9,1,2,4)
label var improved_sanitation "Household has access to improved sanitation"
*improved water source
gen improved_watersource=inlist(h5,1,2,3,4,5,12) 
label var improved_watersource "Household has access to improved water source"
*housing type
gen housing=inlist(h1,5,6,8,9,10)
label var housing "Household lives in improved housing"
*electricity
gen electricity=(inlist(h7,1,2,9,10))
label var electricity "Household has access to electricity" 
*sleeping room density (two missing cases set to mean)
quietly su h3, meanonly
replace h3=r(mean) if h3<0 | missing(h3)
gen crowding=(hhsize/h2)>=4
label var crowding "Household lives in overcrowded household"
gen memperroom=1 if hhsize/h2>=4
replace memperroom=2 if (hhsize/h2)<4 & (hhsize/h2)>=2
replace memperroom=3 if (hhsize/h2)<2 & (hhsize/h2)>=1
replace memperroom=4 if hhsize/h2<1
*cooking 
gen cook=(inlist(h8,1,6,7))
label var cook "Household cooks with grass, dung, or firewood"
*head age
su head_age, meanonly
replace head_age=r(mean) if missing(head_age)
*information
gen mobile_phone=i33_1==1
label var mobile_phone "Household owns at least one Mobile phone"
gen tvsat=(i31_1==1 )
label var tvsat "Household owns at least one TV/Satellite dish"
gen radio=i32_1==1
label var radio "Household owns at least one radio"
gen computer=i34_1==1
label var computer "Household owns at least one computer"
*transportation
gen cartruck=i21_1==1
label var cartruck "Household owns at least one car/truck"
gen motorcycleshaw=i22_1==1
label var motorcycleshaw "Household owns at least one motorcycle/rickshaw"
gen bicycle=i23_1==1
label var bicycle "Household owns at least one bicycle"
*merge with education data
merge 1:1 state ea hh using "${gsdTemp}/multidimensional_educ_NBHS.dta", nogen assert(match)
*create dimensional indices
gen information=(mobile_phone==0 & tvsat==0 & radio==0 & computer==0)
label var information "Household deprived in dimension: information"
gen transportation=(cartruck==0 & motorcycleshaw==0 & bicycle==0)
label var transportation "Household deprived in dimension: transportation"
gen assets=(information==1 | transportation==1)
label var assets "Household deprived in dimension: assets"
gen living_standards=(housing==0 | electricity==0 | crowding==1 | cook==1)
label var living_standards "Household deprived in dimension: living standards"
gen education=(child_noed==1 | adult_noed==1)
label var education "Household deprived in dimension: education"
gen wash=(improved_sanitation==0 | improved_watersource==0)
label var wash "Household deprived in dimension: WASH"
egen deprivations=rowtotal(assets living_standards education wash poor)
label var deprivations "Total number of dimensions household is deprived in"
egen deprivations2=rowtotal(assets living_standards education wash )
label var deprivations2 "Total number of dimensions household is deprived in, no poverty"
*clean up and save
gen hhh_gender=head_sex-1
rename (quintile ) (quintiles_tc ) 
local tokeep = "tc_imp poor quintiles_tc memperroom hhh_gender deprivations deprivations2 head_marital head_age improved_sanitation improved_watersource electricity housing cook crowding mobile_phone tvsat radio computer cartruck motorcycleshaw bicycle adult_noed adult_nolit child_noed information transportation assets education living_standards wash"
label define lyn 0 "No" 1 "Yes"
local labelling = "improved_sanitation improved_watersource electricity housing cook crowding mobile_phone tvsat radio computer cartruck motorcycleshaw bicycle adult_noed child_noed information transportation assets education living_standards wash"
label val `labelling' lyn
gen dataset=3
keep dataset wave state ea hh urban weight pweight hhsize `tokeep'
order dataset wave state ea hh urban weight pweight hhsize `tokeep'
save  "${gsdTemp}/multidimensional_deprivation_NBHS.dta", replace

*Deprivation in the HFS
*Education
use  "${gsdData}/1-CleanTemp/hhm_analysis.dta", clear
*generate dummy if adult had no education ever
gen adult_noedu=(edu_level_g==1) if inrange(age,15,120)
*generate dummy for child not attending school
gen child_noed=(edu_current==0) if inrange(age,6,14)
gen head_age=age if ishead==1
*adult no literate
gen adult_nolite=literacy==0 if inrange(age, 15,120)
*create household level data
collapse (sum) adult_noedu adult_nolite (max) head_age child_noed (count) adult_num=adult_noed , by(wave state ea hh)
quietly su head_age, meanonly
replace head_age=r(mean) if missing(head_age)
gen adult_noed=adult_noedu==adult_num
replace child_noed=0 if missing(child_noed)
gen adult_nolit=adult_nolite==adult_num
drop adult_noedu adult_num
label var child_noed "At least one child is not attending school, ages 6-14"
label var adult_noed "All adults have no education, ages 15+"
label var adult_nolit "All adutls are illiterate, ages 15+"
save "${gsdTemp}/multidimensional_educ_HFS.dta", replace
*WASH
use  "${gsdData}/1-CleanTemp/hhq_analysis.dta", clear
*improved sanitation
gen improved_sanitation=inlist(toilet_type,1,3,4,5) if  inrange(wave,1,3)
gen x=inlist(toilet,1,2,3,4,5,6,7,9)
replace improved_sanitation=x if missing(improved_sanitation) & !missing(x) &  wave==4
replace improved_sanitation=0 if share_facility==1
drop x
label var improved_sanitation "Household has access to improved sanitation"
*improved drinking source
gen improved_watersource=inlist(drink_source,1,2,3,4,5,10) if  inrange(wave,1,3)
gen x=inlist(water_source,1,2,3,4,5,7,9) 
replace improved_watersource=x if missing(improved_watersource) & !missing(x) & wave==4
drop x
label var improved_watersource "Household has access to improved watersource"
*housing type
gen housing=inlist(housingtype,5,6,8,9,10) 
label var housing "Household lives in improved housing"
drop memperroom
gen memperroom=1 if hhsize/rooms_n>=4
replace memperroom=2 if (hhsize/rooms_n)<4 & (hhsize/rooms_n)>=2
replace memperroom=3 if (hhsize/rooms_n)<2 & (hhsize/rooms_n)>=1
replace memperroom=4 if hhsize/rooms_n<1
*cooking
gen cook=inlist(cooking,2,3)
label var cook "Household cooks with grass, dung, or firewood"
*sleeping room density
quietly su slrooms_n, meanonly
replace slrooms_n=r(mean) if missing(slrooms_n)
gen crowding=(hhsize/rooms_n)>=4
label var crowding "Household lives in overcrowded household"
label val crowding lyn
*electricity
gen electricity=(inlist(lighting,5,6)) & !missing(lighting)
label var electricity "Household has access to electricity" 
*marital status
quietly su hhh_marital, detail
replace hhh_marital=r(p50) if missing(hhh_marital)
recode hhh_marital (1 2 .=1 "Married") (5 3 4=2 "Widowed/divorced") (6=3 "Never married") , gen(head_marital)
*merge with assets
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/assets_analysis_wide.dta", nogen assert(match master using) keep(match master)  
*information
gen tvsat=(!missing(Television) | !missing(Satellite_dish) )
label var tvsat  "Household owns at least one TV/Satellite dish"
gen radio=!missing(Radio_transistor)
label var radio "Household owns at least one Radio"
gen mobile_phone=!missing(Mobile_phone)
label var mobile_phone "Household owns at least one Mobile phone"
gen computer=!missing(Computer_laptop)
label var computer "Household owns at least one computer"
*transportation
gen cartruck=(!missing(Trucks) | !missing(Cars))
label var cartruck "Household owns at least one car/truck"
 gen motorcycleshaw=(!missing(Motorcycle_motor) | !missing(Rickshaw))
label var motorcycleshaw "Household owns at least one motorcycle/rickshaw"
gen bicycle=!missing(Bicycle)
label var bicycle "Household owns at least one bicycle"
*merge with education data
merge 1:1 wave state ea hh using "${gsdTemp}/multidimensional_educ_HFS.dta", nogen assert(match)
*create dimensional indices
gen information=(mobile_phone==0 & tvsat==0 & radio==0 & computer==0)
label var information "Household deprived in dimension: information"
gen transportation=(cartruck==0 & motorcycleshaw==0 & bicycle==0)
label var transportation "Household deprived in dimension: transportation"
gen assets=(information==1 | transportation==1)
label var assets "Household deprived in dimension: assets"
gen living_standards=(housing==0 | electricity==0 | crowding==1 | cook==1)
label var living_standards "Household deprived in dimension: living standards"
gen education=(child_noed==1 | adult_noed==1)
label var education "Household deprived in dimension: education"
gen wash=(improved_sanitation==0 | improved_watersource==0)
label var wash "Household deprived in dimension: WASH"
egen deprivations=rowtotal(assets living_standards education wash poor)
label var deprivations "Total number of dimensions household is deprived in"
egen deprivations2=rowtotal(assets living_standards education wash )
label var deprivations2 "Total number of dimensions household is deprived in, no poverty"
*clean up and save
local tokeep = "tc_imp memperroom poor quintiles_tc hhh_gender deprivations deprivations2 head_marital head_age improved_sanitation improved_watersource electricity housing cook crowding mobile_phone tvsat radio computer cartruck motorcycleshaw bicycle adult_noed adult_nolit child_noed information transportation assets education living_standards wash"
local labelling = "improved_sanitation improved_watersource electricity housing cook crowding mobile_phone tvsat radio computer cartruck motorcycleshaw bicycle adult_noed child_noed information transportation assets education living_standards wash"
label val `labelling' lyn
keep dataset wave state ea hh urban weight pweight hhsize `tokeep'
save  "${gsdTemp}/multidimensional_deprivation_HFS.dta", replace

*append the two datasets
use "${gsdTemp}/multidimensional_deprivation_HFS.dta", clear
append using "${gsdTemp}/multidimensional_deprivation_NBHS.dta"
quietly su hhh_gender, detail
replace hhh_gender=r(p50) if missing(hhh_gender)
egen stratum=group(state urban)
order stratum, before(urban)
label define lwave 0 "NBHS", modify
label define dataset 3 "NBHS", modify
label define s_v 71 "Upper Nile" 72 "Jonglei" 73 "Unity" 81 "Warrap", modify
svyset ea [pw=pweight], strata(stratum)
*create the continuous index
gen improved_sanitation_i=improved_sanitation==0
gen improved_watersource_i=improved_watersource==0
local components = "adult_noed child_noed improved_sanitation_i improved_watersource_i information transportation"
foreach v of local components {
	gen `v'_x=`v'*(1/10)
}
gen housing_i=housing==0
gen electricity_i=electricity==0
local components2 = "housing_i crowding cook electricity_i"
foreach v of local components2 {
	gen `v'_x=`v'*(1/20)
}
gen poor_x=poor*(1/5)
egen mpi=rowtotal(*_x)
label var mpi "Multi-dimensional Poverty Index"
drop *_i  *_x
*create continuous index without poverty in it
gen improved_sanitation_i=improved_sanitation==0
gen improved_watersource_i=improved_watersource==0
local components = "adult_noed child_noed improved_sanitation_i improved_watersource_i information transportation"
foreach v of local components {
	gen `v'_x=`v'*(1/8)
}
gen housing_i=housing==0
gen electricity_i=electricity==0
local components2 = "housing_i crowding cook electricity_i"
foreach v of local components2 {
	gen `v'_x=`v'*(1/16)
}
egen mpi_np=rowtotal(*_x)
label var mpi_np "Multi-dimensional Poverty Index, no poverty"
drop  *_x
drop if missing(tc_imp)
*create poor by MPI standards
gen mpi_poor=mpi>(1/3) if !missing(mpi)
save  "${gsdTemp}/multidimensional_deprivation_formaps.dta", replace
keep if state>81 | state<10
save  "${gsdTemp}/multidimensional_deprivation.dta", replace


*tryout mpi command
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
*calculate mpi per wave
forvalues n = 0(3)3 {
	mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
		, svy subpop(if wave==`n') cutoff(.333) postadditional 
	*display for easy copyingfor figures
	matrix A=e(mpi_main)'
	matrix list A
	matrix B=e(ind)'
	matrix list B
	matrix C=e(dom)'
	matrix list C
	*urban 
	mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
		, svy subpop(if wave==`n' & urban==1) cutoff(.333) postadditional 
	matrix A=e(mpi_main)'
	matrix list A
	matrix B=e(ind)'
	matrix list B
	matrix C=e(dom)'
	matrix list C
	*rural
	mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
		, svy subpop(if wave==`n' & urban==0) cutoff(.333) postadditional 
	matrix A=e(mpi_main)'
	matrix list A
	matrix B=e(ind)'
	matrix list B
	matrix C=e(dom)'
	matrix list C
}
*check sensitivity to threshold (only for 2016)
forvalues n=1(1)10 {
	local i=`n'/10
	mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
		, svy subpop(if wave==3) cutoff(`i') nos nod 
}
*graph mpi density
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)    
*consumption distributions
kdensity mpi if wave==0   [aw=pweight] , nograph gen(x mpi2009 )
kdensity mpi if wave==3 [aw=pweight]  , nograph at(x) gen(mpi2016 )
kdensity mpi if dataset==1 [aw=pweight]  , nograph at(x) gen(mpiidp )
*urban-rural
kdensity mpi if wave==0  & urban==1 [aw=pweight] , nograph at(x) gen(mpi2009_urban )
kdensity mpi if wave==0  & urban==0 [aw=pweight] , nograph at(x) gen(mpi2009_rural )
kdensity mpi if wave==3  & urban==1 [aw=pweight] , nograph at(x) gen(mpi2016_urban )
kdensity mpi if wave==3  & urban==0 [aw=pweight] , nograph at(x) gen(mpi2016_rural )
*clean up and export
label var mpi2009 "2009"
label var mpi2016 "2016"
label var mpiidp "IDP"
label var mpi2009_urban "Urban 2009"
label var mpi2009_rural "Rural 2009"
label var mpi2016_urban "Urban 2016"
label var mpi2016_rural "Rural 2016"
export excel x mpi2009 mpi2016 mpiidp mpi2009_* mpi2016_* using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("MultiDimensional") first(varl) cell(AG233)

*get the full MPI by categories and wave
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
*2009
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==0) cutoff(.333) nos nod 
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==0 & urban==1) cutoff(.333) nos nod 
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==0 & urban==0) cutoff(.333) nos nod 
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==0 & hhh_gender==1) cutoff(.333) nos nod 
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==0 & hhh_gender==0) cutoff(.333)  nos nod 
*2016
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==3) cutoff(.333) nos nod 
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==3 & urban==1) cutoff(.333) nos nod 
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==3 & urban==0) cutoff(.333) nos nod 
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==3 & hhh_gender==1) cutoff(.333) nos nod 
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if wave==3 & hhh_gender==0) cutoff(.333)  nos nod 
*IDP
mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
	, svy subpop(if dataset==1) cutoff(.333) 
	matrix A=e(mpi_main)'
	matrix list A
	matrix B=e(ind)'
	matrix list B
	matrix C=e(dom)'
	matrix list C
*analysis
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
*urban rural dimensions
svy: mean mpi if wave==3 & mpi_poor==1, over(urban)
lincom [mpi]Urban-[mpi]Rural
*head gender dimensions
svy: mean mpi if wave==3 & mpi_poor==1, over(hhh_gender)
lincom [mpi]_subpop_1-[mpi]_subpop_2
*IDPs
svy: mean mpi if mpi_poor==1 & (wave==3 | (wave==4 & dataset==1)), over(dataset)
lincom [mpi]CRS-[mpi]HFS

*differences 2009-2016 in indicators
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
keep if wave==0 | wave==3
gen w=wave==0
*get poorPPP for wave 3
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master using) keep(match master) keepusing(poorPPP_prob)
gen p=poorPPP_prob
replace p=poor if wave==0
local indicators = "p adult_noed child_noed improved_sanitation_i improved_watersource_i information transportation housing_i cook crowding electricity_i"
iebaltab `indicators' , grpvar(w) save("${gsdOutput}/multidim_indicators.xlsx") replace rowvarlabels weight(pw=pweight)   
*by urban
iebaltab `indicators' if urban==1, grpvar(w) save("${gsdOutput}/multidim_indicators_urban.xlsx") replace rowvarlabels weight(pw=pweight)   
*by rural
iebaltab `indicators' if urban==0, grpvar(w) save("${gsdOutput}/multidim_indicators_rural.xlsx") replace rowvarlabels weight(pw=pweight)   
*IDPs
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master using) keep(match master) keepusing(poorPPP_prob)
gen idps=dataset==1 if (wave==3 | (wave==4 & dataset==1))
gen p=poorPPP_prob
replace p=poor if wave==0
local indicators = "p assets living_standards education wash adult_noed child_noed improved_sanitation_i improved_watersource_i information transportation housing_i cook crowding electricity_i "
iebaltab `indicators' , grpvar(idps) save("${gsdOutput}/multidim_indicators_idp.xlsx") replace rowvarlabels weight(pw=pweight)   
*correlation between deprivations
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
corr poor wash education living_standards assets [aw=pweight] if wave==0
corr poor wash education living_standards assets [aw=pweight] if wave==3

*create local with MPI values for maps
use "${gsdTemp}/multidimensional_deprivation_formaps.dta", clear
svyset ea [pw=pweight], strata(stratum)
keep if state>5 & wave==0
*loop over states
levelsof state, local(states)
foreach s of local states {
	quietly mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
		, svy subpop(if state==`s') cutoff(.333) nos nod 
	matrix A=e(mpi_main)
	local s`s'_09=A[1,2]
	display `s`s'_09'
}
use "${gsdTemp}/multidimensional_deprivation_formaps.dta", clear
svyset ea [pw=pweight], strata(stratum)
keep if state>5 & wave==0
collapse mpi_poor [aw=pweight], by(state)
*create mpi variable
gen mpi=.
foreach state of local states {
	replace mpi=`s`state'_09' if state==`state'
}
*create IDs for the map
decode state, gen(State)
gen _ID= 1 if State=="Lakes"
replace _ID= 2 if State=="Central Equatoria"
replace _ID= 3 if State=="Eastern Equatoria"
replace _ID= 4 if State=="Upper Nile"
replace _ID= 5 if State=="Western Bahr el Ghazal"
replace _ID= 6 if State=="Unity"
replace _ID= 7 if State=="Northern Bahr el Ghazal"
replace _ID= 8 if State=="Jonglei"
replace _ID= 9 if State=="Western Equatoria"
replace _ID= 10 if State=="Warrap"
format mpi_poor mpi %9.2f
*export a dataset to compare
preserve 
keep _ID mpi_poor mpi
rename (mpi mpi_poor) (mpi_09 mpi_poor_09)
tempfile 09data
save `09data', replace
restore
*MPH
spmap mpi_poor using "${gsdDataRaw}/states_shp_coordinates.dta", id(_ID) fcolor(BuRd) clmethod(custom) clbreak(0 .40 .50  .60  .7  .8  .9 1)  ///
	ndocolor(black) ndpattern(solid) ndfcolor(gs15) ndlabel(Not covered) ///
	legend( size(medium) ) legstyle(2) legtitle("MPI:") ///
	polygon(data("${gsdDataRaw}/states_shp_coordinates.dta") ocolor(black) osize(thick)) ///
	point(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) fcolor(black) shape(O D) by(juba) ) ///
	label(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) label(Town_Name) by(labtype) pos(12 3 9) size(medium medium medium)) 
graph export "${gsdOutput}/MPH-2009.png", replace
*MPI
spmap mpi using "${gsdDataRaw}/states_shp_coordinates.dta", id(_ID) fcolor(BuRd) clmethod(custom) clbreak(0 .40 .50  .60  .7  .8  .9 1)  ///
	ndocolor(black) ndpattern(solid) ndfcolor(gs15) ndlabel(Not covered) ///
	legend( size(medium) ) legstyle(2) legtitle("MPI:") ///
	polygon(data("${gsdDataRaw}/states_shp_coordinates.dta") ocolor(black) osize(thick)) ///
	point(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) fcolor(black) shape(O D) by(juba) ) ///
	label(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) label(Town_Name) by(labtype) pos(12 3 9) size(medium medium medium)) 
graph export "${gsdOutput}/MPI-2009.png", replace
*2016
*create local with MPI values for maps
use "${gsdTemp}/multidimensional_deprivation_formaps.dta", clear
svyset ea [pw=pweight], strata(stratum)
keep if state>5 & wave==3
*loop over states
levelsof state, local(states)
foreach s of local states {
	quietly mpi d1(poor)  d2(adult_noed child_noed) d3(improved_sanitation_i improved_watersource_i) d4(information transportation) d5(housing_i cook crowding electricity_i) ///
		, svy subpop(if state==`s') cutoff(.333) nos nod 
	matrix A=e(mpi_main)
	local s`s'_16=A[1,2]
	display `s`s'_16'
}
use "${gsdTemp}/multidimensional_deprivation_formaps.dta", clear
svyset ea [pw=pweight], strata(stratum)
keep if state>5 & wave==3
collapse mpi_poor [aw=pweight], by(state)
*create mpi variable
gen mpi=.
foreach state of local states {
	replace mpi=`s`state'_16' if state==`state'
}
*create IDs for the map
decode state, gen(State)
set obs `=_N+4'
replace State="Unity" if _n==7
replace state=73 if _n==7
replace State="Upper Nile" if _n==8
replace state=71 if _n==8
replace State="Jonglei" if _n==9
replace state=72 if _n==9
replace State="Warrap" if _n==10
replace state=81 if _n==10
gen _ID= 1 if State=="Lakes"
replace _ID= 2 if State=="Central Equatoria"
replace _ID= 3 if State=="Eastern Equatoria"
replace _ID= 4 if State=="Upper Nile"
replace _ID= 5 if State=="Western Bahr el Ghazal"
replace _ID= 6 if State=="Unity"
replace _ID= 7 if State=="Northern Bahr el Ghazal"
replace _ID= 8 if State=="Jonglei"
replace _ID= 9 if State=="Western Equatoria"
replace _ID= 10 if State=="Warrap"
format mpi_poor mpi %9.2f
*MPH
spmap mpi_poor using "${gsdDataRaw}/states_shp_coordinates.dta", id(_ID)  ndfcolor(gs14) fcolor(BuRd) clmethod(custom) clbreak(0 .40 .50  .60  .7  .8  .9 1)  ///
	legend( size(medium) ) legstyle(2) legtitle("MPI:") ///
	polygon(data("${gsdDataRaw}/states_shp_coordinates.dta") ocolor(black) osize(thick)) ///
	point(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) fcolor(black) shape(O D) by(juba) ) ///
	label(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) label(Town_Name) by(labtype) pos(12 3 9) size(medium medium medium)) 
graph export "${gsdOutput}/MPH-2016.png", replace
*MPI
spmap mpi using "${gsdDataRaw}/states_shp_coordinates.dta", id(_ID) ndfcolor(gs14) fcolor(BuRd) clmethod(custom) clbreak(0 .40 .50  .60  .7  .8  .9 1)  ///
	legend( size(medium) ) legstyle(2) legtitle("MPI:") ///
	polygon(data("${gsdDataRaw}/states_shp_coordinates.dta") ocolor(black) osize(thick)) ///
	point(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) fcolor(black) shape(O D) by(juba) ) ///
	label(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) label(Town_Name) by(labtype) pos(12 3 9) size(medium medium medium)) 
graph export "${gsdOutput}/MPI-2016.png", replace
*view side by side estimates 
merge 1:1 _ID using  `09data', nogen assert(match)
gen diff_mpi=mpi-mpi_09
gen diff_poor=mpi_poor-mpi_poor_09

*create tables for graphs
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
*tabulate mean number of deprivations 
qui tabout deprivations if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) replace h1("deprivations overall") f(4)
qui tabout deprivations urban if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations urban") f(4)
qui tabout deprivations hhh_gender if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations hhh gender") f(4)
*tabulate mean number of deprivations per quintile, without poverty
qui tabout deprivations2 quintiles_tc if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations quintiles") f(4)
*each deprivation individually 
foreach v of varlist assets living_standards education wash {
	qui tabout `v' if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' overall") f(4)
	qui tabout `v' urban if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' urban") f(4)
	qui tabout `v' quintiles_tc if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' quintiles") f(4)
	qui tabout `v' hhh_gender if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' hhh gender") f(4)
}
*2009 figures
*tabulate mean number of deprivations  
qui tabout deprivations if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations overall 2009") f(4)
qui tabout deprivations urban if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations urban 2009") f(4)
qui tabout deprivations hhh_gender if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations hhh gender 2009") f(4)
*tabulate mean number of deprivations 
qui tabout deprivations2 quintiles_tc using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations quintiles 2009") f(4)
*each deprivation individually 
foreach v of varlist assets living_standards education wash {
	qui tabout `v' if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' overall 2009") f(4)
	qui tabout `v' urban if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' urban 2009") f(4)
	qui tabout `v' quintiles_tc if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' quintiles 2009") f(4)
	qui tabout `v' hhh_gender if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' hhh gender 2009") f(4)
}
*Add IDP variables
qui tabout deprivations if dataset==1 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations IDP") f(4)
*IDPS are 100 percent deprived of living standards
foreach v of varlist assets education wash {
	qui tabout `v' if dataset==1 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' IDP") f(4) 
}
*deprivations along four dimensions
qui tabout deprivations2 urban if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations overall") f(4)
qui tabout deprivations2 quintiles_tc if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations urban") f(4)
qui tabout deprivations2 urban if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations overall 2009") f(4)
qui tabout deprivations2 quintiles_tc if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("deprivations urban 2009") f(4)
*each sub-indicator individually 
foreach v of varlist housing crowding electricity improved_sanitation improved_watersource adult_noed child_noed cook information transportation {
	qui tabout `v' if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' overall 2009") f(4)
	qui tabout `v' if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' overall 2016") f(4)
	qui tabout `v' urban if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' urban 2009") f(4)
	qui tabout `v' urban if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' urban 2016") f(4)
	qui tabout `v' quintiles_tc if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' quintiles 2009") f(4)
	qui tabout `v' quintiles_tc if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' quintiles 2016") f(4)
	qui tabout `v' hhh_gender if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' hhh gender 2009") f(4)
	qui tabout `v' hhh_gender if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' hhh gender 2016") f(4)
}
foreach v of varlist housing crowding electricity cook improved_sanitation improved_watersource adult_noed child_noed information transportation {
	qui tabout `v' if dataset==1 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("`v' IDP") f(4)
}
*MPI continuous
qui tabout wave using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi lb ub) npos(col) append h1("mpi overall") f(4)
qui tabout wave urban using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi lb ub) npos(col) append h1("mpi urban") f(4)
qui tabout wave quintiles_tc using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi lb ub) npos(col) append h1("mpi quintiles ") f(4)
qui tabout wave hhh_gender using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi lb ub) npos(col) append h1("mpi hhh gender ") f(4)
qui tabout wave if dataset==1 using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi lb ub) npos(col) append h1("mpi overall") f(4)
*without poverty
qui tabout wave using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_np lb ub) npos(col) append h1("mpi np overall") f(4)
qui tabout wave urban using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_np lb ub) npos(col) append h1("mpi np urban") f(4)
qui tabout wave quintiles_tc using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_np lb ub) npos(col) append h1("mpi np quintiles ") f(4)
qui tabout wave hhh_gender using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_np lb ub) npos(col) append h1("mpi np hhh gender ") f(4)
qui tabout wave if dataset==1 using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_np lb ub) npos(col) append h1("mpi np overall") f(4)
*mpi poor
qui tabout wave using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_poor lb ub) npos(col) append h1("mpi overall") f(4)
qui tabout wave urban using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_poor lb ub) npos(col) append h1("mpi urban") f(4)
qui tabout wave quintiles_tc using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_poor lb ub) npos(col) append h1("mpi quintiles ") f(4)
qui tabout wave hhh_gender using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_poor lb ub) npos(col) append h1("mpi hhh gender ") f(4)
qui tabout wave if dataset==1 using "${gsdOutput}/Raw-Data 16.xls", svy sum c(mean mpi_poor lb ub) npos(col) append h1("mpi overall") f(4)
*Sanitation by type
use "${gsdW3}/Data/1-CleanOutput/hhq.dta", clear
gen wave=3
gen pweight=weight*hhsize
keep wave stratum state urban ea hh  weight pweight D_17_toilet D_9_water_home D_10_drink_source
rename (D_17_toilet D_9_water_home D_10_drink_source ) (h9 water_home drink_source  )
append using "${gsdData}/1-CleanTemp/NBHS.dta", keep(wave stratum urban state ea hh h9 h5 weight pweight)
*merge with hhh_gender
merge 1:1 wave state ea hh using "${gsdTemp}/multidimensional_deprivation.dta", nogen assert(match using master) keep(match) keepusing(hhh_gender quintiles_tc)
*tabulate
replace h9=8 if inlist(h9,5,6,7)
replace h9=3 if h9==4
replace h9=. if h9<0 
label define toilet 8 "No toilet" 3 "Flush toilet", modify
qui tabout h9 urban if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("toilet urban 2016") f(4)
qui tabout h9 quintiles_tc if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("toilet quintiles 2016") f(4)
qui tabout h9 hhh_gender if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("toilet hhh gender 2016") f(4)
qui tabout h9 urban if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("toilet urban 2009") f(4)
qui tabout h9 quintiles_tc if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("toilet quintiles 2009") f(4)
qui tabout h9 hhh_gender if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("toilet hhh gender 2009") f(4)
*water sources
gen improved_watersource=inlist(drink_source,1,2,3,4,5,10) if  inrange(wave,1,3)
recode drink_source (1 2 3 5 10  = 1 "Borehole") (4 = 2 "Hand pump") (6=3 "Shallow well") (7 8 9 11=4 "Open water"), gen(water)
recode h5 (1 2 3 4 6 12  = 1 "Borehole") (5 = 2 "Hand pump") (7=3 "Shallow well") (8 9 10 11 13=4 "Open water"), gen(xwater)
replace water=xwater if wave==0
qui tabout water urban if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("water urban 2016") f(4)
qui tabout water quintiles_tc if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("water quintiles 2016") f(4)
qui tabout water hhh_gender if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("water hhh gender 2016") f(4)
qui tabout water urban if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("water urban 2009") f(4)
qui tabout water quintiles_tc if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("water quintiles 2009") f(4)
qui tabout water hhh_gender if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("water hhh gender 2009") f(4)
*IDPs
use  "${gsdTemp}/multidimensional_deprivation.dta", clear
keep if dataset==1
merge 1:1 dataset state ea hh using "${gsdData}/1-CleanOutput/hhq.dta", nogen keep(match) keepusing(C_20_toilet C_21_share_facility )
*toilet
gen t=3 if inlist(C_20_toilet,1,2,3,4,5) 
replace t=1 if inlist(C_20_toilet,6,7,9) & C_21_share_facility==2
replace t=2 if inlist(C_20_toilet,8) | (inlist(C_20_toilet,6,7,9) & C_21_share_facility==1)
replace t=4 if inlist(C_20_toilet,10,11,12) 
qui tabout t using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("toilet IDPs") f(4)
*water
merge 1:1 dataset state ea hh using "${gsdData}/1-CleanOutput/hhq.dta", nogen keep(match) keepusing(C_10_water_home )
recode C_10_water_home (1 2 4  = 1 "Borehole") (3 = 2 "Hand pump") (5 6=3 "Shallow well") (7 8 9 13=4 "Open water"), gen(water)
qui tabout water using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("water IDPs") f(4)
*members per room
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
qui tabout memperroom urban if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("memperroom urban 2016") f(4)
qui tabout memperroom quintiles_tc if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("memperroom quintiles 2016") f(4)
qui tabout memperroom hhh_gender if wave==3 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("memperroom hhh gender 2016") f(4)
qui tabout memperroom urban if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("memperroom urban 2009") f(4)
qui tabout memperroom quintiles_tc if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("memperroom quintiles 2009") f(4)
qui tabout memperroom hhh_gender if wave==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("memperroom hhh gender 2009") f(4)
*cooking fuel in 2016
use "${gsdW3}/Data/1-CleanOutput/hhq.dta", clear
gen wave=3
merge 1:1 wave state ea hh using "${gsdTemp}/multidimensional_deprivation.dta", nogen assert(match using master) keep(match) keepusing(hhh_gender)
keep if state>81
gen pweight=weight*hhsize 
svyset ea [pw=pweight], strata(stratum)
qui tabout cooking urban using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("cook urban 2009") f(4)
qui tabout cooking quintiles_tc using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("cook quintiles 2009") f(4)
qui tabout cooking hhh_gender using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("cook hhh gender 2009") f(4)
*quintiles urban rural
*Sanitation by type
use "${gsdW3}/Data/1-CleanOutput/hhq.dta", clear
gen wave=3
gen pweight=weight*hhsize
keep wave stratum state urban ea hh  weight pweight D_17_toilet D_9_water_home D_10_drink_source
rename (D_17_toilet D_9_water_home D_10_drink_source ) (h9 water_home drink_source  )
append using "${gsdData}/1-CleanTemp/NBHS.dta", keep(wave stratum urban state ea hh h9 h5 weight pweight)
*merge with hhh_gender
merge 1:1 wave state ea hh using "${gsdTemp}/multidimensional_deprivation.dta", nogen assert(match using master) keep(match) keepusing(hhh_gender quintiles_tc)
*tabulate
replace h9=8 if inlist(h9,5,6,7)
replace h9=3 if h9==4
replace h9=. if h9<0 
label define toilet 8 "No toilet" 3 "Flush toilet", modify
qui tabout h9 quintiles_tc if wave==3 & urban==1 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("toilet quintiles urban 2016") f(4)
qui tabout h9 quintiles_tc if wave==3 & urban==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("toilet quintiles rural 2016") f(4)
*water sources
gen improved_watersource=inlist(drink_source,1,2,3,4,5,10) if  inrange(wave,1,3)
recode drink_source (1 2 3 5 10  = 1 "Borehole") (4 = 2 "Hand pump") (6=3 "Shallow well") (7 8 9 11=4 "Open water"), gen(water)
recode h5 (1 2 3 4 6 12  = 1 "Borehole") (5 = 2 "Hand pump") (7=3 "Shallow well") (8 9 10 11 13=4 "Open water"), gen(xwater)
replace water=xwater if wave==0
qui tabout water quintiles_tc if wave==3 & urban==1 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("water urban quintiles 2016") f(4)
qui tabout water quintiles_tc if wave==3 & urban==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("water rural quintiles 2016") f(4)
*crowding quintiles
use  "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)	
qui tabout memperroom quintiles_tc if wave==3 & urban==1 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("memperroom quintiles 2016") f(4)
qui tabout memperroom quintiles_tc if wave==3 & urban==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("memperroom quintiles 2016") f(4)
qui tabout memperroom quintiles_tc if dataset==1 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("memperroom quintiles idp") f(4)
*electricity quintiles
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
qui tabout electricity quintiles_tc if wave==3 & urban==1 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("elec urban 2016") f(4)
qui tabout electricity quintiles_tc if wave==3 & urban==0 using "${gsdOutput}/Raw-Data 16.xls", svy c(col lb ub) npos(col) append h1("elec urban 2016") f(4)
*place raw data into the excel figures file
insheet using "${gsdOutput}/Raw-Data 16.xls", clear nonames
export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data 16") 
rm "${gsdOutput}/Raw-Data 16.xls"

*Assets analysis
*Asset ownership?
use "${gsdTemp}/multidimensional_deprivation.dta", clear
svyset ea [pw=pweight], strata(stratum)
*prepare HFS asset ownership
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/assets_analysis_wide.dta", nogen assert(match master using) keep(match master) keepusing(Canoe_boat Plough Refrigerator Fan Air_cooler_air_conditioner Mattress_or_bed Mosquito_net Hoe_spade_axe)
local assets = "Canoe_boat Plough Refrigerator Fan Air_cooler_air_conditioner Mattress_or_bed Mosquito_net Hoe_spade_axe"
foreach v of local assets {
	quietly replace `v'=!missing(`v')
}
rename (Canoe_boat Plough Refrigerator Fan Air_cooler_air_conditioner Mattress_or_bed Mosquito_net Hoe_spade_axe) (canoe plough refrigerator fan aircon mattress_bed mosquito_net hoe_spade_axe)
*prepare NBHS assets
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/NBHS.dta", nogen assert(match master using) keep(match master) keepusing(i24_1 i35_1 i36_1 i37_1 i310_1)
foreach v of varlist i24_1 i35_1 i36_1 i37_1 i310_1 {
	replace `v'=`v'==1 
}
replace canoe=i24_1 if wave==0
replace refrigerator=i35_1 if wave==0
replace fan=i36_1 if wave==0
replace aircon=i37_1 if wave==0
replace mosquito_net=i310_1 if wave==0
drop  i24_1 i35_1 i36_1 i37_1 i310_1 
order tvsat radio mobile_phone computer cartruck motorcycleshaw bicycle canoe plough refrigerator fan aircon mattress_bed mosquito_net hoe_spade_axe, last
local assets = "tvsat radio mobile_phone computer cartruck motorcycleshaw bicycle canoe refrigerator fan aircon mosquito_net plough mattress_bed hoe_spade_axe"
foreach v of local assets {
	qui tabout `v' wave if dataset!=1 using "${gsdOutput}/Raw-Data 17.xls", svy c(col lb ub) npos(col) append h1("`v' ownership") f(4)
	qui tabout `v' if dataset==1 using "${gsdOutput}/Raw-Data 17.xls", svy c(col lb ub) npos(col) append h1("`v' ownership IDP") f(4)	
	display "`v'"
}
*ownership of selected assets by quintile
merge 1:1 wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master) keepusing(mi_cons_f mi_cons_nf)
egen tc_fnf=rowtotal(mi_cons_f mi_cons_nf)
xtile quintiles_fnf=tc_fnf [aw=pweight] if wave==3, nq(5)
label val quintiles_fnf lquintiles_tc
local assets = "tvsat radio mobile_phone computer cartruck motorcycleshaw bicycle canoe  refrigerator fan  mosquito_net plough mattress_bed hoe_spade_axe"
foreach v of local assets {
	qui tabout `v' quintiles_fnf if dataset==2 & wave==3 using "${gsdOutput}/Raw-Data 17.xls", svy c(col lb ub) npos(col) append h1("`v' ownership") f(4)
		display "`v'"
}
*Assets by urban rural
local assets = "tvsat radio mobile_phone computer cartruck motorcycleshaw bicycle canoe  refrigerator fan  mosquito_net plough mattress_bed hoe_spade_axe"
foreach v of local assets {
	qui tabout `v' urban if dataset==2 & wave==3 using "${gsdOutput}/Raw-Data 17.xls", svy c(col lb ub) npos(col) append h1("`v' ownership urban/rural") f(4)
	display "`v'"
}
*place raw data into the excel figures file
insheet using "${gsdOutput}/Raw-Data 17.xls", clear nonames
export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data 17") 
rm "${gsdOutput}/Raw-Data 17.xls"
