*this do file prepares education statistics

use "${gsdData}/1-CleanTemp/hhm_analysis.dta" , clear
svyset ea [pw=weight], strata(stratum)
keep dataset wave urban stratum state ea weight hh hhmid ishead age gender age_g school_age_primary-edu_reason
merge m:1 dataset wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match) keepusing(poor* tc_imp quintiles_tc lhood hhh_gender)
*create analysis variables
gen inschool=edu_current==1 if school_age_prim_sec==1
label val inschool lyn
*replace other in edu level categorized
replace edu_level_g=. if edu_level_g==5
gen edu_levels=edu_level_g if inrange(age,6,120)
label define edu_level_g 2 "Primary" , modify
label val edu_levels edu_level_g
*recode edu level for school attendance to take into those who may have completed primary last year and are now in secondary
recode edu_level (0 = 1 "No Education") (10/20 = 2 "Primary & Intermediate") (21/27 = 3 "Secondary") (29/33 = 4 "University") (7 8 5 = 1000 "Others"), generate(edu_level_a)
replace edu_level_a=1 if edu_ever==0
replace edu_level_a = 0 if inrange(age,0,5)
label define edu_level_a 0 "Not of Education Age" .a "Don't know" .b "Refused to respond", add
*create primary attendance ratio
gen primary_attend=edu_current if school_age_primary
label val primary_attend lyn
*create secondary attendance ratio
gen secondary_attend=0 if school_age_secondary==1 
replace secondary_attend=1 if school_age_secondary==1 & edu_level_a==3
label val secondary_attend lyn
*create 5 yr increment variable
recode age (0/5 = 1 "5 and under") (6/10 = 2 "6 - 10 Years") (11/15 = 3 "11 - 15 Years") (16/20 = 4 "16 - 20 Years") (21/25 = 5 "21 - 25 Years") (26/120 = 7 "26 and above") , generate(age_cat_g)
*create age ranges for different educational stats
gen youth=inrange(age,6,25)
gen adult=inrange(age,26,120)
gen age18up=inrange(age,18,120)
gen age15up=inrange(age,15,120)
gen age25up=inrange(age,25,120)
recode age (0/4 = 1 "Under 5 Years") (5/9 = 2 "5 - 9 Years") (10/14 = 3 "10 - 14 Years") (15/19 = 4 "15 - 19 Years") (20/24 = 5 "20 - 24 Years") (25/29 = 6 "25 - 29 Years") (30/34 = 7 "30 - 34 Years") (35/39 = 8 "35 - 39 Years") (40/44 = 9 "40 - 44 Years") (45/49 = 10 "45 - 49 Years") (50/54 = 11 "50 - 54 Years") (55/59 = 12 "55 - 59 Years") (60/65 = 13 "60 - 64 Years") (65/120 = 14 "65+ Years") , generate(age_cat_gg)
*gen completed at least primary
gen primary=inrange(edu_levels,2,4) if !missing(edu_levels)
gen secondary=inrange(edu_levels,3,4) if !missing(edu_levels)
*label
foreach v of varlist youth adult age*up primary secondary {
	label val `v' lyn
}
save "${gsdTemp}/hhm_analysis_education.dta", replace

if ${public}==0 {
	*save temp education analysis file
	*Education
	use "${gsdNBHS}/NBHS_IND.dta", clear
	egen stratum=group(state urban)
	rename hhweight weight
	rename (cluster hhid) (ea hh)
	svyset ea [pw=weight], strata(stratum)
	rename (b3 b41) (gender age)
	replace urban=0 if urban==2
	gen wave=0
	gen dataset=3
	svyset ea [pw=weight], strata(stratum)
	*create age groupings
	gen school_age_primary=inrange(age,6,13)
	gen school_age_secondary=inrange(age,14,18)
	gen school_age=inrange(age,6,18)
	*clean attendance
	rename (c1 c2 c3) (literacy edu_ever edu_current)
	replace edu_ever=. if edu_ever==-9
	replace edu_current=. if edu_current==-9
	replace edu_current=2 if edu_ever==2	
	*create primary attendance rate
	gen primary_attend=edu_current if school_age_primary==1 & inrange(c5,1,8)
	replace primary_attend=2 if school_age_primary==1 & edu_current==2
	label val primary_attend c3
	*create secondary attendance rate
	gen secondary_attend=edu_current if school_age_secondary==1 & inrange(c6,9,14)
	replace secondary_attend=2 if school_age_secondary==1 & edu_current==2
	label val secondary_attend c3
	*create in school dummy
	gen inschool=edu_current if inrange(age,6,18)
	label val inschool c3
	rename head ishead 
	bysort state ea hh: gen hhmid=_n 
	keep dataset wave stratum urban state ea hh weight ishead age gender literacy inschool edu_ever edu_current  
	order dataset wave stratum urban state ea hh weight ishead age gender literacy inschool edu_ever edu_current   
	foreach v of varlist literacy inschool edu_ever edu_current {
		replace `v'=0 if `v'==2
		replace `v'=. if `v'<0
	}
	save  "${gsdTemp}/NBHS_hhm_education_temp.dta", replace
	use "${gsdTemp}/hhm_analysis_education.dta", clear
	drop if dataset==1 
	replace edu_ever=1 if edu_current==1
	keep dataset wave stratum urban state ea hh weight ishead age gender literacy inschool edu_ever edu_current  
	append using "${gsdTemp}/NBHS_hhm_education_temp.dta"
	label val state state
	*save as education analysis data
	save  "${gsdTemp}/analysis_education.dta", replace
}

*Tables
use "${gsdTemp}/hhm_analysis_education.dta", clear
*Literacy
qui tabout literacy wave if inlist(wave,1,3) & age15up==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Literacy W1-3") f(4)
qui tabout literacy wave if urban==0 & dataset==2 & age15up==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Literacy W1-3 Rural") f(4)
qui tabout literacy wave if urban==1 & dataset==2  & age15up==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Literacy W1-4 Urban") f(4)
qui tabout literacy wave if dataset==1  & age15up==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Literacy IDP") f(4)
*Adult educational attainment
qui tabout edu_levels wave if inlist(wave,1,3) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Attainment W1-3") f(4)
qui tabout edu_levels wave if urban==0 & dataset==2  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Attainment W1-3 Rural") f(4)
qui tabout edu_levels wave if urban==1 & dataset==2  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Attainment W1-4 Urban") f(4)
qui tabout edu_levels wave if dataset==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Attainment IDP") f(4)
*school attendance, primary
qui tabout primary_attend wave if inlist(wave,1,3)  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Primary school attendance W1-3") f(4)
qui tabout primary_attend wave if urban==0 & dataset==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Primary school attendance W1-3 Rural") f(4)
qui tabout primary_attend wave if urban==1 & dataset==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Primary school attendance W1-4 Urban") f(4)
qui tabout primary_attend wave if dataset==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Primary school attendance IDP") f(4)
*school attendance, secondary
qui tabout secondary_attend wave if inlist(wave,1,3) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Secondary school attendance W1-3") f(4)
qui tabout secondary_attend wave if urban==0 & dataset==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Secondary school attendance W1-3 Rural") f(4)
qui tabout secondary_attend wave if urban==1 & dataset==2  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Secondary school attendance W1-4 Urban") f(4)
qui tabout secondary_attend wave if dataset==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Secondary school attendance IDP") f(4)
*grade attended by age group for those attending school
qui tabout edu_level_g age_cat_g if inrange(age,6,35) & wave==3 & edu_current==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col) npos(col) append h1("Grade attended W3") f(4)
qui tabout edu_level_g age_cat_g if inrange(age,6,35) & wave==1 & edu_current==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col) npos(col) append h1("Grade attended W1") f(4)
*attendance rate for school aged children
qui tabout inschool wave if inlist(wave,1,3) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("school attendance W1-3") f(4)
qui tabout inschool wave if urban==0 & dataset==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("school attendance W1-3 Rural") f(4)
qui tabout inschool wave if urban==1 & dataset==2  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("school attendance W1-4 Urban") f(4)
qui tabout inschool wave if dataset==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("school attendance IDP") f(4)
*Adult educational attainment by gender
forvalues i=1/2 {
	if `i'==1 {
		local g="Male"
	}
	if `i'==2 {
		local g="Female"
	}
	qui tabout edu_levels wave if inlist(wave,1,3) & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' Attainment W1-3") f(4)
	qui tabout edu_levels wave if urban==0 & dataset==2 & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' Attainment W1-3 Rural") f(4)
	qui tabout edu_levels wave if urban==1 & dataset==2 & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' Attainment W1-4 Urban") f(4)
	qui tabout edu_levels wave if dataset==1 & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' Attainment IDP") f(4)
}
*School attendance by gender
forvalues i=1/2 {
	if `i'==1 {
		local g="Male"
	}
	if `i'==2 {
		local g="Female"
	}
	qui tabout inschool wave if inlist(wave,1,3) & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance W1-3") f(4)
	qui tabout inschool wave if urban==0 & dataset==2 & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance W1-3 Rural") f(4)
	qui tabout inschool wave if urban==1 & dataset==2 & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance W1-4 Urban") f(4)
	qui tabout inschool wave if dataset==1 & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance IDP") f(4)
}
*Adult and youth literacy and educational attainment
foreach a in youth adult {
	*Literacy
	qui tabout literacy wave if inlist(wave,1,3) & `a'==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' Literacy W1-3") f(4)
	qui tabout literacy wave if urban==0 & dataset==2 & `a'==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' Literacy W1-3 Rural") f(4)
	qui tabout literacy wave if urban==1 & dataset==2  & `a'==1  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' Literacy W1-4 Urban") f(4)
	qui tabout literacy wave if dataset==1  & `a'==1  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' Literacy IDP") f(4)
	*Adult educational attainment
	qui tabout edu_levels wave if inlist(wave,1,3)  & `a'==1  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' Attainment W1-3") f(4)
	qui tabout edu_levels wave if urban==0 & dataset==2  & `a'==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' Attainment W1-3 Rural") f(4)
	qui tabout edu_levels wave if urban==1 & dataset==2  & `a'==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' Attainment W1-4 Urban") f(4)
	qui tabout edu_levels wave if dataset==1  & `a'==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' Attainment IDP") f(4)
}


*** OVER QUINTILES
*school attendance by poverty
qui tabout inschool quintiles_tc if dataset==2 & wave==3 & inrange(age,6,18) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance W3") f(4)
qui tabout inschool quintiles_tc if dataset==2 & urban==1 & wave==3 & inrange(age,6,18) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance W3 urban") f(4)
qui tabout inschool quintiles_tc if dataset==2 & urban==0 & wave==3 & inrange(age,6,18) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance W3 rural") f(4)
qui tabout inschool quintiles_tc if dataset==1 & inrange(age,6,18) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance IDP") f(4)
*literacy
qui tabout literacy quintiles_tc if dataset==2 & wave==3 & inrange(age,15,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("literacy W3") f(4)
qui tabout literacy quintiles_tc if dataset==2 & urban==1 & wave==3 & inrange(age,15,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("literacy W3 Urban") f(4)
qui tabout literacy quintiles_tc if dataset==2 & urban==0 & wave==3 & inrange(age,15,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("literacy W3 rural") f(4)
qui tabout literacy quintiles_tc if dataset==1 & inrange(age,15,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("literacy IDP") f(4)
*educational attainment by quintiles
qui tabout edu_levels quintiles_tc if dataset==2 & wave==3 & inrange(age,20,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attainment W3") f(4)
qui tabout edu_levels quintiles_tc if dataset==2 & urban==1 & wave==3 & inrange(age,20,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attainment urban W3") f(4)
qui tabout edu_levels quintiles_tc if dataset==2 & urban==0 & wave==3 & inrange(age,20,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attainment rural W3") f(4)
qui tabout edu_levels quintiles_tc if dataset==1 & inrange(age,20,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attainment IDP") f(4)
*poverty and gender wave 3
qui tabout edu_levels quintiles_tc if dataset==2 & wave==3 & gender==1 & inrange(age,18,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance quintiles male W3") f(4)
qui tabout edu_levels quintiles_tc if dataset==2 & wave==3 & gender==2 & inrange(age,18,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance quintiles gender female W3") f(4)
qui tabout edu_levels quintiles_tc if dataset==2 & wave==1 & gender==1 & inrange(age,18,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance quintiles gender male W1") f(4)
qui tabout edu_levels quintiles_tc if dataset==2 & wave==1 & gender==2 & inrange(age,18,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance quintiles gender female W1") f(4)
*School attendance by gender
forvalues i=1/2 {
	if `i'==1 {
		local g="Male"
	}
	if `i'==2 {
		local g="Female"
	}
	qui tabout inschool quintiles_tc if dataset==2 & wave==3 & inrange(age,6,18) & gender==`i'  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance poverty W3") f(4)
	qui tabout inschool quintiles_tc if urban==0 & dataset==2 & wave==3 & inrange(age,6,18) & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance poverty W3 Rural") f(4)
	qui tabout inschool quintiles_tc if urban==1 & dataset==2 &  wave==3 & inrange(age,6,18) & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance poverty W3 Urban") f(4)
	qui tabout inschool quintiles_tc if dataset==1 & inrange(age,6,18) &  gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance poverty IDP") f(4)
}

*completed at least some primary, youth and adults
foreach a in youth adult {
	*Literacy
	qui tabout primary wave if inlist(wave,1,3) & `a'==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' primary completion W1-3") f(4)
	qui tabout primary wave if urban==0 & dataset==2 & `a'==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' primary completion W1-3 Rural") f(4)
	qui tabout primary wave if urban==1 & dataset==2 & `a'==1  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' primary completion W1-4 Urban") f(4)
	qui tabout primary wave if dataset==1  & `a'==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`a' primary completion IDP") f(4)
}
*per age category
qui tabout age_cat_gg literacy if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3") f(4)
qui tabout age_cat_gg literacy if wave==3 & dataset==2 & gender==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
qui tabout age_cat_gg literacy if wave==3 & dataset==2 & gender==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Female") f(4)
qui tabout age_cat_gg primary if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3") f(4)
qui tabout age_cat_gg primary if wave==3 & dataset==2 & gender==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
qui tabout age_cat_gg primary if wave==3 & dataset==2 & gender==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Female") f(4)
qui tabout age_cat_gg secondary if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3") f(4)
qui tabout age_cat_gg secondary if wave==3 & dataset==2 & gender==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
qui tabout age_cat_gg secondary if wave==3 & dataset==2 & gender==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Female") f(4)
*attendance for youth by gender
qui tabout age_cat_g edu_current if wave==3 & dataset==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3") f(4)
qui tabout age_cat_g edu_current if wave==3 & dataset==2 & gender==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
qui tabout age_cat_g edu_current if wave==3 & dataset==2 & gender==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Female") f(4)
*reason for not attending
recode edu_reason (1=1 "Too young") (2=2 "Too old/finished school") (3=3 "Illness/disability") (4=4 "Pregnant") (6 =5 "Working at home") (5 7=6 "Working") (8=7 "lack of financial resources") (15/18 =9 "School closed/damaged/occupied/unsafe due to conflict") (9 10=10 "Lack of information/documents on enrollment") (11=11 "poor quality school") (14=12 "No school nearby") (20=13 "Not allowed") (nonmissing=.), gen(reason)
qui tabout reason dataset if wave==4 & edu_reason>2 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("reason for nto attending wave 4") f(4)
*attendance by age level
*School attendance by gender
forvalues i=1/2 {
	if `i'==1 {
		local g="Male"
	}
	if `i'==2 {
		local g="Female"
	}
	qui tabout inschool wave if dataset==2 & inrange(age,6,13) & gender==`i'  using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance poverty W3") f(4)
	qui tabout inschool wave if urban==0 & dataset==2 & inrange(age,6,18) & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance poverty W3 Rural") f(4)
	qui tabout inschool wave if urban==1 & dataset==2 & inrange(age,6,18) & gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance poverty W3 Urban") f(4)
	qui tabout inschool wave if dataset==1 & inrange(age,6,18) &  gender==`i' using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' attendance poverty IDP") f(4)
}
qui tabout wave inschool if inrange(age,6,13) & gender==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
qui tabout wave inschool if inrange(age,6,13) & gender==2 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
qui tabout wave inschool if inrange(age,6,13) & urban==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
qui tabout wave inschool if inrange(age,6,13) & urban==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
qui tabout wave inschool if inrange(age,6,13) & urban==0 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
qui tabout wave inschool if inrange(age,6,13) & urban==0 using "${gsdOutput}/Raw-Data 4.xls", svy c(row lb ub) npos(col) append h1("literacy by age group wave 3 Male") f(4)
*school attendance by poverty for Wave 1
qui tabout inschool quintiles_tc if dataset==2 & wave==1 & inrange(age,6,18) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance W1") f(4)
qui tabout inschool quintiles_tc if dataset==2 & urban==1 & wave==1 & inrange(age,6,18) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance W1 urban") f(4)
qui tabout inschool quintiles_tc if dataset==2 & urban==0 & wave==1 & inrange(age,6,18) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("attendance W1 rural") f(4)
*why not going to school
recode edu_reason (1 2 =1 "Too young/old") (3=3 "Illness/disability") (4=4 "Pregnant") (5 7 =5 "Working") (6=6 "Taking care of household") (8=7 "Lack of financial resources") (15 16 17 18=8 "Safety concerns/Schools closed due to conflict") (9 10 = 9 "No documents/Do not understand how to enroll") (nonmissing =10 "Other"), gen (edureasons)
qui tabout edureasons if dataset==2 & wave==4 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("why not attending school") f(4)
*literacy 18+ in 2016
qui tabout literacy urban if wave==3  & age18up==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Literacy 2016 18+") f(4)
qui tabout literacy quintiles_tc if wave==3  & age18up==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Literacy 2016 18+") f(4)
qui tabout literacy gender if wave==3  & age18up==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Literacy 2016 18+") f(4)
qui tabout literacy if dataset==1  & age18up==1 using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("Literacy IDP 18+") f(4)
*men women edu levels by state
qui tabout edu_levels state if inlist(wave,3) & gender==1 & inrange(age,18,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' Attainment W1-3") f(4)
qui tabout edu_levels state if inlist(wave,3) & gender==2 & inrange(age,18,120) using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) append h1("`g' Attainment W1-3") f(4)

if ${public}==0 {
	*by state
	use  "${gsdTemp}/analysis_education.dta", clear
	foreach n in 0 1 3 {
		qui tabout urban state if wave==`n'  using "${gsdOutput}/Raw-Data 4.xls", svy sum c(mean inschool lb ub) npos(col) append h1("inschool wave `n' 18+") f(4)
	}
	*Education in NBHS
	use "${gsdData}/1-CleanTemp/NBHS_hhm.dta", clear
	svyset ea [pw=weight], strata(stratum)
	*create age groupings
	gen school_age_primary=inrange(age,6,13)
	gen school_age_secondary=inrange(age,14,18)
	gen school_age=inrange(age,6,18)
	*clean attendance
	rename (c1 c2 c3) (literacy edu_ever edu_current)
	replace edu_ever=. if edu_ever==-9
	replace edu_current=. if edu_current==-9
	replace edu_current=2 if edu_ever==2	
	*create primary attendance rate
	gen primary_attend=edu_current if school_age_primary==1 & inrange(c5,1,8)
	replace primary_attend=2 if school_age_primary==1 & edu_current==2
	label val primary_attend c3
	*create secondary attendance rate
	gen secondary_attend=edu_current if school_age_secondary==1 & inrange(c6,9,14)
	replace secondary_attend=2 if school_age_secondary==1 & edu_current==2
	label val secondary_attend c3
	*create in school dummy
	gen inschool=edu_current if inrange(age,6,18)
	label val inschool c3
	*primary and secondary attendance rates
	qui tabout primary_attend urban using "${gsdOutput}/Raw-Data 4.xls", svy c(col lb ub) npos(col) f(4) append sebnone h2("primary attendance rate NBHS")
	qui tabout secondary_attend urban using "${gsdOutput}/Raw-Data 4.xls" , svy c(col lb ub) npos(col) f(4) append sebnone h2("secondary attendance rate NBHS")
	qui tabout literacy urban if inrange(age,14,120) using "${gsdOutput}/Raw-Data 4.xls" , svy c(col lb ub) npos(col) f(4) append sebnone h2("literacy rate NBHS")
	*inschool by income quintiles
	rename (ea hh) (cluster hhid)
	merge m:1 state cluster hhid using "${gsdNBHS}/NBHS_HH.dta", nogen assert(match using) keep(match) keepusing(quintile)
	rename (cluster hhid) (ea hh) 
	qui tabout inschool quintile using "${gsdOutput}/Raw-Data 4.xls" , svy c(col lb ub) npos(col) f(4) append sebnone h2("inschool 6-18 NBHS")
	qui tabout inschool quintile if urban==1 using "${gsdOutput}/Raw-Data 4.xls" , svy c(col lb ub) npos(col) f(4) append sebnone h2("inschool 6-18 NBHS urban")
	qui tabout inschool quintile if urban==0 using "${gsdOutput}/Raw-Data 4.xls" , svy c(col lb ub) npos(col) f(4) append sebnone h2("inschool 6-18 NBHS rural")
	qui tabout inschool gender using "${gsdOutput}/Raw-Data 4.xls" , svy c(col lb ub) npos(col) f(4) append sebnone h2("inschool gender 6-18 NBHS")
}
*place raw data into the excel figures file
insheet using "${gsdOutput}/Raw-Data 4.xls", clear nonames
export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data 4") 
rm "${gsdOutput}/Raw-Data 4.xls"


*expenditure analysis
if ${public}==0 {
	*prepare nbhs also
	*NBHS
	use "${gsdNBHS}/NBHS_NONFOOD.dta", clear
	keep if inlist(item,101,102)
	rename (cluster hhid) (ea hh)
	replace item=21901 if item==101
	replace item=21902 if item==102 
	rename (item q3) (itemid cons_value)
	keep state ea hh cons_value
	gen wave=0
	*turn into per capita per day
	merge m:1 state ea hh using "${gsdData}/1-CleanTemp/NBHS.dta", nogen keepusing(hhsize pceduca) assert(match using master) keep(match ) 
	replace cons_value=cons_value/12
	drop hhsize pceduca
	save "${gsdTemp}/nbhs_educ.dta", replace
	*get number of children
	use  "${gsdData}/1-CleanTemp/NBHS_hhm.dta",clear
	append using  "${gsdData}/1-CleanTemp/hhm_analysis.dta"
	keep if inrange(age,6,18)
	collapse (count) children_num=age, by(wave state ea hh)
	save "${gsdTemp}/children_num_6to18.dta", replace
	*prepare data
	use "${gsdTemp}/nonfood_analysis.dta", clear
	keep if inrange(itemid,21901,21902) & mod_item==0
	*check if NGOs provide education in camps
	tab free_main if state<10
	keep wave state ea hh cons_value
	append using  "${gsdTemp}/nbhs_educ.dta"
	replace cons_value=cons_value*(30/7) if wave!=0
	*collapse 
	collapse (sum) cons_value, by(wave state ea hh)
	rename cons_value educ_exp
	*merge with hhq
	merge 1:1  wave state ea hh using "${gsdTemp}/multidimensional_deprivation.dta", nogen assert(match master using) keep(match using) keepusing(dataset weight pweight stratum urban poor* tc_imp quintiles_tc hhsize hhh_gender)
	*merge with deflators
	merge 1:1  wave state ea hh using "${gsdData}/1-CleanTemp/hhq_analysis.dta", nogen assert(match master) keep(match master) keepusing(hhsize *cons_defl)
	replace nonfood_cons_defl=1.106 if urban==1 & wave==0
	replace nonfood_cons_defl=0.983 if urban==0 & wave==0
	replace nonfood_cons_defl=food_cons_defl if wave==1
	drop food_cons_defl
	*replace missings
	replace educ_exp=0 if missing(educ_exp)
	*merge with children number
	merge 1:1 wave state ea hh using  "${gsdTemp}/children_num_6to18.dta", nogen assert(match master using) keep(match master)
	replace children_num=0 if missing(children_num)
	*deflate
	replace educ_exp=educ_exp/hhsize/nonfood_cons_defl/(3576.183/3355.756) if wave==4
	replace educ_exp=educ_exp/hhsize/nonfood_cons_defl/(1779.765/3355.756)  if wave==3
	replace educ_exp=educ_exp/hhsize/nonfood_cons_defl/(517.19/3355.756)  if wave==2
	replace educ_exp=educ_exp/hhsize/nonfood_cons_defl/(239.906/3355.756) if wave==1
	replace educ_exp=educ_exp/hhsize/nonfood_cons_defl/(72.224/3355.756) if wave==0
	*remove outliers
	forvalues n=0/4 {
		quietly su educ_exp if wave==`n', detail
		replace educ_exp=r(p50) if educ_exp>=r(p99) & wave==`n'
	}
	*
	gen tc_month=tc_imp*52
	gen s=educ_exp/tc_month
	replace educ_exp=educ_exp*12
	*analysis
	svyset ea [pw=pweight], strata(stratum)
	save "${gsdTemp}/education_expenditure.dta", replace
	use "${gsdTemp}/education_expenditure.dta", clear
	*education gini
	fastgini educ_exp [pw=pweight] if wave==0
	fastgini educ_exp [pw=pweight] if wave==1
	fastgini educ_exp [pw=pweight] if wave==3
	*urban
	fastgini educ_exp [pw=pweight] if wave==0 & urban==1
	fastgini educ_exp [pw=pweight] if wave==1 & urban==1
	fastgini educ_exp [pw=pweight] if wave==3 & urban==1
	*rural
	fastgini educ_exp [pw=pweight] if wave==0 & urban==0
	fastgini educ_exp [pw=pweight] if wave==1 & urban==0
	fastgini educ_exp [pw=pweight] if wave==3 & urban==0
	*analysis and tables
	svy: mean educ_exp tc_month, over(wave dataset)
	svy: mean educ_exp tc_month, over(wave urban dataset)
	gen isq5=quintiles_tc==5
	svy: mean educ_exp if inlist(wave,0,1), over(wave isq5)
	lincom [educ_exp]_subpop_1-[educ_exp]_subpop_3
	lincom [educ_exp]_subpop_2-[educ_exp]_subpop_4
	*expenditure stats
	qui tabout wave urban if dataset!=1 using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean educ_exp lb ub) npos(col) replace h1("Expenditure") f(4)
	qui tabout wave hhh_gender if dataset!=1 using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean educ_exp lb ub) npos(col) append h1("Expenditure") f(4)
	qui tabout wave quintiles_tc if dataset!=1 using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean educ_exp lb ub) npos(col) append h1("Expenditure") f(4)
	qui tabout wave poor if dataset!=1 using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean educ_exp lb ub) npos(col) append h1("Expenditure") f(4)
	qui tabout dataset using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean educ_exp lb ub) npos(col) append h1("Expenditure") f(4)
	*share stats
	svy: mean s , over(wave dataset)
	svy: mean s , over(wave urban dataset)
	qui tabout wave urban if dataset!=1 using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean s lb ub) npos(col) append h1("Share") f(4)
	qui tabout wave hhh_gender if dataset!=1 using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean s lb ub) npos(col) append h1("Share") f(4)
	qui tabout wave quintiles_tc if dataset!=1 using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean s lb ub) npos(col) append h1("Share") f(4)
	qui tabout wave poor if dataset!=1 using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean s lb ub) npos(col) append h1("Share") f(4)
	qui tabout dataset using "${gsdOutput}/Raw-Data 20.xls", svy sum c(mean s lb ub) npos(col) append h1("Share") f(4)
	*concentration curve
	glcurve educ_exp if inlist(wave,0,1,3), by(wave) split lorenz  gl(edulorenz) p(p) nograph
	glcurve educ_exp if inlist(wave,3), by(urban) split lorenz  gl(edulorenz2016) p(p2016) nograph
	glcurve educ_exp if inlist(wave,0), by(urban) split lorenz  gl(edulorenz2009) p(p2009) nograph
	glcurve educ_exp if inlist(wave,1), by(urban) split lorenz  gl(edulorenz2015) p(p2015) nograph
	sort p
	export excel p edulorenz_0 edulorenz_1 edulorenz_3 p2016 edulorenz2016_0 edulorenz2016_1 p2009 edulorenz2009_0 edulorenz2009_1 p2015 edulorenz2015_0 edulorenz2015_1 using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("Education Lorenz") first(variables) cell(B1)
	*place raw data into the excel figures file
	insheet using "${gsdOutput}/Raw-Data 20.xls", clear nonames
	export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data 20") 
	rm "${gsdOutput}/Raw-Data 20.xls"
}

if ${public}==0 {
	*map school attendance
	use  "${gsdTemp}/analysis_education.dta", clear
	keep if inrange(age,6,18)
	collapse inschool [aw=weight], by(wave state urban)
	reshape wide inschool, i(state urban) j(wave)
	drop inschool2 inschool4
	label var inschool0 "May-2009"
	label var inschool1 "July-2015"
	label var inschool3 "Oct-2016"
	export excel  using "${gsdOutput}/Figures.xlsx", sheetmodify sheet("Education") first(varl) cell(CG37)
	*map each state
	use  "${gsdTemp}/analysis_education.dta", clear
	keep if inrange(age,6,18)
	collapse inschool [aw=weight], by(wave state )
	reshape wide inschool, i(state) j(wave)
	drop inschool2 inschool4
	decode state, gen(State)
	gen _ID= 1 if State=="Lakes"
	replace _ID= 2 if State=="Central Equatoria"
	replace _ID= 3 if State=="Eastern Equatoria"
	replace _ID= 4 if State=="Upper Nile"
	replace _ID= 5 if State=="Western Bahr Al Ghazal"
	replace _ID= 6 if State=="Unity"
	replace _ID= 7 if State=="Northern Bahr Al Ghazal"
	replace _ID= 8 if State=="Jonglei"
	replace _ID= 9 if State=="Western Equatoria"
	replace _ID= 10 if State=="Warap"	
	format inschool* %9.0f
	replace inschool0=inschool0*100
	replace inschool1=inschool1*100
	replace inschool3=inschool3*100
	*2009
	spmap inschool0 using "${gsdDataRaw}/states_shp_coordinates.dta", id(_ID) fcolor(RdBu)  ndfcolor(gs14)  clmethod(custom)  clbreaks(20 30 40 50 60 70 80) ///
		legend( size(medium) ) legstyle(2) legtitle("In school (%):") ///
		polygon(data("${gsdDataRaw}/states_shp_coordinates.dta") ocolor(black) osize(thick))  ///
		point(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) fcolor(black) shape(O D) by(juba) ) ///
		label(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) label(Town_Name)  by(labtype) pos(2) size(medium medium medium)) 
	graph export "${gsdOutput}/Inschool-2009.png", replace
	*
	spmap inschool1 using "${gsdDataRaw}/states_shp_coordinates.dta", id(_ID) fcolor(RdBu)  ndfcolor(gs14)  clmethod(custom)  clbreaks(20 30 40 50 60 70 80) ///
		legend( size(medium) ) legstyle(2) legtitle("In school (%):") ///
		polygon(data("${gsdDataRaw}/states_shp_coordinates.dta") ocolor(black) osize(thick))  ///
		point(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) fcolor(black) shape(O D) by(juba) ) ///
		label(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) label(Town_Name)  by(labtype) pos(2) size(medium medium medium)) 
	graph export "${gsdOutput}/Inschool-2015.png", replace
	*
	spmap inschool3 using "${gsdDataRaw}/states_shp_coordinates.dta", id(_ID) fcolor(RdBu)  ndfcolor(gs14)  clmethod(custom)  clbreaks(20 30 40 50 60 70 80) ///
		legend( size(medium) ) legstyle(2) legtitle("In school (%):") ///
		polygon(data("${gsdDataRaw}/states_shp_coordinates.dta") ocolor(black) osize(thick))  ///
		point(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) fcolor(black) shape(O D) by(juba) ) ///
		label(data("${gsdDataRaw}/towns_shp.dta") xcoord(X) ycoord(Y) label(Town_Name)  by(labtype) pos(2) size(medium medium medium)) 
	graph export "${gsdOutput}/Inschool-2016.png", replace
}
