*this do file performs the living conditions analysis

use "${gsdData}/1-CleanTemp/hhq_analysis.dta" , clear
svyset ea [pw=weight], strata(stratum)
*prepare variables
recode housingtype (1= 1 "Tent") (3 4=2 "Tukul/gottiya") (5 6 8 10=4 "Concrete/brick house") (7 10=3 "Mud/wood hut") (nonmissing=.), gen(house)
*recode variables
recode cooking ( 2 =1 "Grass") (3=2 "Firewood") (4=3 "Charcoal") (nonmissing=4 "Elec./Gas/Biogas/Other"), gen(cook)
*clean numerical variables
local services = "mkt school health water"
foreach s of local services {
	display "`s'"
	replace dist_`s'=. if dist_`s'>12
	replace dist_`s'=. if dist_`s'<=0
	bys data wave state ea: egen dist_`s'_ea=mean(dist_`s') 
}
replace sanitation=. if sanitation==2
*Wave 3 stats by consumption quintile
local amenities = "house cook sanitation lighting phone_network"
foreach s of local amenities {
	qui tabout `s' quintiles_tc if dataset==2 & urban==1 & wave==3 using "${gsdOutput}/Raw-Data 3.xls" , svy c(col ) npos(col) append h1("`s' urban W3") f(4)
	qui tabout `s' quintiles_tc if dataset==2 & urban==0 & wave==3 using "${gsdOutput}/Raw-Data 3.xls" , svy c(col ) npos(col) append h1("`s' rural W3") f(4)
	qui tabout `s' quintiles_tc if dataset==1 using "${gsdOutput}/Raw-Data 3.xls" , svy c(col ) npos(col) append h1("`s' National") f(4)
}
*National
local amenities = "house cook sanitation lighting phone_network"
foreach s of local amenities {
	qui tabout `s' if dataset==2 using "${gsdOutput}/Raw-Data 3.xls" , svy c(col ) npos(col) append h1("`s' overall") f(4)
}
if ${public}==0 {
	*2009
	use "${gsdNBHS}/NBHS_HH.dta", clear
	*keep only surveyed states, drop Warrap
	keep if state>81
	egen stratum=group(state urban)
	svyset cluster [pw=hhweight], strata(stratum)
	replace urban=0 if urban==2
	*living standards/Amenities
	*house type
	recode h1 (1= 1 "Tent") (3 4=2 "Tukul/gottiya") (5 6 8 10=4 "Concrete/brick house") (7 10=3 "Mud/wood hut") (nonmissing=.), gen(house)
	qui tabout house quintile using "${gsdOutput}/Raw-Data 3.xls", svy c(col) npos(col) replace h1("house type") f(4)
	qui tabout house quintile if urban==1 using "${gsdOutput}/Raw-Data 3.xls", svy c(col ) npos(col) append h1("house type urban") f(4)
	qui tabout house quintile if urban==0 using "${gsdOutput}/Raw-Data 3.xls", svy c(col) npos(col) append h1("house type rural") f(4)
	*sanitation
	recode h9 (6 = 1 "Bush") (1 2 = 3 "Pit Latrine") (3 4 = 4 "Flush") (nonmissing=.) , generate(sanitation)
	qui tabout sanitation quintile using "${gsdOutput}/Raw-Data 3.xls", svy c(col) npos(col) append h1("sanitation") f(4)
	qui tabout sanitation quintile if urban==1 using "${gsdOutput}/Raw-Data 3.xls", svy c(col) npos(col) append h1("sanitation urban") f(4)
	qui tabout sanitation quintile if urban==0 using "${gsdOutput}/Raw-Data 3.xls", svy c(col ) npos(col) append h1("sanitation rural") f(4)
	*energy for cooking
	recode h8 (9 = 1 "No cooking") (7 = 2 "Grass") (1 = 3 "Firewood") (2 = 4 "Charcoal") (3 = 5 "Gas") (4 = 6 "Electricity") (6 = 7 "Biogas") (nonmissing=1000 "Other"), generate(cooking)
	recode cooking ( 2 =1 "Grass") (3=2 "Firewood") (4=3 "Charcoal") (nonmissing=4 "Elec./Gas/Biogas/Other"), gen(cook)
	qui tabout cook quintile using "${gsdOutput}/Raw-Data 3.xls", svy c(col ) npos(col) append h1("cooking") f(4)
	qui tabout cook quintile if urban==1 using "${gsdOutput}/Raw-Data 3.xls", svy c(col ) npos(col) append h1("cooking urban") f(4)
	qui tabout cook quintile if urban==0 using "${gsdOutput}/Raw-Data 3.xls", svy c(col ) npos(col) append h1("cooking rural") f(4)
	*lighting
	recode h7 (11 = 1 "No Lighting") (6 7 = 2 "Grass / Firewood") (3/5 8 = 3 "Lamp/Candle/Torch") (1 2 = 5 "Electricity") (9 10 = 6 "Solar Power/Biogas")  (nonmissing=. ) , generate(lighting)
	qui tabout lighting quintile using "${gsdOutput}/Raw-Data 3.xls", svy c(col ) npos(col) append h1("lighting") f(4)
	qui tabout lighting quintile if urban==1 using "${gsdOutput}/Raw-Data 3.xls", svy c(col ) npos(col) append h1("lighting urban") f(4)
	qui tabout lighting quintile if urban==0 using "${gsdOutput}/Raw-Data 3.xls", svy c(col ) npos(col) append h1("lighting rural") f(4)
}

*place raw data into the excel figures file
insheet using "${gsdOutput}/Raw-Data 3.xls", clear nonames
export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data 3") 
rm "${gsdOutput}/Raw-Data 3.xls"
