*vulnerability analysis

*few preliminary stats for write up
use  "${gsdData}/1-CleanTemp/hhq_analysis.dta", clear
*adjust for population growth based on WDI figures
replace  pweight=pweight*(12230730/9263136)
svyset ea [pw=pweight], strata(stratum)
keep dataset stratum wave state urban ea hh pweight tc_imp poor poor125 plinePPP pline125PPP
drop if missing(tc_imp)
*how many nonpoor households live within 10 and 20	 percent of the poverty line
gen within10=inrange(tc_imp,plinePPP,plinePPP*1.1)
gen within20=inrange(tc_imp,plinePPP,plinePPP*1.2)
svy: total within10 within20 if wave==3
svy: mean within10 within20 if poor==0 & dataset==2, over(wave)
svy: mean within10 within20 if poor==0 & dataset==1, 
drop with*
*how many nonpoor households live within 10 and 20	 percent of 1 USD PPP
gen p1usdppp=tc_imp<(plinePPP*(1/1.90))
gen within10=tc_imp<(plinePPP*1.1*(1/1.90))
gen within20=tc_imp<(plinePPP*1.2*(1/1.90))
svy: mean p1usdppp within10 within20 if dataset==2, over(wave)
svy: mean within10 within20 if poor==1 & dataset==1, 
drop with*
*how many hosueholds live within 40 SSP of either poverty lines
gen within40pc=inrange(tc_imp,plinePPP,plinePPP+20)
gen within40pc_extreme=inrange(tc_imp,pline125PPP,pline125PPP+20)
svy: mean within40pc within40pc_extreme if inlist(wave,1,3), over(wave)
svy: total within40pc within40pc_extreme if inlist(wave,1,3), over(wave)
drop with*

*livestock losses and cattle raiding
use "${gsdW3}/Data/1-CleanOutput/livestock.dta", clear
gen raiding=(G_43_lose_reason==8 )
gen theft=(G_43_lose_reason==4 )
gen theftraiding=(G_43_lose_reason==8 | G_43_lose_reason==4)
gen cattle=index==1 & G_1_raise==1
gen givetohelp=(G_29_give_reason==3 | G_29_give_reason==4)
collapse (max) cattle own=G_1_raise theft raiding theftraiding givetohelp, by(state ea hh)
merge 1:1 state ea hh using "${gsdW3}/Data/1-CleanOutput/hhq.dta", nogen assert(match using) keepusing(weight urban hhsize stratum)
keep if state>81
svyset ea [pw=weight], strata(stratum)
svy: mean own cattle theft raiding theftraiding
svy: mean theft raiding theftraiding if own==1
svy: mean theft raiding theftraiding if cattle==1
*per giving
svy: mean givetohelp  if own==1


*prepare shock smoothed coefficients
import excel using "${gsdOutput}/QREG_percentiles.xlsx", clear sheet("Data for shock")  firstrow  case(lower) 
*create 99 and 100th percentile
set obs `=_N+2'
replace percentile=_n if missing(percentile)
foreach v of varlist beta_smooth beta_smooth_max beta_smooth_min {
	replace `v'=`v'[98] if missing(`v')
	*replace positive coefficients with zero, assume conflict can't have positive impact on consumption
	replace `v'=0 if `v'>0
}
save "${gsdTemp}/smoother_quantile_coefficients.dta", replace

*Shock analysis
use  "${gsdData}/1-CleanTemp/hhq_analysis.dta", clear
keep if wave==3
svyset ea [pw=pweight], strata(stratum)
keep dataset stratum wave state urban ea hh pweight tc_imp poor poor125 plinePPP pline125PPP
drop if missing(tc_imp)
*uniform consumption shock and min-max u
gen x1tc_shock_uniform=tc_imp*(1-.1)
gen x1p=x1tc_shock_uniform<plinePPP
gen x2tc_shock_uniform=tc_imp*(1-.2)
gen x2p=x2tc_shock_uniform<plinePPP
svy: mean x1p x2p
*uniform consumption shock and min-max using estimated SE for inflation analysis
gen tc_shock_uniform=tc_imp*(1-.32)
gen tc_shock_uniform_min=tc_imp*(1-.05)
gen tc_shock_uniform_max=tc_imp*(1-.59)
twoway (kdensity tc_shock_uniform [aw=pweight]) (kdensity tc_shock_uniform_min [aw=pweight]) (kdensity tc_shock_uniform_max [aw=pweight]) if tc_imp<450, xline(121)
*merge with smoother quantile regression
xtile percentile=tc_imp [pw=pweight], nq(100)
merge m:1 percentile using "${gsdTemp}/smoother_quantile_coefficients.dta", nogen assert(match)
*progressive consumption shock and min-max using estimated SE
gen tc_shock_prog=tc_imp*(1+beta_smooth)  
gen tc_shock_prog_min=tc_imp*(1+beta_smooth_min)
gen tc_shock_prog_max=tc_imp*(1+beta_smooth_max)
twoway (kdensity tc_shock_prog [aw=pweight]) (kdensity tc_shock_prog_min [aw=pweight]) (kdensity tc_shock_prog_max [aw=pweight]) if tc_imp<450, xline(121)
*calculate poverty statistics
local shocks = "uniform prog"
foreach s of local shocks {
	gen poor_`s'=tc_shock_`s'<plinePPP
	gen poor_`s'_ext=tc_shock_`s'<pline125PPP
	*min
	gen poor_`s'_min=tc_shock_`s'_min<plinePPP
	gen poor_`s'_ext_min=tc_shock_`s'_min<pline125PPP	
	*max
	gen poor_`s'_max=tc_shock_`s'_max<plinePPP
	gen poor_`s'_ext_max=tc_shock_`s'_max<pline125PPP
}
*check 
svy: mean poor_*
svy: mean poor_*, over(urban)
*graph 
local shocks = "uniform prog"
foreach s of local shocks {
	qui tabout poor_`s' urban using "${gsdOutput}/Raw-Data shock.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("poverty after `s' shock")
	qui tabout poor_`s'_ext urban using "${gsdOutput}/Raw-Data shock.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("extreme poverty after `s' shock")
	foreach m in min max {
		qui tabout poor_`s'_`m' urban using "${gsdOutput}/Raw-Data shock.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("poverty after `s'_`m' shock")
		qui tabout poor_`s'_ext_`m' urban using "${gsdOutput}/Raw-Data shock.xls", svy c(col se lb ub) npos(col) f(4) append sebnone h2("extreme poverty after `s'_`m' shock")		
	}
}
*calculate poverty gap
local shocks = "uniform prog"
foreach s of local shocks {
	gen gap_`s' = (plinePPP - tc_shock_`s')/plinePPP if (!missing(tc_shock_`s')) 
	replace gap_`s' = 0 if (tc_shock_`s'>plinePPP & !missing(tc_shock_`s'))
	foreach m in min max {
			gen gap_`s'_`m' = (plinePPP - tc_shock_`s'_`m')/plinePPP if (!missing(tc_shock_`s'_`m')) 
		replace gap_`s'_`m' = 0 if (tc_shock_`s'_`m'>plinePPP & !missing(tc_shock_`s'_`m'))

	}
}
*check 
svy: mean gap_*
svy: mean gap_*, over(urban)
*graph 
local shocks = "uniform prog"
foreach s of local shocks {
	qui tabout urban using "${gsdOutput}/Raw-Data shock.xls", svy sum c(mean gap_`s' se lb ub) npos(col) f(4) append sebnone h2("gap after `s' shock")
	foreach m in min max {
		qui tabout urban using "${gsdOutput}/Raw-Data shock.xls", svy sum c(mean gap_`s'_`m' se lb ub) npos(col) f(4) append sebnone h2("gap after `s'_`m' shock")
	}
}
*create consumption distribution for shock 
local shocks = "uniform prog"
foreach s of local shocks {
	xtile pctile_`s'=tc_shock_`s' [pw=pweight], nq(100)
	qui tabout pctile_`s' using "${gsdOutput}/Raw-Data shock.xls", svy sum c(mean tc_shock_`s' se lb ub) npos(col) f(4) append sebnone h2("distribution after `s' shock")	
	foreach m in min max {
		xtile pctile_`s'_`m'=tc_shock_`s'_`m' [pw=pweight], nq(100)
		qui tabout pctile_`s'_`m' using "${gsdOutput}/Raw-Data shock.xls", svy sum c(mean tc_shock_`s'_`m' se lb ub) npos(col) f(4) append sebnone h2("distribution after `s'_`m' shock")	
	}
}
*place raw data into the excel figures file
insheet using "${gsdOutput}/Raw-Data shock.xls", clear nonames
export excel using "${gsdOutput}/Figures.xlsx", sheetreplace sheet("Raw-Data shock") 
rm "${gsdOutput}/Raw-Data shock.xls"

*safety nets
svyset ea [pw=pweight], strata(stratum)
keep dataset wave stratum urban state ea hh weight pweight tc_imp poor* poor*PPP_prob hhh_gender pline*PPP quintiles_tc hunger_sleep hunger_nores hunger_sleep_freq hunger_daynight hunger_daynight_freq
merge 1:1 wave state ea hh using "${gsdTemp}/food_ownprod_aid.dta", nogen assert(match master using) keep(match)
*safety nets (i.e. receives aid/gifts/gov.t.
gen sn=cons_aid>0
svy: mean sn type2-type4 cons_aid cons_aid_sum aid if dataset==2 & wave==3, over(wave )
svy: mean sn type2-type4 cons_aid cons_aid_sum aid if dataset==2 & wave==3, over(wave urban)
